@@ -1,13 +1,12 @@
 #!/bin/bash
 #=======================================================================
-# * Version: $Id: motd.sh,v 1.4 2015/09/04 15:30:15 nroche Exp $
 # * Project: MediaTex
 # * Module:  client modules (User API)
 # *
 # * Unit test script for motd.c
 #
 # MediaTex is an Electronic Records Management System
-# Copyright (C) 2014 2015 Nicolas Roche
+# Copyright (C) 2014 2015 2016 Nicolas Roche
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,9 +32,7 @@ TEST=$(basename $0)
 TEST=${TEST%.sh}
 
 # run the unit test
-cp $CVSCLT/$MDTXUSER-coll1$SERVFILE $CVSCLT/$MDTXUSER-coll3$SERVFILE
-#cp $MD5SUMS/$MDTXUSER-coll1.md5 $MD5SUMS/$MDTXUSER-coll3.md5
-client/ut$TEST >client/$TEST.out 2>&1
+client/ut$TEST -d $srcdir/../misc >client/$TEST.out 2>&1
 
 # compare with the expected output
 mrProperOutputs client/$TEST.out
