@@ -1,13 +1,12 @@
 #!/bin/bash
 #=======================================================================
-# * Version: $Id: serverTree.sh,v 1.2 2015/08/30 17:07:57 nroche Exp $
 # * Project: MediaTex
 # * Module:  memory tree modules
 # *
 # * Unit test script for servertree.c
 #
 # MediaTex is an Electronic Records Management System
-# Copyright (C) 2014 2015 Nicolas Roche
+# Copyright (C) 2014 2015 2016 Nicolas Roche
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -38,6 +37,6 @@ memory/ut$TEST -d $srcdir > memory/$TEST.out 2>&1
 
 # compare with the expected output
 diff -I '# Version: $Id' \
-    $srcdir/memory/$TEST.exp ${CVSCLT}/${MDTXUSER}-coll1${SERVFILE}
+    $srcdir/memory/$TEST.exp ${GITCLT}/${MDTXUSER}-coll1${SERVFILE}
 mrProperOutputs memory/$TEST.out
 diff $srcdir/memory/$TEST.exp2 memory/$TEST.out
