@@ -1,5 +1,4 @@
 /*=======================================================================
- * Version: $Id: utFunc.c,v 1.18 2015/09/22 11:42:38 nroche Exp $
  * Project: MediaTeX
  * Module : utFunc
  *
@@ -7,7 +6,7 @@
  * (please look at utconfTree.c for some explanation on the topology)
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -674,7 +673,7 @@ createExempleServerTree(Collection* coll)
     "localhost", "127.0.0.1", "mediatex.org"};
   int mdtxPorts[] = {11111, 6560, 33333};
   int sshPorts[] = {22, 22, 2222};
-  int wwwPorts[] = {443, 443, 4443};
+  int wwwPorts[] = {443, 80, 4443};
 
   // fingerprints related to confTree
   char serverId[][MAX_SIZE_MD5+1] = {
@@ -864,7 +863,10 @@ createExempleRecordTree(Collection* coll)
     record->date = dates[i];
 
     // add the record to the tree
-    if (!rgInsert(rc->records, record)) goto error;
+    if (!avl_insert(rc->records, record)) {
+      logMemory(LOG_ERR, "cannot add record (already there?)");
+      goto error;
+    }
   }
  
   return rc;
