@@ -1,13 +1,12 @@
 #!/bin/bash
 #=======================================================================
-# * Version: $Id: command.sh,v 1.2 2015/08/23 23:39:11 nroche Exp $
 # * Project: MediaTex
 # * Module:  miscellaneous modules
 # *
 # * Unit test script for command.c
 #
 # MediaTex is an Electronic Records Management System
-# Copyright (C) 2014 2015 Nicolas Roche
+# Copyright (C) 2014 2015 2016 Nicolas Roche
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,7 +32,7 @@ TEST=$(basename $0)
 TEST=${TEST%.sh}
 
 # run the unit test
-misc/ut$TEST -s err -S -i $PWD/$srcdir/misc/env.sh \
+misc/ut$TEST -s err -sdebug:script -i $PWD/$srcdir/misc/env.sh \
     >misc/$TEST.out 2>&1
 
 # compare with the expected output
