@@ -1,13 +1,12 @@
 #!/bin/bash
 #=======================================================================
-# * Version: $Id: catalogFile.sh,v 1.2 2015/08/10 12:24:26 nroche Exp $
 # * Project: MediaTex
 # * Module:  parser modules
 # *
 # * Unit test script for catalogfile.c
 #
 # MediaTex is an Electronic Records Management System
-# Copyright (C) 2014 2015 Nicolas Roche
+# Copyright (C) 2014 2015 2016 Nicolas Roche
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,7 +32,7 @@ TEST=$(basename $0)
 TEST=${TEST%.sh}
 
 # run the unit test
-IN=${CVSCLT}/${MDTXUSER}-coll1${CATHFILE}
+IN=${GITCLT}/${MDTXUSER}-coll1${CATHFILE}
 parser/ut$TEST.tab -i $IN >parser/$TEST.out 2>parser/$TEST.txt
 
 # compare with the expected output
