@@ -1,13 +1,12 @@
 #!/bin/bash
 #=======================================================================
-# * Version: $Id: confFile.sh,v 1.2 2015/08/10 12:24:26 nroche Exp $
 # * Project: MediaTex
 # * Module:  parser modules
 # *
 # * Unit test script for conffile.c
 #
 # MediaTex is an Electronic Records Management System
-# Copyright (C) 2014 2015 Nicolas Roche
+# Copyright (C) 2014 2015 2016 Nicolas Roche
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -36,7 +35,7 @@ TEST=${TEST%.sh}
 for SRV in $(seq 1 3); do
     loadPaths "mdtx$SRV"
 
-    IN=${MDTXCVS}/${MDTXUSER}.conf
+    IN=${MDTXGIT}/${MDTXUSER}.conf
     parser/utconfFile.tab -i $IN \
 	>parser/$TEST$SRV.out 2>parser/$TEST$SRV.txt
 
