@@ -1,13 +1,12 @@
 #!/bin/bash
 #=======================================================================
-# * Version: $Id: notify.sh,v 1.4 2015/09/13 23:47:34 nroche Exp $
 # * Project: MediaTex
 # * Module:  server modules
 # *
 # * Unit test script for notify.c
 #
 # MediaTex is an Electronic Records Management System
-# Copyright (C) 2014 2015 Nicolas Roche
+# Copyright (C) 2014 2015 2016 Nicolas Roche
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,10 +32,10 @@ TEST=$(basename $0)
 TEST=${TEST%.sh}
 
 # run the unit test
-SRC=$CVSCLT/$MDTXUSER-coll1
+SRC=$GITCLT/$MDTXUSER-coll1
 loadPaths "mdtx2"
 for I in $(seq 1 3); do
-    DST=$CVSCLT/$MDTXUSER-coll$I
+    DST=$GITCLT/$MDTXUSER-coll$I
     cp $SRC$SERVFILE $DST$SERVFILE
     cp $SRC$EXTRFILE $DST$EXTRFILE
 done
