@@ -1,6 +1,5 @@
 #!/bin/bash
 #=======================================================================
-# * Version: $Id: tests.sh,v 1.14 2015/10/04 22:15:50 nroche Exp $
 # * Project: MediaTex
 # * Module : post installation tests
 # *
@@ -11,7 +10,7 @@
 # *        from the beginning
 #
 # MediaTex is an Electronic Records Management System
-# Copyright (C) 2014 2015 Nicolas Roche
+# Copyright (C) 2014 2015 2016 Nicolas Roche
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,26 +25,23 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #=======================================================================
+#set -x
 
 ############################################
 # remanent tasks
 ############################################
 
 ## demo
+DEBUG_SERVER=0
 SEVERITY_CLIENT="-s notice"
 SEVERITY_SERVER="-s notice"
-DEBUG_CLIENT_SCRIPT=""
-DEBUG_SERVER=0
 
 ## debug
-#SEVERITY_CLIENT="-s debug"
-#SEVERITY_SERVER="-s notice -s debug"
-#DEBUG_CLIENT_SCRIPT="-S"
 #DEBUG_SERVER=1          # need to run "$ xhost +" first
-#ADDON_SERVER="valgrind --leak-check=full"
-#ADDON_SERVER="valgrind"
+#SEVERITY_CLIENT="-s debug"
+#SEVERITY_SERVER="-s info -sdebug:main"
 
-### not done
+### todo
 ## ADDON_SERVER=gdb
 ## cf: gdb -ex "set args -c serv1" -ex "r" mediatexd
 
@@ -66,12 +62,8 @@ function query()
 {
     QUERY=$1
     SERVER=${2-serv1}
-    echo "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
-    echo " $SERVER: $QUERY"
-    echo "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
-    logger -p local2.NOTICE "++++++++++++++++++++++++++++++++++++++++++"
-    logger -p local2.NOTICE " $SERVER: $QUERY"
-    logger -p local2.NOTICE "++++++++++++++++++++++++++++++++++++++++++"
+    echo "> $SERVER: $QUERY"
+    logger -p local2.NOTICE "> $SERVER: $QUERY"
 }
 
 # $1: admin query
@@ -81,7 +73,7 @@ function mdtxA()
     QUERY=$1
     SERVER=${2-serv1}
     query "$QUERY" $SERVER
-    mediatex -c $SERVER $SEVERITY_CLIENT $DEBUG_CLIENT_SCRIPT $QUERY 
+    mediatex -c $SERVER $SEVERITY_CLIENT $QUERY 
 }
 
 # $1: publisher query
@@ -91,7 +83,7 @@ function mdtxP()
     QUERY=$1
     SERVER=${2-serv1}
     query "$QUERY" $SERVER
-    mediatex -c $SERVER $SEVERITY_CLIENT $DEBUG_CLIENT_SCRIPT su <<EOF
+    mediatex -c $SERVER $SEVERITY_CLIENT su <<EOF
 mediatex $QUERY
 EOF
 }
@@ -100,13 +92,12 @@ EOF
 # $2: command to exec before
 function question()
 {
+    echo -ne "\n"
     if [ ! -z "$2" ]; then
-	echo "=> $2 <="
-	echo "----------------------------------"
+	#echo "=> $2 <="
 	eval $2
-	echo "----------------------------------"
     fi
-    read -p "> $1 (y)/n: " VALUE
+    read -p "?> $1 (y)/n: " VALUE
     case "$VALUE" in
 	n|N)
 	    echo "Sorry, please fix me and retry..."
@@ -119,13 +110,12 @@ function question()
 # $2: command to exec before
 function notice()
 {
+    echo -ne "\n"
     if [ ! -z "$2" ]; then
-	echo "=> $2 <="
-	echo "----------------------------------"
+	#echo "=> $2 <="
 	eval $2
-	echo "----------------------------------"
     fi
-    echo "> $1"
+    echo "!> $1"
 }
 
 # $1: mdtx user (serv1 by default)
@@ -142,7 +132,6 @@ function yourMail()
 # $2: file to display
 function finalQuestion()
 {
-    echo "**********************************"
     question "$1" "$2"
     if [ $TEST_OK -eq 1 ]; then
 	TEST_NB=$[TEST_NB+1]
@@ -166,23 +155,37 @@ function sedInPlace()
 function startInitdScript()
 {
     SERVER=${1-serv1}
+    PORT=600${SERVER#serv}
 
     query "start" $SERVER
     
     # replace localhost by 127.0.0.1 in configuration
     sedInPlace "s/\(host.*\)localhost/\1127.0.0.1/" \
-	/etc/mediatex/$SERVER.conf
+	       /etc/mediatex/$SERVER.conf
 
-    # copy initd script
-    sed -e "s|mediatexd|mediatexd-$SERVER|" \
-	-e "s|\(DAEMON=/usr/bin\)/.*|\1/mediatexd|" \
-	-e "s|mdtx|$SERVER|" \
-	-e "s|--severity notice|$SEVERITY_SERVER|" \
-	/etc/init.d/mediatexd > /etc/init.d/mediatexd-$SERVER
-    chmod +x /etc/init.d/mediatexd-$SERVER
-    systemctl daemon-reload # needed by systemd
+    # set dedicated socket port
+    sedInPlace "s/6561/$PORT/" /etc/mediatex/$SERVER.conf
 
     if [ $DEBUG_SERVER -eq 0 ]; then
+	# copy initd script
+	sed -e "s|mediatexd|mediatexd-$SERVER|" \
+	    -e "s|\(DAEMON=/usr/bin\)/.*|\1/mediatexd|" \
+	    -e "s|mdtx|$SERVER|" \
+	    -e "s|--severity notice|$SEVERITY_SERVER|" \
+	    /etc/init.d/mediatexd > /etc/init.d/mediatexd-$SERVER
+	cat >>/etc/init.d/mediatexd-$SERVER <<EOF
+
+do_stop_cmd() {
+	start-stop-daemon --stop --quiet --retry=TERM/1/KILL/5 \
+	    \${PIDFILE:+--pidfile \${PIDFILE}} --name \$NAME --exec \$DAEMON
+	RETVAL="\$?"
+	[ "$RETVAL" = 2 ] && return 2
+	rm -f \$PIDFILE
+	return \$RETVAL
+}
+EOF
+	
+	chmod +x /etc/init.d/mediatexd-$SERVER
 	/etc/init.d/mediatexd-$SERVER start
     else 
 	cat >/tmp/doNotClose.sh <<EOF
@@ -193,23 +196,12 @@ echo "---- exited ----"
 bash
 EOF
 	chmod +x /tmp/doNotClose.sh
-	mkdir -p /var/run/mediatex
 	su $SERVER -c \
-	    "env -u SESSION_MANAGER xterm -e \
-              /tmp/doNotClose.sh $ADDON_SERVER mediatexd \
-               -c $SERVER $SEVERITY_SERVER -ffile -S &"	    
-
-	read -p "Please tel me when server is started..."
-
-	case "$ADDON_SERVER" in
-	    valgrind*)
-		PS=$(ps -ef | grep "valgrind.bin" | grep "$SERVER")
-		;;
-	    *)
-		PS=$(ps -ef | grep "0 [m]ediatexd -c $SERVER")
-	esac
-
-	echo $PS | awk '{print $2}' >/var/run/mediatex/${SERVER}d.pid
+	    "env -u SESSION_MANAGER \
+             xterm -sl 100000 -sb -rightbar \
+               -e /tmp/doNotClose.sh $ADDON_SERVER \
+                 mediatexd -c $SERVER $SEVERITY_SERVER -ffile &"   
+	while [ ! -f /var/run/mediatex/${SERVER}d.pid ]; do sleep 1; done
     fi
 }
 
@@ -223,7 +215,7 @@ function statusInitdScript()
     if [ $DEBUG_SERVER -eq 0 ]; then
 	/etc/init.d/mediatexd-$SERVER status
     else
-	ps -ef | grep $(cat /var/run/mediatex/${SERVER}d.pid)
+	ps -ef | grep "[ ]"$(cat /var/run/mediatex/${SERVER}d.pid)
     fi
 }
 
@@ -232,21 +224,18 @@ function statusInitdScript()
 function stopInitdScript()
 {
     SERVER=${1-serv1}
-
+    
+    [ -f /var/run/mediatex/${SERVER}d.pid ] || return
     query "stop" $SERVER
-
+    
     if [ $DEBUG_SERVER -eq 0 ]; then
-	if [ -f /etc/init.d/mediatexd-$SERVER ]; then
-	    /etc/init.d/mediatexd-$SERVER stop
-	fi
+	/etc/init.d/mediatexd-$SERVER stop
+	rm -f /etc/init.d/mediatexd-$SERVER
     else
-	if [ -f /var/run/mediatex/${SERVER}d.pid ]; then
-	    kill -TERM $(cat /var/run/mediatex/${SERVER}d.pid)
+	kill -TERM $(cat /var/run/mediatex/${SERVER}d.pid) || \
 	    rm /var/run/mediatex/${SERVER}d.pid
-	fi
+	while [ -f /var/run/mediatex/${SERVER}d.pid ]; do sleep 1; done
     fi
-
-    rm -f /etc/init.d/mediatexd-$SERVER
 }
 
 # $1: mdtx user (serv1 by default)
@@ -257,9 +246,7 @@ function reloadInitdScript()
     query "reload" $SERVER
 
     if [ $DEBUG_SERVER -eq 0 ]; then
-	if [ -f /etc/init.d/mediatexd-$SERVER ]; then
-	    /etc/init.d/mediatexd-$SERVER reload
-	fi
+	/etc/init.d/mediatexd-$SERVER reload
     else
 	if [ -f /var/run/mediatex/${SERVER}d.pid ]; then
 	    kill -HUP $(cat /var/run/mediatex/${SERVER}d.pid)
@@ -275,12 +262,19 @@ function restartInitdScript()
     query "restart" $SERVER
 
     if [ $DEBUG_SERVER -eq 0 ]; then
-	if [ -f /etc/init.d/mediatexd-$SERVER ]; then
-	    /etc/init.d/mediatexd-$SERVER restart
-	fi
+	/etc/init.d/mediatexd-$SERVER restart
     else
 	stopInitdScript $SERVER
-	read -p "Please tel me when server is stopped..."
+	startInitdScript $SERVER
+    fi
+}
+
+# $1: mdtx user (serv1 by default)
+function startInitdScriptIfNeeded()
+{
+    SERVER=${1-serv1}
+
+    if [ ! -f /var/run/mediatex/${SERVER}d.pid ]; then
 	startInitdScript $SERVER
     fi
 }
@@ -303,16 +297,15 @@ function cleanAll()
 function test1()
 {
     if [ "x$1" != "xclean" ]; then
-	topo "Configuring"
+	topo "Initialize"
 	mdtxA "adm init"
-	sedInPlace "s/6561/6001/" /etc/mediatex/serv1.conf
 	startInitdScript
 	finalQuestion "is http://localhost/~serv1/ correct ?"
     else
 	topo "Cleanup"
-	stopInitdScript
 	mdtxA "adm remove"
 	mdtxA "adm purge"
+	stopInitdScript
     fi
 }
 
@@ -320,16 +313,17 @@ function test1()
 function test2()
 {
     if [ "x$1" != "xclean" ]; then
-	topo "Dealing with locals supports"
+	topo "Dealing with supports"
+	startInitdScriptIfNeeded
 	mdtxP "ls supp"
 	mdtxP "note supp ex-cd1 as cd1"
 	mdtxP "add supp iso1 on /usr/share/mediatex/misc/logoP1.iso"
 	mdtxP "add file /usr/share/mediatex/misc/logoP2.iso"  
 	mdtxP "check supp ex-cd1 on /usr/share/mediatex/misc/logoP1.iso"  
-	mdtxP "check supp iso1 on /usr/share/mediatex/misc/logoP1.iso"
+	echo -ne "\n"
 	mdtxP "ls supp"
 	finalQuestion "is support db updated ?" \
-		      "cat /var/cache/mediatex/serv1/cvs/serv1/supports.txt"
+		      "cat ~serv1/git/serv1/supports.txt"
     else
 	topo "Cleanup"
 	mdtxP "del supp iso2"
@@ -343,20 +337,26 @@ function test3()
 {
     if [ "x$1" != "xclean" ]; then
 	topo "Create 'Hello' collection on server1"
+	startInitdScriptIfNeeded
 	mdtxA "adm add coll hello@localhost"
-	
-	# workaround for multiple server instances (because of systemd)
-	restartInitdScript
-	
+	mdtxP "make coll hello"
+	echo -ne "\n"
+	mdtxP "add supp iso1 to coll hello"
+	mdtxP "add supp /usr/share/mediatex/misc/logoP2.iso to coll hello"
+	echo -ne "\n"
+	question "does the configuration mention supports ?" \
+		 "grep -A10 Collection /etc/mediatex/serv1.conf"
+	[ $TEST_OK -eq 0 ] && return
+
 	mdtxP "make coll hello"
 	finalQuestion \
 	    "is https://127.0.0.1/~serv1-hello/ correct ? (login is serv1)"
     else
 	topo "Cleanup"
 	mdtxA "adm del coll hello"
-
-	# here we may want to remove the CVS content too (or not)
+	# needed else the previous entry remains in servers.txt
 	# rm -fr /var/lib/mediatex/serv1/serv1-hello
+	stopInitdScript
     fi
 }
 
@@ -364,21 +364,25 @@ function test3()
 function test4()
 {
     if [ "x$1" != "xclean" ]; then
-	topo "Ask for an archive record not yet available and register your mail"
+	topo "Ask for an archive record not yet into the cache"
+	startInitdScriptIfNeeded
+	sleep 1
+	
 	echo "123456789012345" | netcat 127.0.0.1 6001
 	statusInitdScript
 	question "does server survive after a strange message ?"
 	[ $TEST_OK -eq 0 ] && return
-
+	
 	yourMail
 	mdtxP "srv save"
 	finalQuestion "does the server get it ?" \
-		      "cat /var/cache/mediatex/serv1/md5sums/serv1-hello.md5"
+		 "cat ~serv1/md5sums/serv1-hello.md5 && echo -ne '\n'" 
     else
 	topo "Cleanup"
 	stopInitdScript
-	rm -f /var/cache/mediatex/serv1/md5sums/serv1-hello.md5
-	startInitdScript
+	rm -f ~serv1/md5sums/serv1-hello.md5
+	rm -fr ~serv1/cache/serv1-hello/logo*
+	rm -fr ~serv1/cache/serv1-hello/supports
     fi
 }
 
@@ -386,31 +390,30 @@ function test4()
 function test5()
 {
     if [ "x$1" != "xclean" ]; then
-    topo "Provide supports to get the requested archive record"
-    mdtxP "add supp iso1 to coll hello"
-    mdtxP "add supp /usr/share/mediatex/misc/logoP2.iso to coll hello"
-    question "does the configuration mention supports ?" \
-	     "grep -A10 Collection /etc/mediatex/serv1.conf"
-    [ $TEST_OK -eq 0 ] && return
+	topo "Provide supports to get the requested archive record"
+	startInitdScriptIfNeeded
     
-    mdtxP "motd"
-    mdtxP "check supp iso1 on /usr/share/mediatex/misc/logoP1.iso"
-    mdtxP "srv save"
-    question "check your mailbox" \
-		  "cat /var/cache/mediatex/serv1/md5sums/serv1-hello.md5"*
-    [ $TEST_OK -eq 0 ] && return
-
-    mdtxP "srv extract"
-    mdtxP "srv save"
-    finalQuestion "have simply extract from support. Extract do more ?" \
-	"cat /var/cache/mediatex/serv1/md5sums/serv1-hello.md5"
+	mdtxP "motd"
+	question "only asked to provide iso1 ?"
+	[ $TEST_OK -eq 0 ] && return
+	
+	mdtxP "check supp iso1 on /usr/share/mediatex/misc/logoP1.iso"
+	mdtxP "srv save"
+	question "check your mailbox" \
+		      "cat ~serv1/md5sums/serv1-hello.md5 && echo -ne '\n'"
+	[ $TEST_OK -eq 0 ] && return
+	
+	mdtxP "srv extract"
+	mdtxP "srv save"
+	finalQuestion "does extract copy support iso2 into the cache ?" \
+		      "cat ~serv1/md5sums/serv1-hello.md5 && echo -ne '\n'"
     else
 	topo "Cleanup"
-	mdtxP "del supp iso1 from coll hello"
-	mdtxP "del supp /usr/share/mediatex/misc/logoP2.iso from coll hello"
-	rm -fr /var/cache/mediatex/serv1/cache/serv1-hello/logo*
-	rm -fr /var/cache/mediatex/serv1/cache/serv1-hello/supports
+	rm -fr ~serv1/cache/serv1-hello/logo*
+	rm -fr ~serv1/cache/serv1-hello/supports
 	reloadInitdScript
+	echo -n "!> you may need to re-ask for the logo file"
+	echo " and give an email address."
     fi
 }
 
@@ -429,22 +432,24 @@ Document "css": "css"
   $SIGN
 EOF
 	topo "Upload file"
+	startInitdScriptIfNeeded
 	mdtxP "upload file $FILE catalog /tmp/test.cat to coll hello"
 	mdtxP "make coll hello"
 	finalQuestion "Please, browse score index and download mediatex.css"
 	[ $TEST_OK -eq 0 ] && return
 	
 	# clean extracted files (~test5) on cache for next tests
-	topo "remove support iso2 and extract files"
+	topo "remove supports and extract files"
+	mdtxP "del supp iso1 from coll hello"
 	mdtxP "del supp /usr/share/mediatex/misc/logoP2.iso from coll hello"
-	rm -fr /var/cache/mediatex/serv1/cache/serv1-hello/logo*
-	rm -fr /var/cache/mediatex/serv1/cache/serv1-hello/supports
+	sleep 1 # warning del supp will HUP server (so will scan cache)
+	rm -fr ~serv1/cache/serv1-hello/logo*
+	rm -fr ~serv1/cache/serv1-hello/supports
 	mdtxP "upgrade+"
-	# reloadInitdScript (already done by upgrade)
     else
 	topo "Cleanup"
-	rm -fr /var/cache/mediatex/serv1/cache/serv1-hello/incoming
-	sed -i -e "/(INC/, /)/ d" /etc/mediatex/serv1-hello/extract000.txt
+	rm -fr ~serv1/cache/serv1-hello/incoming
+	sedInPlace "/(INC/, /)/ d" ~serv1-hello/git/extract000.txt
 	reloadInitdScript
     fi
 }
@@ -454,11 +459,13 @@ function test7()
 {
     if [ "x$1" != "xclean" ]; then
 	topo "Configure server 2 (as a private network gateway)"
+	startInitdScriptIfNeeded
 	mdtxA "adm init" serv2
-	sedInPlace "s/6561/6002/" /etc/mediatex/serv2.conf
 	sedInPlace "s/networks   www/networks   www, private/" \
 	    /etc/mediatex/serv2.conf
 	echo "Gateways private" >> /etc/mediatex/serv2.conf
+	mdtxP "check supp ex-cd1 on /usr/share/mediatex/misc/logoP1.iso" \
+	      serv2
 	startInitdScript serv2
 	finalQuestion "is 2nd server running ?" "statusInitdScript serv2"
     else
@@ -473,63 +480,69 @@ function test8()
 {
     if [ "x$1" != "xclean" ]; then
 	topo "Register collection 'hello' on server 2"
-
+	for i in $(seq 1 2); do
+	    startInitdScriptIfNeeded serv$i
+	done
+	
 	# create serv2-hello key
-	notice "you will be ask for this fingerprint" \
+	notice "you will be ask twice for this fingerprint" \
 	       "grep 'host fingerprint' /etc/mediatex/serv1.conf"
 	mdtxA "adm add coll serv1-hello" serv2
+	echo -ne "\n"
 
 	# register serv2-hello key on serv1
-	cp /var/cache/mediatex/serv2/home/serv2-hello/.ssh/id_dsa.pub \
+	cp ~serv2/home/serv2-hello/.ssh/id_dsa.pub \
 	    /tmp/key
 	mdtxP "add key /tmp/key to coll hello" serv1
 
 	# server 2 register for collection hello on server 1
 	mdtxA "adm add coll serv1-hello" serv2
-
-	# workaround for multiple server instances (already done else)
-	restartInitdScript serv2
 	
-	question "connected to serv1 cvsroot ?" \
-		 "cat /var/cache/mediatex/serv2/cvs/serv2-hello/CVS/Root"
+	question "connected to serv1 gitbare ?" \
+		 "grep url ~serv2/git/serv2-hello/.git/config"
 	[ $TEST_OK -eq 0 ] && return
 	
 	# seen by first server
 	mdtxP "upgrade" serv1
 	finalQuestion "does 1st server see 2nd server ?" \
-	    "grep -A2 Server /var/cache/mediatex/serv1/cvs/serv1-hello/servers.txt"
+	    "grep -A2 Server ~serv1/git/serv1-hello/servers.txt"
     else
 	topo "Cleanup"
 
 	# remove serv2-hello keys from serv1
-	SRV="/var/cache/mediatex/serv1/cvs/serv1-hello/servers.txt"
+	SRV="~serv1/git/serv1-hello/servers.txt"
 	FPS=$(grep Server $SRV | awk '{ print $2 }')
 	for FP in $FPS; do 
 	    mdtxP "del key $FP from coll hello" serv1
 	done
 	
 	mdtxA "adm del coll hello" serv2
+	restartInitdScript serv1
     fi
 }
 
-# First server notify to second one you ask for an archive record not yet available
+# First server notify to second one you ask for an archive record
+# not yet available
 function test9()
 {
     if [ "x$1" != "xclean" ]; then
-	topo "Serv1 notify serv2 you ask for an archive record not yet available"
-
+	topo "Serv1 notify serv2 it is looking for the archive you ask"
+	for i in $(seq 1 2); do
+	    startInitdScriptIfNeeded serv$i
+	done
+	
 	# same as test4
 	yourMail
 	mdtxP "srv save" serv1
 	question "do the 1st server get it ?" \
-	     "cat /var/cache/mediatex/serv1/md5sums/serv1-hello.md5"
+	     "cat ~serv1/md5sums/serv1-hello.md5 && echo -ne '\n'"
 	[ $TEST_OK -eq 0 ] && return
 
 	# tell serv2 we need to extract a record
 	mdtxP "srv notify" serv1
 	mdtxP "srv save" serv2
 	finalQuestion "does 2nd server get your demand ?" \
-		      "cat /var/cache/mediatex/serv2/md5sums/serv2-hello.md5"
+		      "cat ~serv2/md5sums/serv2-hello.md5 && echo -ne '\n'"
     else
 	topo "Cleanup"
 	for SERV in serv1 serv2; do
@@ -546,26 +559,33 @@ function test10()
     if [ "x$1" != "xclean" ]; then
 	topo "server 2 provides first support and tell it to server 1"
 	mdtxP "add supp iso1 on /usr/share/mediatex/misc/logoP1.iso" serv2
+	mdtxP "motd" serv2
 	mdtxP "add supp iso1 to coll hello" serv2
+	mdtxP "motd" serv2
 	mdtxP "check supp iso1 on /usr/share/mediatex/misc/logoP1.iso" serv2
+	mdtxP "motd" serv2
+	
+	question "motd do not ask for 'iso1' anymore" ""
+	[ $TEST_OK -eq 0 ] && return
 	mdtxP "srv notify" serv2
 
 	# check server 1 was notified
 	mdtxP "srv save" serv1
 	question "do the 2nd server notify it gets materials ?" \
-		 "cat /var/cache/mediatex/serv1/md5sums/serv1-hello.md5"
+		 "cat ~serv1/md5sums/serv1-hello.md5 && echo -ne '\n'"
 	[ $TEST_OK -eq 0 ] && return
 	
 	# serv1 scp the remote content
 	mdtxP "srv extract" serv1
 	mdtxP "srv save" serv1
 	finalQuestion "part1 remotely copied by serv1 ?" \
-		      "cat /var/cache/mediatex/serv1/md5sums/serv1-hello.md5"
+		      "cat ~serv1/md5sums/serv1-hello.md5 && echo -ne '\n'"
     else
 	topo "Cleanup"
 	mdtxP "del supp iso1" serv2
 	for SERV in serv1 serv2; do
-	    rm -f /var/cache/mediatex/$SERV/cache/$SERV-hello/logo*
+	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/logo*
+	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/supports
 	    reloadInitdScript $SERV
 	done
 	mdtxP "srv notify" serv2
@@ -580,9 +600,10 @@ function test11()
         topo "Configure server 3 (from inside a private network)"
 
 	mdtxA "adm init" serv3
-	sedInPlace "s/6561/6003/" /etc/mediatex/serv3.conf
 	sedInPlace "s/networks   www/networks   private/" \
-	    /etc/mediatex/serv3.conf
+		   /etc/mediatex/serv3.conf
+	mdtxP "check supp ex-cd1 on /usr/share/mediatex/misc/logoP1.iso" \
+	      serv3
 	startInitdScript serv3
 	finalQuestion "is 3rd server running ?" "statusInitdScript serv3"
     else
@@ -598,36 +619,37 @@ function test12()
 {
     if [ "x$1" != "xclean" ]; then
 	topo "Register collection 'hello' on server 3"
-
+	for i in $(seq 1 3); do
+	    startInitdScriptIfNeeded serv$i
+	done
+	
 	# create serv3-hello key
-	notice "you will be ask for this fingerprint" \
+	notice "you will be ask twice for this fingerprint" \
 	       "grep 'host fingerprint' /etc/mediatex/serv1.conf"
 	mdtxA "adm add coll serv1-hello" serv3
+	echo -ne "\n"
 
 	# register serv3-hello key on serv1
-	cp /var/cache/mediatex/serv3/home/serv3-hello/.ssh/id_dsa.pub /tmp/key
+	cp ~serv3/home/serv3-hello/.ssh/id_dsa.pub \
+	   /tmp/key
 	mdtxP "add key /tmp/key to coll hello" serv1
 
 	# server 3 register for collection hello on server 1
 	mdtxA "adm add coll serv1-hello" serv3
 
-	# workaround for multiple server instances (already done else)
-	restartInitdScript serv3
-	
-	question "connected to serv1 cvsroot ?" \
-		 "cat /var/cache/mediatex/serv3/cvs/serv3-hello/CVS/Root"
+	question "connected to serv1 gitbare ?" \
+		 "grep url ~serv3/git/serv3-hello/.git/config"
 	[ $TEST_OK -eq 0 ] && return
 	
 	# seen by first servers
 	mdtxP "upgrade" serv1
 	finalQuestion "does 1st server see 3rd server ?" \
-		      "grep -A2 Server 
-                        /var/cache/mediatex/serv1/cvs/serv1-hello/servers.txt"
+		      "grep -A2 Server ~serv1/git/serv1-hello/servers.txt"
     else
 	topo "Cleanup"
 
 	# remove serv3-hello keys from serv1 (but not serv2 key!)
-	SRV="/var/cache/mediatex/serv1/cvs/serv1-hello/servers.txt"
+	SRV="~serv1/git/serv1-hello/servers.txt"
 	FPS1=$(grep -B3 end $SRV | grep Server | awk '{ print $2 }')
 	FPS2=$(grep -B4 6003 $SRV | grep Server | awk '{ print $2 }')
 	for FP in $FPS1 $FPS2; do 
@@ -638,8 +660,8 @@ function test12()
     fi
 }
 
-# First server notify to third one you ask for an archive record not yet available
-# (close to test 9)
+# First server notify to third one you ask for an archive record
+# not yet available (close to test 9)
 function test13()
 {
     if [ "x$1" != "xclean" ]; then
@@ -652,11 +674,11 @@ function test13()
 	
 	mdtxP "srv save" serv3
 	finalQuestion "does 3rd server get your demand ?" \
-		      "cat /var/cache/mediatex/serv3/md5sums/serv3-hello.md5"
+		      "cat ~serv3/md5sums/serv3-hello.md5 && echo -ne '\n'"
     else
 	topo "Cleanup"
 	stopInitdScript serv3
-	rm -f /var/cache/mediatex/serv3/md5sums/serv3-hello.md5
+	rm -f ~serv3/md5sums/serv3-hello.md5
 	startInitdScript serv3
     fi
 }
@@ -669,18 +691,22 @@ function test14()
 	topo "Server 3 provides second support and tell it to others"
  
 	mdtxP "add file /usr/share/mediatex/misc/logoP2.iso" serv3
-	mdtxP "add supp /usr/share/mediatex/misc/logoP2.iso to coll hello" serv3
+	mdtxP "motd" serv3
+	mdtxP "add supp /usr/share/mediatex/misc/logoP2.iso to coll hello" \
+	      serv3
+	
+	mdtxP "motd" serv3
 	mdtxP "srv extract" serv3
 	mdtxP "srv save" serv3
-	question "does serv3 get part2 ?" \
-		 "cat /var/cache/mediatex/serv3/md5sums/serv3-hello.md5"
+	question "does serv3 provides part2 ?" \
+		 "cat ~serv3/md5sums/serv3-hello.md5 && echo -ne '\n'"
 	[ $TEST_OK -eq 0 ] && return
 	
 	mdtxP "srv notify" serv3
 	mdtxP "srv extract" serv2
 	mdtxP "srv save" serv2
-	finalQuestion "part2 remotely copied by serv2 ? (and mediatex.css too)" \
-		      "cat /var/cache/mediatex/serv2/md5sums/serv2-hello.md5"
+	finalQuestion "part2 remotely copied by serv2 (mediatex.css too)?" \
+		      "cat ~serv2/md5sums/serv2-hello.md5 && echo -ne '\n'"
     else
 	topo "Cleanup"
 	mdtxP "del supp /usr/share/mediatex/misc/logoP2.iso" serv3
@@ -691,7 +717,7 @@ function test14()
 	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/logo
 	    reloadInitdScript $SERV
 	done
-	rm -fr /var/cache/mediatex/serv3/cache/serv3-hello/logo*
+	rm -fr ~serv3/cache/serv3-hello/*
 	reloadInitdScript serv3
     fi
 }
@@ -700,25 +726,25 @@ function test14()
 function test15()
 {
     if [ "x$1" != "xclean" ]; then
-	topo "Server 1 retrieve the archive and notify other it is no more looking for"
+	topo "Server 1 retrieve the archive"
  
 	mdtxP "srv notify" serv2
 	mdtxP "srv extract" serv1
 	mdtxP "srv save" serv1
 	question "does serv1 deliver logo.png (mail sent) ?" \
-		 "cat /var/cache/mediatex/serv1/md5sums/serv1-hello.md5"
+		 "cat ~serv1/md5sums/serv1-hello.md5 && echo -ne '\n'"
 	[ $TEST_OK -eq 0 ] && return
 	
 	mdtxP "srv notify" serv1
 	mdtxP "srv save" serv2
 	mdtxP "srv save" serv3
-	finalQuestion "does serv2 and serv3 are no more looking for logo.png ?" \
-		 "cat /var/cache/mediatex/serv2/md5sums/serv2-hello.md5 \
-                      /var/cache/mediatex/serv3/md5sums/serv3-hello.md5"
+	finalQuestion "does serv 2 and 3 no more looking for logo.png ?" \
+		 "cat ~serv2/md5sums/serv2-hello.md5 && echo -ne '\n' \
+                  && cat ~serv3/md5sums/serv3-hello.md5 && echo -ne '\n'" 
 	[ $TEST_OK -eq 0 ] && return
     else
 	topo "Cleanup"
-	rm -f /var/cache/mediatex/serv1/cache/serv1-hello/logo.png
+	rm -f ~serv1/cache/serv1-hello/logo.png
 	reloadInitdScript serv1
     fi
 }
@@ -733,7 +759,8 @@ function test16()
 	for SERV in serv1 serv2 serv3; do
 	    stopInitdScript $SERV
 	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/logo*
-	    rm -f /var/cache/mediatex/${SERV}/md5sums/${SERV}-hello.md5
+	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/supports
+	    rm -f /var/cache/mediatex/$SERV/md5sums/$SERV-hello.md5
 	    startInitdScript $SERV
 	done
 
@@ -743,22 +770,23 @@ function test16()
 
 	# same as test4
 	mdtxP "make" serv3
+	echo "!! please switch to server3 web site !!"
 	yourMail serv3
 	mdtxP "srv save" serv3
 	question "do the 3rd server get it ?" \
-	     "cat /var/cache/mediatex/serv3/md5sums/serv3-hello.md5"
+	     "cat ~serv3/md5sums/serv3-hello.md5 && echo -ne '\n'"
 	[ $TEST_OK -eq 0 ] && return
 
 	mdtxP "srv notify" serv3	
 	mdtxP "srv save" serv2
 	question "does 2nd server get your demand ?" \
-		      "cat /var/cache/mediatex/serv2/md5sums/serv2-hello.md5"
+		      "cat ~serv2/md5sums/serv2-hello.md5 && echo -ne '\n'"
 	[ $TEST_OK -eq 0 ] && return
 
 	mdtxP "srv notify" serv2	
 	mdtxP "srv save" serv1
-	finalQuestion "does 1st server get your demand (managed by serv2)?" \
-		      "cat /var/cache/mediatex/serv1/md5sums/serv1-hello.md5"
+	finalQuestion "does 1st server get your demand ?" \
+		      "cat ~serv1/md5sums/serv1-hello.md5 && echo -ne '\n'"
     else
 	topo "Cleanup"
     fi
@@ -769,22 +797,21 @@ function test16()
 function test17()
 {
     if [ "x$1" != "xclean" ]; then
-	topo "Server 3 provides second support and tell it to others"
+	topo "Server 1 provides first support and tell it to others"
 
 	mdtxP "motd" serv1
-	mdtxP "add supp iso1 to coll hello" serv1
 	mdtxP "check supp iso1 on /usr/share/mediatex/misc/logoP1.iso" serv1
 	mdtxP "srv notify" serv1
 
 	mdtxP "srv save" serv3
-	question "does 3rd server see iso1 on 1st server ?" \
-	    "cat /var/cache/mediatex/serv3/md5sums/serv3-hello.md5"
+	question "does 3rd server see part1 on 1st server ?" \
+	    "cat ~serv3/md5sums/serv3-hello.md5 && echo -ne '\n'"
 	[ $TEST_OK -eq 0 ] && return
 
 	mdtxP "srv extract" serv3
 	mdtxP "srv save" serv3
 	question "does serv3 deliver logo.png (mail sent) ?" \
-		 "cat /var/cache/mediatex/serv3/md5sums/serv3-hello.md5"
+		 "cat ~serv3/md5sums/serv3-hello.md5 && echo -ne '\n'"
 	[ $TEST_OK -eq 0 ] && return
 
 	mdtxP "srv notify" serv3
@@ -792,30 +819,69 @@ function test17()
 	mdtxP "srv save" serv1
 	mdtxP "srv save" serv2
 	mdtxP "srv save" serv3
-	finalQuestion "does serv1 and serv2 are no more looking for logo.png ?" \
-	    "cat /var/cache/mediatex/serv1/md5sums/serv1-hello.md5 \
-                 /var/cache/mediatex/serv2/md5sums/serv2-hello.md5 \
-                 /var/cache/mediatex/serv3/md5sums/serv3-hello.md5"
+	finalQuestion "does serv 1 and 2 no more looking for logo.png ?" \
+	    "cat ~serv1/md5sums/serv1-hello.md5 && echo -ne '\n' \
+             && cat ~serv2/md5sums/serv2-hello.md5 && echo -ne '\n' \
+             && cat ~serv3/md5sums/serv3-hello.md5 && echo -ne '\n'"
     else
 	topo "Cleanup"
-	mdtxP "del supp iso1 from coll hello" serv1
-	rm -fr /var/cache/mediatex/serv1/cache/serv1-hello/supports
-	reloadInitdScript serv1
-	stopInitdScript serv3
-	rm -f /var/cache/mediatex/serv3/cache/serv3-hello/logoP1.iso
-	rm -f /var/cache/mediatex/serv3/cache/serv3-hello/logoP1.cat
-	rm -f /var/cache/mediatex/serv3/cache/serv3-hello/logo.tgz
-	rm -fr /var/cache/mediatex/serv3/cache/serv3-hello/logo
-	rm -f /var/cache/mediatex/serv3/md5sums/serv3-hello.md5
-	startInitdScript serv3
+	for SERV in serv1 serv2 serv3; do
+	    stopInitdScript $SERV
+	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/logo*
+	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/supports
+	    startInitdScript $SERV
+	done
     fi	    
 }
 
-# Move CVS repository from serv1 to serv2
+
+# GIT backup on server 1
 function test18()
 {
     if [ "x$1" != "xclean" ]; then
-	topo "Move CVS repository from serv1 to serv2"
+	topo "GIT backup on server 1"
+
+	sedInPlace  "s/\(logGit\) *\(.*\)/\1 yes/" \
+		    ~serv1-hello/git/servers.txt
+	QUERY="/usr/share/mediatex/scripts/cron_monthly.sh"
+	query $QUERY serv1
+	export MDTX=serv1 
+	$QUERY
+	mdtxP "make" serv1
+
+	finalQuestion "does GITBARE is backuped ?"
+	[ $TEST_OK -eq 0 ] && return
+    else
+	topo "Cleanup"
+    fi
+}
+
+# Apache's logs backup on server 1
+function test19()
+{
+    if [ "x$1" != "xclean" ]; then
+	topo "Apache's logs backup on server 1"
+
+	sedInPlace "s/\(logApache\) *\(.*\)/\1 yes/" \
+		   ~serv1-hello/git/servers.txt
+	QUERY="/etc/logrotate.d/httpd-prerotate/mediatex_logrotate"
+	query $QUERY serv1
+	export MDTX=serv1 
+	$QUERY
+	mdtxP "make" serv1
+
+	finalQuestion "does Apache's logs are backuped ?"
+	[ $TEST_OK -eq 0 ] && return
+    else
+	topo "Cleanup"
+    fi
+}
+
+# Move GIT repository from serv1 to serv2
+function test20()
+{
+    if [ "x$1" != "xclean" ]; then
+	topo "Move GIT repository from serv1 to serv2"
 	if [ -d /var/lib/mediatex/serv1/serv1-hello ]; then
 	    cp -fr /var/lib/mediatex/serv1/serv1-hello /tmp/test15
 	    mv /var/lib/mediatex/serv1/serv1-hello \
@@ -823,22 +889,22 @@ function test18()
 	fi
 	
 	mdtxA "adm add coll hello" serv2
-	question "connected to serv2 cvsroot ?" \
-		 "cat /var/cache/mediatex/serv2/cvs/serv2-hello/CVS/Root"
+	question "connected to serv2 gitbare ?" \
+		 "grep url ~serv2/git/serv2-hello/.git/config"
 	[ $TEST_OK -eq 0 ] && return
 
 	notice "you will be ask for localhost fingerprint..." \
 	       "grep 'host fingerprint' /etc/mediatex/serv1.conf"
 	mdtxA "adm add coll serv2-hello" serv1
-	question "connected to serv2 cvsroot ?" \
-		 "cat /var/cache/mediatex/serv1/cvs/serv1-hello/CVS/Root"
+	question "connected to serv2 gitbare ?" \
+		 "grep url ~serv1/git/serv1-hello/.git/config"
 	[ $TEST_OK -eq 0 ] && return
 
 	notice "you will be ask for localhost fingerprint..." \
 	       "grep 'host fingerprint' /etc/mediatex/serv1.conf"
 	mdtxA "adm add coll serv2-hello" serv3
-	finalQuestion "connected to serv2 cvsroot ?" \
-		      "cat /var/cache/mediatex/serv3/cvs/serv3-hello/CVS/Root"
+	finalQuestion "connected to serv2 gitbare ?" \
+		      "grep url ~serv3/git/serv3-hello/.git/config"
 	[ $TEST_OK -eq 0 ] && return
 	
 	rm -fr /var/lib/mediatex/serv1/serv1-hello
@@ -852,28 +918,43 @@ function test18()
 }
 
 # Audit on server 1
-function test19()
+function test21()
 {
     if [ "x$1" != "xclean" ]; then
-	topo "Audit on server"
- 
+	topo "Audit on server 1"
+
+	sedInPlace "s/\(logAudit\) *\(.*\)/\1 yes/" \
+		   ~serv1-hello/git/servers.txt
 	read -p "Please enter your mail: " MAIL
 	mdtxP "audit coll hello for $MAIL" serv1
 	mdtxP "check supp iso1 on /usr/share/mediatex/misc/logoP1.iso"
+	mdtxP "serv save" serv1
+	cat ~serv1/md5sums/serv1-hello.md5 && echo -ne '\n'
+	mdtxP "serv notify" serv1
+	mdtxP "serv extract" serv3
+	mdtxP "serv notify" serv3
+	mdtxP "serv extract" serv2
+	mdtxP "serv notify" serv2
 	mdtxP "srv extract" serv1
+	mdtxP "make" serv1
 
 	finalQuestion "do you receive the audit repport ?"
 	[ $TEST_OK -eq 0 ] && return
     else
 	topo "Cleanup"
-	stopInitdScript
-	rm -f /var/cache/mediatex/serv1/md5sums/serv1-hello.md5
-	startInitdScript
+	for SERV in serv1 serv2 serv3; do
+	    stopInitdScript $SERV
+	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/supports*
+	    rm -fr /var/cache/mediatex/$SERV/cache/$SERV-hello/logo*
+	    rm -f /var/cache/mediatex/$SERV/md5sums/$SERV-hello.md5
+	    startInitdScript $SERV
+	done
+	rm -f ~serv1/tmp/serv1-hello/audit*.txt
     fi
 }
 
 # Make all functionnal for manuals tests
-function test20()
+function test22()
 {
     if [ "x$1" != "xclean" ]; then
 	topo "Make all functionnal for manuals tests"
@@ -881,6 +962,7 @@ function test20()
 	for SERV in serv1 serv2 serv3; do
 	    mdtxP "upgrade+" $SERV
 	done
+	mdtxP "serv notify" serv1
 	finalQuestion "All tests done ! Do you want to clean all ?"
 	[ $TEST_OK -eq 0 ] && return
 	cleanAll
@@ -901,7 +983,7 @@ function test20()
 }
 
 # check no hello users are logged
-ps -ef | grep h[e]llo
+ps -ef | grep h[e]llo | grep -v http
 [ $? -ne 1 ] && {
     echo "** Please logout hello users"
     who | grep hello
@@ -919,6 +1001,10 @@ TEST_OK=1
 TEST_NB=1
 [ -f /tmp/test.nb ] && TEST_NB=$(cat /tmp/test.nb)
 
+if [ $DEBUG_SERVER -ne 0 ]; then
+    xhost +
+fi
+
 # run tests
 while [ $TEST_OK -eq 1 ]; do
     echo $TEST_NB > /tmp/test.nb
@@ -931,3 +1017,6 @@ if [ $TEST_OK -eq 0 ]; then
     test$TEST_NB clean
 fi
 
+if [ $DEBUG_SERVER -ne 0 ]; then
+    xhost -
+fi
