@@ -1,14 +1,13 @@
 #!/bin/sh
 #set -x
 #=======================================================================
-# * Version: $Id: cron_daily.src,v 1.6 2015/10/08 21:43:50 nroche Exp $
 # * Project: MediaTex
 # * Module : scripts
 # *
 # * This script is call by cron
 #
 # MediaTex is an Electronic Records Management System
-# Copyright (C) 2014 2015 Nicolas Roche
+# Copyright (C) 2014 2015 2016 Nicolas Roche
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,7 +23,8 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #=======================================================================
 
-BINDIR=/usr/local/bin
+BINDIR=/usr/bin
+MDTX=${MDTX-mdtx}
 
-$BINDIR/mediatex -swarning -ffile make >/dev/null
-$BINDIR/mediatex -swarning -ffile motd >/usr/local/etc/motd
\ No newline at end of file
+$BINDIR/mediatex -c $MDTX -swarning -ffile make >/dev/null
+$BINDIR/mediatex -c $MDTX -swarning -ffile motd >/etc/motd
