@@ -1,14 +1,13 @@
 #!/bin/sh
 #set -x
 #=======================================================================
-# * Version: $Id: cron_hourly.src,v 1.5 2015/09/22 11:42:40 nroche Exp $
 # * Project: MediaTex
 # * Module : scripts
 # *
 # * This script is call by cron
 #
 # MediaTex is an Electronic Records Management System
-# Copyright (C) 2014 2015 Nicolas Roche
+# Copyright (C) 2014 2015 2016 Nicolas Roche
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,8 +23,9 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #=======================================================================
 
-BINDIR=/usr/local/bin
+BINDIR=/usr/bin
+MDTX=${MDTX-mdtx}
 
-$BINDIR/mediatex -swarning -ffile srv extract    
-$BINDIR/mediatex -swarning -ffile srv notify
+$BINDIR/mediatex -c $MDTX -swarning -ffile srv extract    
+$BINDIR/mediatex -c $MDTX -swarning -ffile srv notify
 
