@@ -2,14 +2,13 @@
 #set -x
 set -e
 #=======================================================================
-# * Version: $Id: free.sh,v 1.4 2015/06/30 17:37:21 nroche Exp $
 # * Project: MediaTex
 # * Module : script libs
 # *
 # * This script purge a MediaTex collection
 #
 # MediaTex is an Electronic Records Management System
-# Copyright (C) 2014 2015 Nicolas Roche
+# Copyright (C) 2014 2015 2016 Nicolas Roche
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -41,8 +40,8 @@ USERS_coll_remove_user $USER
 
 # do not purge the collection
 if [ -d $STATEDIR/$MDTX/$USER ]; then
-    Warning "note: do not purge $STATEDIR/$MDTX/$USER directory."
+    Notice "note: do not purge $STATEDIR/$MDTX/$USER directory."
     chown -R root.root $STATEDIR/$MDTX/$USER
 fi
 
-Info "done"
\ No newline at end of file
+Info "done"
