@@ -2,7 +2,6 @@
 #set -x
 set -e
 #=======================================================================
-# * Version: $Id: purge.sh,v 1.4 2015/06/30 17:37:22 nroche Exp $
 # * Project: MediaTex
 # * Module : script libs
 # *
@@ -10,7 +9,7 @@ set -e
 # * ... to be copy past into debian/postrm for purge
 #
 # MediaTex is an Electronic Records Management System
-# Copyright (C) 2014 2015 Nicolas Roche
+# Copyright (C) 2014 2015 2016 Nicolas Roche
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -56,11 +55,15 @@ done
 USERS_mdtx_remove_user
 USERS_root_disease
 
-/usr/sbin/a2disconf ${MEDIATEX#/}-$MDTX.conf
+if [ -f /etc/apache2/conf-enabled/${MEDIATEX#/}-$MDTX.conf ]; then
+    /usr/sbin/a2disconf ${MEDIATEX#/}-$MDTX.conf
+fi
 HTDOCS_unconfigure_mdtx_apache2
 
 Info "Please check if these apache modules we were using are still needed:"
-Info "* auth_digest autoindex env include rewrite userdir ssl"
-Info "done"
+Info "* authz_core auth_digest authz_groupfile autoindex cgi env *"
+Info "* include rewrite userdir setenvif ssl                     *"
 
-/usr/sbin/invoke-rc.d apache2 restart
\ No newline at end of file
+/usr/sbin/invoke-rc.d apache2 restart
+
+Info "done"
