@@ -1,12 +1,11 @@
 /*=======================================================================
- * Version: $Id: cgi.c,v 1.11 2015/10/11 01:03:54 nroche Exp $
  * Project: MediaTeX
  * Module : cgi script software
  *
  * Cgi script software's main function
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -144,7 +143,7 @@ int mdtxSearch(RecordTree* rTree, char* reply)
   if (!(coll = rTree->collection)) goto error;
   if (!(localhost = getLocalHost(coll))) goto error;
 
-  logMain(LOG_WARNING, "localhost: %s/%s", 
+  logMain(LOG_INFO, "cgi lunched on localhost: %s/%s", 
 	  localhost->host, localhost->fingerPrint);
 
   if ((sTree = coll->serverTree) == 0) goto error;
@@ -153,19 +152,20 @@ int mdtxSearch(RecordTree* rTree, char* reply)
   /* loop on every server */
   rgRewind(sTree->servers);
   while ((server = rgNext(sTree->servers))) {
-
-    logMain(LOG_WARNING, "server: %s/%s", 
-	    server->host, server->fingerPrint);
-
+    if (!isReachable(coll, localhost, server)) continue;
+					   
+    /*
     // skip server not directly connected to us
     if (!rgShareItems(localhost->networks, server->networks)) {
       logMain(LOG_INFO, "do not connect unreachable server %s:%i",
 	      server->host, server->mdtxPort);
       continue;
     }
-
+    */
     // query server
-    if (!server) break;
+    //if (!server) break;
+    logMain(LOG_INFO, "ask  %s/%s server for file",
+	    server->host, server->fingerPrint);
     if (!queryServer(server, rTree, reply)) goto error;
      
     if (env.dryRun) {
@@ -213,7 +213,7 @@ int mdtxFind(RecordTree *tree)
   logMain(LOG_DEBUG, "mdtxFind");
 
   if (!(coll = tree->collection)) goto error;
-  if (!(record = (Record*)tree->records->head->it)) goto error;
+  if (!(record = (Record*)tree->records->head->item)) goto error;
 
   // send query
   if (!mdtxSearch(tree, reply)) goto error;
@@ -233,7 +233,6 @@ int mdtxFind(RecordTree *tree)
     fprintf(stdout, "Content-Type: text/html\r\n");
     fprintf(stdout, "Refresh: 0; url=%s\r\n", url);
     fprintf(stdout, "\r\n");
-
     sendTemplate(coll, "cgiHeader.shtml");
     fprintf(stdout, "Please follow <a href=\"%s\"> link</a>!", url);
     sendTemplate(coll, "footer.html");
@@ -244,27 +243,23 @@ int mdtxFind(RecordTree *tree)
     
     fprintf(stdout, "Content-Type: text/html\r\n");
     fprintf(stdout, "\r\n");
-    
     sendTemplate(coll, "cgiHeader.shtml");
-
     fprintf(stdout, 
 	    "<br>Sorry, this document is not available yet.\r\n<br>");
     fprintf(stdout, "<h5><i>hash=%s\r\n</i><br>", record->archive->hash);
     fprintf(stdout, "<i>size=%llu\r\n</i><br></h5>",
 	    (unsigned long long int)record->archive->size);
-    
     fprintf(stdout, 
 	    "<br>Please provide a mail to process exctraction.\r\n<br>");
-    fprintf(stdout, "<FORM method=post action=\"%s\">\r\n", coll->cgiUrl);
-    fprintf(stdout, "<INPUT TYPE=HIDDEN NAME=hash VALUE=%s>", 
+    fprintf(stdout, "<FORM method=post action=\"%s/cgi/get.cgi\">\r\n",
+	    coll->localhost->url);
+    fprintf(stdout, "<INPUT TYPE=HIDDEN NAME=hash VALUE=%s>\n", 
 	    record->archive->hash);
-    fprintf(stdout, "<INPUT TYPE=HIDDEN NAME=size VALUE=%lli>", 
+    fprintf(stdout, "<INPUT TYPE=HIDDEN NAME=size VALUE=%lli>\n", 
 	    (long long int)record->archive->size);
-
-    fprintf(stdout, "Mail <INPUT type=text name=mail>");
-    fprintf(stdout, "<INPUT type=submit value=submit>");
+    fprintf(stdout, "Mail <INPUT type=text name=mail>\n");
+    fprintf(stdout, "<INPUT type=submit value=submit>\n");
     fprintf(stdout, "</FORM>\n");
-
     sendTemplate(coll, "footer.html");
   }
 
@@ -295,10 +290,13 @@ int mdtxRegister(RecordTree *tree)
   
   logMain(LOG_DEBUG, "mdtxRegister");
 
-  /* querying the local server */
   if (!(coll = tree->collection)) goto error;
-  if (!(record = (Record*)tree->records->head->it)) goto error;
+  if (!(record = (Record*)tree->records->head->item)) goto error;
   if (!(server = getLocalHost(coll))) goto error;
+
+  /* querying the local server */
+  logMain(LOG_INFO, "register final demand at %s/%s server",
+	  server->host, server->fingerPrint);
   if (!queryServer(server, tree, reply)) goto error;
   
   if (env.dryRun) {
@@ -320,16 +318,12 @@ int mdtxRegister(RecordTree *tree)
     fprintf(stdout, "%s", "Content-Type: text/html\r\n");
     fprintf(stdout, "%s", "Refresh: 3; url=../index/\r\n");
     fprintf(stdout, "%s", "\r\n");
-
     sendTemplate(coll, "cgiHeader.shtml");
-
     fprintf(stdout, "%s",
 	    "You will be notified by mail as soon as the file become "
 	    "available\n"
 	    "Please follow this <a href=\"../index\"> link</a>!");
-
     sendTemplate(coll, "footer.html");
-    
     break;
 
   default:
@@ -337,9 +331,7 @@ int mdtxRegister(RecordTree *tree)
     
     fprintf(stdout, "Content-Type: text/html\r\n");
     fprintf(stdout, "\r\n");
-    
     sendTemplate(coll, "cgiHeader.shtml");
-
     fprintf(stdout, 
 	    "<br>Sorry, localhost cannot register it (errno %i).\r\n<br>",
 	    status);
@@ -347,7 +339,6 @@ int mdtxRegister(RecordTree *tree)
     fprintf(stdout, "<i>size=%llu\r\n</i><br>",
 	    (unsigned long long int)record->archive->size);
     fprintf(stdout, "<i>mail=%s</i><br></h5>", record->extra);
-
     sendTemplate(coll, "footer.html");
   }
 
@@ -430,7 +421,11 @@ RecordTree* scanCgiQuery(Collection* coll)
   if (!(record = newRecord(coll->localhost, archive, DEMAND, extra))) 
     goto error;
   extra = 0;
-  if (!rgInsert(tree->records, record)) goto error;
+  if (!avl_insert(tree->records, record)) {
+    logMain(LOG_ERR, "cannot add record (already there?)");
+    goto error;
+  }
+  
   logMain(LOG_INFO, "querying for %s %i", 
 	  record->archive->hash, record->archive->size);
   record = 0;
@@ -532,8 +527,8 @@ char* getIndexLabel()
 
 
 /*=======================================================================
- * Function   : usage
- * Description: Print the usage.
+ * Function   : usageHtml
+ * Description: Send the usage.
  * Synopsis   : static void usage(char* programName)
  * Input      : char* programName = the name of the program; usually
  *                                  argv[0].
@@ -547,7 +542,7 @@ static void usageHtml(Collection* coll, char* programName)
   fprintf(stdout, "\r\n");
 
   sendTemplate(coll, "cgiHeader.shtml");
- 
+  
   fprintf(stdout, "<br>Internal error, sorry\r\n<br>");
   fprintf(stdout, "<h5><i>methode = %s\r\n<br>", getenv("REQUEST_METHOD"));
   fprintf(stdout, "query = %s\r\n<br>", getenv("QUERY_STRING"));
@@ -562,10 +557,37 @@ static void usageHtml(Collection* coll, char* programName)
 	  "\t\tSIZE   : the size of the requested file\r\n<br></h5></i>");
   
   sendTemplate(coll, "footer.html");
-  
   return;
 }
 
+
+/*=======================================================================
+ * Function   : iamAloneHtml
+ * Description: Send a specific error message
+ * Synopsis   : static void usage(char* programName)
+ * Input      : char* programName = the name of the program; usually
+ *                                  argv[0].
+ * Output     : N/A
+ =======================================================================*/
+static void iamAloneHtml(Collection* coll, char* programName)
+{
+  logMain(LOG_INFO, "no server is running");
+
+  fprintf(stdout, "Content-Type: text/html\r\n");
+  fprintf(stdout, "\r\n");
+
+  sendTemplate(coll, "cgiHeader.shtml");
+ 
+  fprintf(stdout, "<br>Server has gone, sorry\r\n<br>");
+  
+  fprintf(stdout, "<br>To launch server do:\r\n<br>");
+  fprintf(stdout, "<h5><i>/etc/init.d/mediatexd start</h5></i>");
+  
+  sendTemplate(coll, "footer.html");
+  return;
+}
+
+
 /*=======================================================================
  * Function   : usage
  * Description: Print the usage.
@@ -689,23 +711,26 @@ main(int argc, char** argv)
   
   // build record query from query parameters
   if ((tree = scanCgiQuery(coll)) == 0) goto htmlError;
-  if (!(record = (Record*)tree->records->head->it)) goto htmlError;
+  if (!(record = (Record*)tree->records->head->item)) goto htmlError;
   
   // relay query to daemon(s)
   if (isEmptyString(record->extra) || record->extra[0]=='!') {
     // first call: ask if servers have the record in cache
     if (!loadCollection(coll, SERV)) goto error;
-    if (!mdtxFind(tree)) goto error;
+    if (!mdtxFind(tree)) goto iamAloneHtmlError;
     if (!releaseCollection(coll, SERV)) goto error;
   }
   else {
     // second call: ask local server remind the provided mail
-    if (!mdtxRegister(tree)) goto error;
+    if (!mdtxRegister(tree)) goto iamAloneHtmlError;
   }
 
   rc = TRUE;
   /************************************************************************/
 
+ iamAloneHtmlError:
+  if (!rc) iamAloneHtml(coll, programName);
+  goto error;
  htmlError:
   if (!rc) usageHtml(coll, programName);
  error:
