@@ -1,12 +1,11 @@
 /*=======================================================================
- * Version: $Id: catalogHtml.c,v 1.10 2015/09/04 15:30:24 nroche Exp $
  * Project: MediaTeX
  * Module : catalogHtml
  *
  * HTML catalog serializer
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -132,7 +131,8 @@ int getCateListUri(char* buf, char* path, int cateId, int listId)
  * Synopsis   : static int htmlIndexArchive(FILE* fd, 
  *                                    Collection* coll, Archive* self)
  * Input      : FILE* fd = where to latexalize
- *              Archive* self = what to latexalize
+ *              Collection * coll: context
+ *              Archive* self: what to latexalize
  * Output     : TRUE on success
  =======================================================================*/
 static int 
@@ -141,7 +141,6 @@ htmlIndexArchive(FILE* fd, Collection* coll, Archive* self)
   int rc = FALSE;
   AssoCarac *assoCarac = 0;
   char url[512];
-  char score[8];
   char* path = "floppy-icon.png";
   RGIT* curr = 0;
 
@@ -152,7 +151,6 @@ htmlIndexArchive(FILE* fd, Collection* coll, Archive* self)
   if (!sprintf(url, 
 	       "../../../cgi/get.cgi?hash=%s&size=%lli", 
 	       self->hash, (long long int)self->size)) goto error;
-  if (!sprintf(score, "(%5.2f)", self->extractScore)) goto error;
 
   htmlLiOpen(fd);
 
@@ -167,7 +165,7 @@ htmlIndexArchive(FILE* fd, Collection* coll, Archive* self)
   htmlImage(fd, "../../../icons", path, url);
 
   getArchiveUri(url, "../../../score", self);
-  htmlLink(fd, 0, url, score);
+  htmlLink(fd, 0, url, getArchiveScore(self));
 
   /* latexalize caracs */
   if (!isEmptyRing(self->assoCaracs)) {
@@ -1222,8 +1220,10 @@ serializeHtmlMainIndex(Collection* coll)
   htmlBr(fd);
   htmlPClose(fd);
   
-  /* TODO: include user's text here */
-   
+  /* collection's readme page */
+  if (!fprintf(fd, "\n<!--#include virtual='../readme.html' -->\n"))
+    goto error;
+
   htmlSSIFooter(fd, "..");
 
   rc = TRUE;
@@ -1300,7 +1300,7 @@ serializeHtmlIndexHeader(Collection* coll)
   Role* role = 0;
   FILE* fd = stdout;
   char* path = 0;
-  char url[512];
+  char url[128];
 
   if (!(self = coll->catalogTree)) goto error;
 
@@ -1356,11 +1356,8 @@ serializeHtmlIndexHeader(Collection* coll)
     htmlPClose(fd);
   }
 
-  // master url (other are relatives ones)
-  if (!getServerUrl(coll->serverTree->master, "", url)) goto error;
-
   if (!htmlLeftPageTail(fd)) goto error;
-  if (!htmlRightHead(fd, url)) goto error;
+  if (!htmlRightHead(fd)) goto error;
   if (!env.dryRun) {
     fclose(fd);
   } else {
