@@ -1,12 +1,11 @@
 /*=======================================================================
- * Version: $Id: misc.c,v 1.14 2015/10/13 08:20:59 nroche Exp $
  * Project: MediaTeX
  * Module : misc
  *
  * Miscelanous client queries
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -459,7 +458,8 @@ mdtxSu(char* label)
   char* argv[] = {"/bin/bash", 0, 0};
   char* home = 0;
   char* user = 0;
-
+  LogSeverity* tmpSev =  env.logHandler->severity[LOG_SCRIPT];
+  
   logMain(LOG_DEBUG, "mdtxSu %s", label?label:"");
 
   // set the HOME directory environment variable
@@ -484,14 +484,15 @@ mdtxSu(char* label)
     if (setenv("HOME", home, 1) == -1) goto error;
     if (!allowedUser(user)) goto error;
     
-    // do not close stdout !
-    env.debugScript = TRUE;
+    // do not close stdout! else we loose id and groups.
+    env.logHandler->severity[LOG_SCRIPT] = LogSeverities+7;
     
     if (!execScript(argv, user, 0, FALSE)) goto error;
   }
 
+  env.logHandler->severity[LOG_SCRIPT] = tmpSev;
   rc = TRUE;
- error:  
+ error:
   if (!rc) {
     logMain(LOG_ERR, "mdtx su has failed");
   }
@@ -507,6 +508,8 @@ mdtxSu(char* label)
  *              char* source: relative path to remote source
  *              char* target: relative path to local destination
  * Output     : TRUE on success
+ * Note       : scp will fails it jail/etc/passwd do not provides
+ *              collection user.
  =======================================================================*/
 int 
 mdtxScp(char* label, char* fingerPrint, char* source, char* target)
@@ -520,7 +523,8 @@ mdtxScp(char* label, char* fingerPrint, char* source, char* target)
   checkLabel(fingerPrint);
   checkLabel(source);
   checkLabel(target);
-  logMain(LOG_DEBUG, "mdtxScp %s@%s on %s", source, fingerPrint, target);
+  logMain(LOG_DEBUG, "mdtxScp %s from %s on %s",
+	  source, fingerPrint, target);
 
   if (!(coll = mdtxGetCollection(label))) goto error;
   if (!loadCollection(coll, SERV)) goto error;
@@ -579,33 +583,34 @@ mdtxAudit(char* label, char* mail)
   int n = 0;
   char reply[255] = "100 nobody";
   int status = 0;
+  int uid = getuid();
 
   logMain(LOG_DEBUG, "audit %s collection for %s", label, mail);
   checkLabel(label);
   checkLabel(mail);
 
   if (!(conf = getConfiguration())) goto error;
-  if (!env.noRegression) {
-    // check if daemon is awake
-    if (access(conf->pidFile, R_OK) == -1) {
-      logMain(LOG_INFO, "cannot read daemon's pid file: %s", 
-	      strerror(errno));
-      goto end;
-    }
-  }
+  /* if (!env.noRegression) { */
+  /*   // check if daemon is awake */
+  /*   if (access(conf->pidFile, R_OK) == -1) { */
+  /*     logMain(LOG_INFO, "cannot read daemon's pid file: %s",  */
+  /* 	      strerror(errno)); */
+  /*     goto end; */
+  /*   } */
+  /* } */
 
   if (!becomeUser(env.confLabel, TRUE)) goto error;
-  if (!(coll = mdtxGetCollection(label))) goto error;
-  if (!(tree = createRecordTree())) goto error;
-  if (!getLocalHost(coll)) goto error;
+  if (!(coll = mdtxGetCollection(label))) goto error2;
+  if (!(tree = createRecordTree())) goto error2;
+  if (!getLocalHost(coll)) goto error2;
   tree->collection = coll;
   tree->messageType = CGI;
 
   // open audit file
-  if ((now = currentTime()) == -1) goto error;
+  if ((now = currentTime()) == -1) goto error2;
   if (localtime_r(&now, &date) == (struct tm*)0) {
     logMemory(LOG_ERR, "localtime_r returns on error");
-    goto error;
+    goto error2;
   }
  
   sprintf(path, "%s/%s%04i%02i%02i-%02i%02i%02i_%s.txt",
@@ -621,15 +626,15 @@ mdtxAudit(char* label, char* mail)
     if ((fd = fopen(path, "w")) == 0) {
       logMemory(LOG_ERR, "fopen %s fails: %s", path, strerror(errno));
       fd = stdout;
-      goto error;
+      goto error2;
     }
-    if (!lock(fileno(fd), F_WRLCK)) goto error;
+    if (!lock(fileno(fd), F_WRLCK)) goto error2;
   }
 
-  logMemory(LOG_INFO, "Serializing audit into: %s", 
-	    env.dryRun?"stdout":path);
+  logMain(LOG_INFO, "Serializing audit into: %s", 
+	  env.dryRun?"stdout":path);
 
-  if (!loadCollection(coll, EXTR)) goto error;
+  if (!loadCollection(coll, EXTR)) goto error2;
 
   fprintf(fd, "Audit on %s collection\n", coll->label);
   fprintf(fd, " requested on %04i-%02i-%02i %02i:%02i:%02i\n",
@@ -650,11 +655,14 @@ mdtxAudit(char* label, char* mail)
       
       // add a final demand
       strcpy(ptrMail, mail);
-      if (!(tmp = createString(extra))) goto error2; 
+      if (!(tmp = createString(extra))) goto error3; 
       if (!(record = newRecord(coll->localhost, archive, DEMAND, tmp))) 
-	goto error;
+	goto error3;
       tmp = 0;
-      if (!rgInsert(tree->records, record)) goto error2;
+      if (!avl_insert(tree->records, record)) {
+	logMain(LOG_ERR, "cannot add record to tree (already there?)");
+	goto error3;
+      }
       record = 0;
     }
   }
@@ -662,8 +670,8 @@ mdtxAudit(char* label, char* mail)
 
   // connect server and write query
   if (env.noRegression) goto end;
-  if ((socket = connectServer(coll->localhost)) == -1) goto error2;
-  if (!upgradeServer(socket, tree, 0)) goto error2;
+  if ((socket = connectServer(coll->localhost)) == -1) goto error3;
+  if (!upgradeServer(socket, tree, 0)) goto error3;
   
   // read reply
   if (env.dryRun) goto end;
@@ -677,11 +685,13 @@ mdtxAudit(char* label, char* mail)
   }
   
   logMain(LOG_INFO, "receive: %s", reply);
-  logMain(LOG_NOTICE, "please check motd and performe extraction", reply);
+  logMain(LOG_NOTICE, "please check motd and perform extraction", reply);
  end:
   rc = (env.noRegression || env.dryRun || status == 221);
+ error3:
+  if (!releaseCollection(coll, EXTR)) rc = FALSE;
  error2:
-  if (!releaseCollection(coll, EXTR)) goto error;
+  if (!logoutUser(uid)) rc = FALSE;
  error:
   if (fd != stdout) {
     if (!unLock(fileno(fd))) rc = FALSE;
