@@ -1,12 +1,11 @@
 /*=======================================================================
- * Version: $Id: motd.c,v 1.16 2015/10/12 23:28:51 nroche Exp $
  * Project: MediaTeX
  * Module : motd
  *
  * Manage message of the day
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -55,7 +54,7 @@ typedef struct MotdSearch {
   
 } MotdSearch;
 
-int motdArchive(MotdSearch* data, Archive* archive);
+int motdArchive(MotdSearch* data, Archive* archive, int depth);
 
 /*=======================================================================
  * Function   : destroyMotdSupport
@@ -296,7 +295,7 @@ updateMotdFromSupportDB(Motd* motd)
       if (!addMotdSupport(motd, support, 0)) goto error;
     }
   }
-  
+
   rc = TRUE;
  error:
   if (!rc) {
@@ -309,20 +308,23 @@ updateMotdFromSupportDB(Motd* motd)
 /*=======================================================================
  * Function   : motdContainer
  * Description: Find image related to a container
- * Synopsis   : int motdContainer
+ * Synopsis   : int motdContainer(MotdSearch* data, 
+ *                                Container* container, int depth)
  * Input      : Collection* coll = context
  *              Container* container = what to motd
+ *              int depth: use to indent logs
  * Output     : int *isAvailable = TRUE when image is already available
  *              FALSE on error
  =======================================================================*/
-int motdContainer(MotdSearch* data, Container* container)
+int motdContainer(MotdSearch* data, Container* container, int depth)
 {
   int rc = FALSE;
   Archive* archive = 0;
   RGIT* curr = 0;
 
-  logMain(LOG_DEBUG, "motd a container %s/%s:%lli", 
-	  strEType(container->type), container->parent->hash,
+  logMain(LOG_DEBUG, "%*slook for container %s/%s:%lli", 
+	  depth, "", strEType(container->type),
+	  container->parent->hash,
 	  (long long int)container->parent->size);
 
   data->isAvailable = FALSE;
@@ -332,14 +334,14 @@ int motdContainer(MotdSearch* data, Container* container)
 
   // we motd all parents (only one for TGZ, several for CAT...)
   while ((archive = rgNext_r(container->parents, &curr))) {
-    if (!motdArchive(data, archive)) goto error;
+    if (!motdArchive(data, archive, depth+1)) goto error;
   }
 
  end:
   rc = TRUE;
  error:
   if (!rc) {
-    logMain(LOG_ERR, "motdContainer fails");
+    logMain(LOG_ERR, "%*smotdContainer fails", depth, "");
   }
   return rc;
 } 
@@ -347,46 +349,66 @@ int motdContainer(MotdSearch* data, Container* container)
 /*=======================================================================
  * Function   : motdArchive
  * Description: Find image related to an archive
- * Synopsis   : int motdArchive
+ * Synopsis   : int motdArchive(MotdSearch* data, Archive* archive, 
+ *                              int depth)
  * Input      : Collection* coll = context
  *              Archive* archive = what to motd
+ *              int depth: use to indent logs
  * Output     : int *isAvailable = TRUE image is already available
  *              FALSE on error
  =======================================================================*/
-int motdArchive(MotdSearch* data, Archive* archive)
+int motdArchive(MotdSearch* data, Archive* archive, int depth)
 {
   int rc = FALSE;
+  Support *supp = 0;
   FromAsso* asso = 0;
   RGIT* curr = 0;
+  int nbSupportFiles = 0;
 
-  logMain(LOG_DEBUG, "motd an archive: %s:%lli", 
-	  archive->hash, archive->size);
-
-  data->isAvailable = FALSE;
+  logMain(LOG_DEBUG, "%*slook for archive: %s:%lli", 
+	  depth, "", archive->hash, archive->size);
   checkCollection(data->coll);
+  data->isAvailable = FALSE;
 
-  if (archive->state == AVAILABLE) {
+  if (archive->state >= AVAILABLE) {
+    logMain(LOG_DEBUG, "%*savailable from cache", depth, "");
     data->isAvailable = TRUE;
     goto end;
   }
 
   // look for a matching image 
   if (archive->images->nbItems > 0) {
-    logMain(LOG_DEBUG, "archive match %i images", archive->images->nbItems);
-    if (!rgInsert(data->imagesWanted, archive)) goto error;
+    logMain(LOG_INFO, "%*s%i images matched", depth, "",
+	    archive->images->nbItems);
+
+    // look for a matching support file without any matching support file
+    rgRewind(data->coll->supports);
+    while ((supp = rgNext(data->coll->supports))) {
+      if (supp->size != archive->size) continue;
+      if (strcmp(supp->fullMd5sum, archive->hash)) continue;
+      if (*supp->name != '/') continue;
+      ++nbSupportFiles;
+    }
+    if (nbSupportFiles) {
+      logMain(LOG_INFO, "%*s%i support files matched", depth, "",
+	      nbSupportFiles);
+    }
+    else {
+      if (!rgInsert(data->imagesWanted, archive)) goto error;	
+    }
   }
 
   // continue searching ; we stop at the first container already there
   while (!data->isAvailable && 
 	(asso = rgNext_r(archive->fromContainers, &curr))) {
-    if (!motdContainer(data, asso->container)) goto error;
+    if (!motdContainer(data, asso->container, depth+1)) goto error;
   }
 
  end:
   rc = TRUE;
  error:
   if (!rc) {
-    logMain(LOG_ERR, "motdArchive fails");
+    logMain(LOG_ERR, "%*smotdArchive fails", depth, "");
   }
   return rc;
 } 
@@ -408,7 +430,7 @@ updateMotdFromMd5sumsDB(Motd* motd, Collection* coll,
   int rc = FALSE;
   Archive* archive = 0;
   Support* support = 0;
-  RGIT* curr = 0;
+  AVLNode* node = 0;
   MotdSearch data;
   Image* image = 0;
 
@@ -419,13 +441,17 @@ updateMotdFromMd5sumsDB(Motd* motd, Collection* coll,
   if (!loadCollection(coll, SERV|EXTR|CACH)) goto error;
   if (!(data.imagesWanted = createRing())) goto error2;
   data.coll = coll;
+
+  logRecordTree(LOG_MAIN, LOG_DEBUG, coll->cacheTree->recordTree, 0);  
   
   // 1) for each cache entry
-  while ((archive = rgNext_r(coll->cacheTree->archives, &curr))) {
+  for (node = coll->cacheTree->archives->head; node; node = node->next) {
+    archive = node->item;
 
     // scan wanted archives not available
+    //  note: support files are loaded as final supplies by server
     if (archive->state != WANTED) continue;
-    if (!motdArchive(&data, archive)) goto error2;
+    if (!motdArchive(&data, archive, 0)) goto error2;
   }
   
   // for images, match supports
@@ -447,20 +473,16 @@ updateMotdFromMd5sumsDB(Motd* motd, Collection* coll,
   // 2) for each cache entry
   motdRecord->coll = coll;
   if (!computeExtractScore(coll)) goto error2;
-  curr = 0;
-  while ((archive = rgNext_r(coll->cacheTree->archives, &curr))) {
-
-    // looking for top containers as content cannot have worse score
-    if (!isEmptyRing(archive->fromContainers)) continue;
-
-    // looking for archive having a bad score
-    if (archive->extractScore > coll->serverTree->scoreParam.maxScore /2)
-      continue;      
+  for (node = coll->cacheTree->archives->head; node; node = node->next) {
+    archive = node->item;
     
     // looking for archive available into the cache
     if (archive->state < AVAILABLE) continue;
- 
-    // looking for archive that have a no local image...
+
+    // looking for bad top container
+    if (!isBadTopContainer(coll, archive)) continue;
+    
+    // looking for archive that have no local image...
     if ((image = getImage(coll, coll->localhost, archive)) &&
 	// ...or a local bad score
 	image->score > coll->serverTree->scoreParam.maxScore / 2)
@@ -511,8 +533,6 @@ updateMotdFromAllMd5sumsDB(Motd* motd)
   rgRewind(conf->collections);
   while ((coll = rgNext(conf->collections))) {
 
-    logRecordTree(LOG_MAIN, LOG_DEBUG, coll->cacheTree->recordTree, 0);
-    
     // assert we have the localhost server object
     if (!getLocalHost(coll)) goto error;
     
@@ -551,6 +571,7 @@ updateMotd()
   MotdRecord* motdRec = 0;
   Record* record = 0;
   char car = ':';
+  int isFileToBurn = 0;
 
   logMain(LOG_DEBUG, "updateMotd");
 
@@ -575,37 +596,53 @@ updateMotd()
   printf("%s\n", "*****************************");
 
   // supports to ask for
-  if (!rgSort(motd->motdSupports, cmpMotdSupport)) goto error2;
-  printf("Please provide theses local supports:\n");
-  while ((motdSupp = rgNext(motd->motdSupports))) {
-    printf("- %s", motdSupp->support->name);
-    car = ':';
-    if (motdSupp->ask4periodicCheck) {
-      printf("%c %s", car, "periodic check");
-      car = ',';
-    }
-    if (motdSupp->collections) {
-      rgRewind(motdSupp->collections);
-      while ((coll = rgNext(motdSupp->collections))) {
-	printf("%c %s", car, coll->label);
+  if (!isEmptyRing(motd->motdSupports)) {
+    printf("Please provide theses local supports:\n");
+    if (!rgSort(motd->motdSupports, cmpMotdSupport)) goto error2;
+    while ((motdSupp = rgNext(motd->motdSupports))) {
+      printf("- %s", motdSupp->support->name);
+      car = ':';
+      if (motdSupp->ask4periodicCheck) {
+	printf("%c %s", car, "periodic check");
 	car = ',';
       }
+      if (motdSupp->collections) {
+	rgRewind(motdSupp->collections);
+	while ((coll = rgNext(motdSupp->collections))) {
+	  printf("%c %s", car, coll->label);
+	  car = ',';
+	}
+      }
+      printf("%s", "\n");
     }
-    printf("%s", "\n");
   }
-
+  
   // records to burn
-  printf("Please burn theses files:\n"); 
   while ((motdRec = rgNext(motd->motdRecords))) {
-    if (isEmptyRing(motdRec->records)) continue;
-    printf("- Collection %s:\n", motdRec->coll->label); 
-    rgRewind(motdRec->records);
-    while ((record = rgNext(motdRec->records))) {
-      printf(" - %s/%s (%5.2f)\n", motdRec->coll->cacheDir,
-	     record->extra, record->archive->extractScore); 
+      if (isEmptyRing(motdRec->records)) continue;
+      isFileToBurn++;
+  }
+  rgRewind(motd->motdRecords);
+  if (isFileToBurn) {
+    printf("Please burn theses files:\n"); 
+    while ((motdRec = rgNext(motd->motdRecords))) {
+      if (isEmptyRing(motdRec->records)) continue;
+      rgSort(motdRec->records, cmpRecordPath);
+      printf("- Collection %s:\n", motdRec->coll->label); 
+      rgRewind(motdRec->records);
+      while ((record = rgNext(motdRec->records))) {
+	printf(" - %s/%s (%5.2f)\n", motdRec->coll->cacheDir,
+	       record->extra, record->archive->extractScore); 
+      }
     }
   }
 
+  // nothing to do
+  if (isEmptyRing(motd->motdSupports) && !isFileToBurn) {
+    printf("nothing to do\n");
+  }
+
+  printf("\n");
   rc = TRUE;
  error2:
   if (!loadConfiguration(CFG|SUPP)) rc = FALSE;
