@@ -1,12 +1,11 @@
 /*=======================================================================
- * Version: $Id: supp.c,v 1.19 2015/09/17 18:53:46 nroche Exp $
  * Project: MediaTeX
  * Module : supp
  *
  * Manage local supports
 
   MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -154,7 +153,7 @@ mdtxLsSupport()
 
   logMain(LOG_DEBUG, "mdtxLsSupport");
   if (!(conf = getConfiguration())) goto error;
-  if (!loadConfiguration(CFG | SUPP)) goto error;
+  if (!loadConfiguration(CFG|SUPP)) goto error;
   supports = conf->supports;
 
   rgRewind(supports);
@@ -320,7 +319,10 @@ addFinalSupplies(Collection* coll, Support* supp, char* path,
   if (!(record = addRecord(coll, coll->localhost, archive, SUPPLY, extra)))
     goto error;
   extra = 0;
-  if (!rgInsert(tree->records, record)) goto error;
+  if (!avl_insert(tree->records, record)) {
+    logMain(LOG_ERR, "cannot add record to tree (already there?)");
+    goto error;
+  }
 
   rc = TRUE;
  error:
@@ -332,35 +334,6 @@ addFinalSupplies(Collection* coll, Support* supp, char* path,
   return rc;
 }
 
-/*=======================================================================
- * Function   : delFinalSupplies
- * Description: empty the record tree used to talk to server
- * Synopsis   : static int delFinalSupplies(Collection* coll, 
- *                                                     RecordTree* tree)
- * Input      : Collection* coll
- *              RecordTree* tree: the record tree to empty
- * Output     : TRUE on success
- =======================================================================*/
-static int delFinalSupplies(Collection* coll, RecordTree* tree)
-{
-  int rc = FALSE;
-  Record* record = 0;
-
- logMain(LOG_DEBUG, "delFinalSupplies");
-
-  while ((record = rgHead(tree->records))) {
-    if (!delRecord(coll, record)) goto error;
-    rgRemove(tree->records);
-  }
-
-  rc = TRUE;
- error:
-  if (!rc) {
-    logMain(LOG_ERR, "delFinalSupplies fails");
-  }
-  return rc;
-}
-
 /*=======================================================================
  * Function   : notifyHave
  * Description: Tell the local server we have a support for him
@@ -425,8 +398,8 @@ notifyHave(Support* supp, char* path)
     
     // wait until server shut down the sockect
     if (!env.dryRun) tcpRead(socket, reply, 1);
-    
-    if (!delFinalSupplies(coll, tree)) goto error;
+
+    if (!diseaseRecordTree(tree)) goto error;
   }
   
   if (!isShared) {
