@@ -1,12 +1,11 @@
 /*=======================================================================
- * Version: $Id: openClose.c,v 1.18 2015/10/12 23:28:51 nroche Exp $
  * Project: MediaTeX
  * Module : openClose
  
  * Manage meta-data files
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -30,35 +29,42 @@ static char* CollFiles[] = {
 };
 
 /*=======================================================================
- * Function   : callUpdate
- * Description: call update.sh
- * Synopsis   : int callUpdate(char* user)
- * Input      : char* user: the collection module to update
+ * Function   : callUpgrade
+ * Description: call upgrade.sh
+ * Synopsis   : int callUpgrade(char* user, 
+ *                              char* signature1, char* signature2)
+ * Input      : char* label: the collection module to commit
+ *              char* fingerprint: the commit's author fingerprint
+ *              char* url: remote origin url (if provided)
  * Output     : TRUE on success
  =======================================================================*/
 int 
-callUpdate(char* user)
+callUpgrade(char* user, char* fingerprint, char* url)
 { 
-  int rc = FALSE;
+  int rc = FALSE;  
   Configuration* conf = 0;
-  char *argv[] = {0, 0, 0};
+  char *argv[] = {0, 0, 0, 0, 0, 0};
 
   checkLabel(user);
-  logCommon(LOG_INFO, "callUpdate %s", user);
+  logCommon(LOG_INFO, "callUpgrade %s: fp=%s url=%s",
+	    user, fingerprint?fingerprint:"?", url?url:"");
 
   if (!(conf = getConfiguration())) goto error;
   if (!(argv[0] = createString(conf->scriptsDir))) goto error;
-  if (!(argv[0] = catString(argv[0], "/update.sh"))) goto error;
+  if (!(argv[0] = catString(argv[0], "/upgrade.sh"))) goto error;
   argv[1] = user;
-
-  if (!env.noRegression && !env.dryRun && !env.noCollCvs) {
+  argv[2] = conf->host;
+  argv[3] = *fingerprint?fingerprint:"?";
+  argv[4] = url;
+  
+  if (!env.noRegression && !env.dryRun && !env.noGit) {
     if (!execScript(argv, user, 0, FALSE)) goto error;
   }
 
   rc = TRUE;
  error:  
   if (!rc) {
-    logCommon(LOG_WARNING, "callUpdate fails");
+    logCommon(LOG_WARNING, "callUpgrade fails");
   }
   argv[0] = destroyString(argv[0]);
   return(rc);
@@ -67,31 +73,30 @@ callUpdate(char* user)
 /*=======================================================================
  * Function   : callCommit
  * Description: call commit.sh
- * Synopsis   : int callCommit(char* user, char* signature)
+ * Synopsis   : int callCommit(char* user, char* comment)
  * Input      : char* label: the collection module to commit
- *              char* signature1: the commit's author fingerprint
- *              char* signature2: the commit's author hostname
+ *              char* comment: to overhide command line as comment
  * Output     : TRUE on success
  =======================================================================*/
 int 
-callCommit(char* user, char* signature1, char* signature2)
+callCommit(char* user, char* comment)
 { 
   int rc = FALSE;  
   Configuration* conf = 0;
-  char *argv[] = {0, 0, 0, 0, 0, 0};
+  char *argv[] = {0, 0, 0, 0};
 
   checkLabel(user);
-  logCommon(LOG_INFO, "callCommit %s: %s", user, env.commandLine);
+  env.commandLine[strlen(env.commandLine)-1] = 0; // \n -> \0
+  logCommon(LOG_INFO, "callCommit %s: %s", user,
+	    comment?comment:env.commandLine);
 
   if (!(conf = getConfiguration())) goto error;
   if (!(argv[0] = createString(conf->scriptsDir))) goto error;
   if (!(argv[0] = catString(argv[0], "/commit.sh"))) goto error;
   argv[1] = user;
-  argv[2] = env.commandLine;
-  argv[3] = signature1;
-  argv[4] = signature2;
+  argv[2] = comment?comment:env.commandLine;
   
-  if (!env.noRegression && !env.dryRun && !env.noCollCvs) {
+  if (!env.noRegression && !env.dryRun && !env.noGit) {
     if (!execScript(argv, user, 0, FALSE)) goto error;
   }
 
@@ -101,6 +106,77 @@ callCommit(char* user, char* signature1, char* signature2)
     logCommon(LOG_WARNING, "callCommit fails");
   }
   argv[0] = destroyString(argv[0]);
+  env.commandLine[strlen(env.commandLine)] = '\n';
+  return(rc);
+}
+
+/*=======================================================================
+ * Function   : callPull
+ * Description: call pull.sh
+ * Synopsis   : int callPull(char* user)
+ * Input      : char* user: the collection module to pull
+ * Output     : TRUE on success
+ =======================================================================*/
+int 
+callPull(char* user)
+{ 
+  int rc = FALSE;
+  Configuration* conf = 0;
+  char *argv[] = {0, 0, 0};
+
+  checkLabel(user);
+  logCommon(LOG_INFO, "callPull %s", user);
+
+  if (!(conf = getConfiguration())) goto error;
+  if (!(argv[0] = createString(conf->scriptsDir))) goto error;
+  if (!(argv[0] = catString(argv[0], "/pull.sh"))) goto error;
+  argv[1] = user;
+
+  if (!env.noRegression && !env.dryRun && !env.noGitPullPush) {
+    if (!execScript(argv, user, 0, FALSE)) goto error;
+  }
+
+  rc = TRUE;
+ error:  
+  if (!rc) {
+    logCommon(LOG_WARNING, "callPull fails");
+  }
+  argv[0] = destroyString(argv[0]);
+  return(rc);
+}
+
+/*=======================================================================
+ * Function   : callPush
+ * Description: call push.sh
+ * Synopsis   : int callPush(char* user)
+ * Input      : char* label: the collection module to commit
+ * Output     : TRUE on success
+ =======================================================================*/
+int 
+callPush(char* user)
+{ 
+  int rc = FALSE;  
+  Configuration* conf = 0;
+  char *argv[] = {0, 0, 0};
+
+  checkLabel(user);
+  logCommon(LOG_INFO, "callPush %s", user);
+
+  if (!(conf = getConfiguration())) goto error;
+  if (!(argv[0] = createString(conf->scriptsDir))) goto error;
+  if (!(argv[0] = catString(argv[0], "/push.sh"))) goto error;
+  argv[1] = user;
+  
+  if (!env.noRegression && !env.dryRun && !env.noGitPullPush) {
+    if (!execScript(argv, user, 0, FALSE)) goto error;
+  }
+
+  rc = TRUE;
+ error:  
+  if (!rc) {
+    logCommon(LOG_WARNING, "callPush fails");
+  }
+  argv[0] = destroyString(argv[0]);
   return(rc);
 }
 
@@ -123,6 +199,11 @@ int loadConfiguration(int confFiles)
   }
   if (!(conf = getConfiguration())) goto error;
 
+  if (!env.noGit) {
+    if (!callCommit(env.confLabel, "manual user edition")) goto error;
+    if (!env.noGitPullPush) callPull(env.confLabel);
+  }
+  
   if ((confFiles & CFG) && conf->fileState[iCFG] == DISEASED) {
     if (!parseConfiguration(conf->confFile)) goto error;
     conf->fileState[iCFG] = LOADED;
@@ -154,8 +235,8 @@ int loadRecords(Collection* coll)
   int rc = FALSE;
   int fd = -1;
   RecordTree* tree = 0;
-  RGIT* curr = 0;
   Record* record = 0;
+  AVLNode* node = 0;
   
   checkCollection(coll);
   logCommon(LOG_DEBUG, "load %s records", coll->label);
@@ -192,10 +273,9 @@ int loadRecords(Collection* coll)
   destroyRecordTree(coll->cacheTree->recordTree);
   coll->cacheTree->recordTree = tree;
   coll->cacheTree->recordTree->messageType = DISK;
-  curr = 0;
-
-  while ((record = rgNext_r(coll->cacheTree->recordTree->records, &curr)) 
-	!= 0) {
+  for (node = coll->cacheTree->recordTree->records->head;
+       node; node = node->next) {
+    record = node->item;
     if (!addCacheEntry(coll, record)) goto error;
   }
    
@@ -240,7 +320,9 @@ collectionLoop(Collection* coll, int collFiles,
   logCommon(LOG_DEBUG, "file loop on %s collection (%s)", 
 	  coll->label, strCF(collFiles));
 
-  // cache need computeExtractScore so cache must be disease first
+  // reverse order:
+  // - cache need computeExtractScore so cache must be disease first.
+  // - catalog get archives so they need to be added first by extract.
   for (i=iCACH; i>=iCTLG; --i) {
     if (collFiles & (1<<i)) {
       if (!callback(coll, i)) goto error;
@@ -307,7 +389,7 @@ loadCvsFiles(Collection* coll, int fileIdx)
     i=1;
 
     // cgi and server only read the meta-data
-    if (!env.noCollCvs) {
+    if (!env.noGit) {
       // force re-serialize and commit to eat NNN.txt
       coll->fileState[fileIdx] = MODIFIED;
     }
@@ -363,10 +445,11 @@ loadColl(Collection* coll, int fileIdx)
       coll->fileState[iSERV] = LOADED;
 
       // cgi and server only read the meta-data
-      if (!env.noCollCvs) {
+      if (!env.noGit) {
 	if (!upgradeCollection(coll)) goto error2;
 	coll->fileState[iSERV] = MODIFIED;
       }
+      if (!computeUrls(coll)) goto error2;
 
       break;
     case iCACH:
@@ -491,9 +574,12 @@ loadCollection(Collection* coll, int collFiles)
 
   if (!expandCollection(coll)) goto error;
 
-  if (!env.noCollCvs) {
-    if (coll->toUpdate && collFiles & (CTLG | EXTR | SERV)) {
-      if (callUpdate(coll->user)) coll->toUpdate = FALSE;
+  if (!env.noGit) {
+    if (!callCommit(coll->user, "manual user edition")) goto error;
+    if (!env.noGitPullPush) {
+      if (coll->toUpdate && collFiles & (CTLG | EXTR | SERV)) {
+	if (callPull(coll->user)) coll->toUpdate = FALSE;
+      }
     }
   }
 
@@ -692,8 +778,12 @@ saveConfiguration()
   }
 
   // commit changes
-  if (change && !env.noCollCvs) {
-    callCommit(env.confLabel, conf->hostFingerPrint, conf->host);
+  if (change && !env.noGit) {
+    if (!callUpgrade(env.confLabel, conf->hostFingerPrint, 0)) goto error;
+    if (!callCommit(env.confLabel, 0)) goto error;
+    if (!env.noGitPullPush) {
+	callPush(env.confLabel);
+    }
   }
 
   rc = TRUE;
@@ -757,12 +847,13 @@ saveColl(Collection* coll, int i)
     coll->fileState[i] = LOADED;
   }
   else {
-    logCommon(LOG_DEBUG, "do not save collection as...");
+    logCommon(LOG_INFO, "do not save %s collection (%s)",
+	      coll->label, strCF(1<<i));
     if (coll->fileState[i] != MODIFIED) {
-      logCommon(LOG_DEBUG, "... not modified");
+      logCommon(LOG_DEBUG, "... as not modified");
     }
     if (coll->cptInUse[i]) {
-      logCommon(LOG_DEBUG, "... still used by %i functions", 
+      logCommon(LOG_DEBUG, "... as still used by %i functions", 
 	      coll->cptInUse[i]);
     }
   }
@@ -857,11 +948,14 @@ saveCollection(Collection* coll, int collFiles)
 	    env.progBar.cur, env.progBar.max);
 
   // commit changes
-  if (coll->toCommit && !env.noCollCvs) {
-    if (callCommit(coll->user, coll->userFingerPrint, conf->host)) {
-      conf->toHup = TRUE;
-      coll->toCommit = FALSE;
-      coll->toUpdate = TRUE;
+  if (coll->toCommit && !env.noGit) {
+    if (!callCommit(coll->user, 0)) goto error;
+    if (!env.noGitPullPush) {
+      if (callPush(coll->user)) {
+	conf->toHup = TRUE;
+	coll->toCommit = FALSE;
+	coll->toUpdate = TRUE;
+      }
     }
   }
 
@@ -895,7 +989,7 @@ clientSaveAll()
     if (!saveCollection(coll, CTLG|EXTR|SERV)) goto error;
   }
 
-  if (!saveConfiguration(env.commandLine)) goto error;
+  if (!saveConfiguration()) goto error;
 
   // tell the server we have upgrade files
   if (!env.noRegression && !env.dryRun && conf->toHup) {
@@ -984,6 +1078,17 @@ diseaseColl(Collection* coll, int i)
     }
     coll->fileState[i] = DISEASED;
   }
+  else {
+    logCommon(LOG_INFO, "do not disease %s collection (%s)",
+	      coll->label, strCF(1<<i));
+    if (coll->fileState[i] != LOADED) {
+      logCommon(LOG_DEBUG, "... as not loaded");
+    }
+    if (coll->cptInUse[i]) {
+      logCommon(LOG_DEBUG, "... as still used by %i functions", 
+	      coll->cptInUse[i]);
+    }
+  }
 
   rc = TRUE; 
  error2:
@@ -1045,7 +1150,8 @@ clientDiseaseAll()
   logCommon(LOG_DEBUG, "clientDiseaseAll");
   if (!(conf = env.confTree)) goto error; // do not malloc
 
-  if ((coll = rgNext_r(conf->collections, &curr))) {
+  while ((coll = rgNext_r(conf->collections, &curr))) {
+    if (!(coll->memoryState & EXPANDED)) continue;
     if (!saveCollection(coll, CTLG|EXTR|SERV)) goto error;
     if (!diseaseCollection(coll, CTLG|EXTR|SERV|CACH)) goto error;
   }
@@ -1075,7 +1181,8 @@ int serverDiseaseAll()
   logCommon(LOG_DEBUG, "serverDiseaseAll");
   if (!(conf = env.confTree)) goto error; // do not malloc
 
-  if ((coll = rgNext_r(conf->collections, &curr))) {
+  while ((coll = rgNext_r(conf->collections, &curr))) {
+    if (!(coll->memoryState & EXPANDED)) continue;
     if (!saveCollection(coll, CACH)) goto error;
     if (!diseaseCollection(coll, CTLG|EXTR|SERV|CACH)) goto error;
   }
@@ -1106,7 +1213,7 @@ Collection* mdtxGetCollection(char* label)
   if (!loadConfiguration(CFG)) goto error;
   if (!(coll = getCollection(label))) goto error;
   if (!expandCollection(coll)) goto error;
-
+    
   rc = coll;
  error:
   if (!rc) {
@@ -1137,7 +1244,8 @@ Support* mdtxGetSupport(char* label)
   rc = supp;
  error:
   if (!rc) {
-    logCommon(LOG_ERR, "fails to get support");
+    logCommon(LOG_ERR, "support '%s' not found (into '%s')", 
+	      label, getConfiguration()->supportDB);
   }
   return rc;
 }
