@@ -1,12 +1,11 @@
 /*=======================================================================
- * Version: $Id: openClose.h,v 1.4 2015/06/30 17:37:27 nroche Exp $
  * Project: MediaTeX
  * Module : openClose
  
  * Manage medta-data files
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -27,8 +26,10 @@
 
 #include "mediatex-types.h"
 
-int callUpdate(char* user);
-int callCommit(char* user, char* signature1, char* signature2);
+int callUpgrade(char* user, char* fingerprint, char* url);
+int callCommit(char* user, char* comment);
+int callPull(char* user);
+int callPush(char* user);
 
 int loadConfiguration(int confFiles); // logical OR on confFiles
 int loadRecords(Collection* coll);
