@@ -1,12 +1,11 @@
 /*=======================================================================
- * Version: $Id: register.c,v 1.6 2015/08/13 21:14:33 nroche Exp $
  * Project: MediaTeX
  * Module : bus/register
  
  * Manage signals from client to server using registers
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -172,13 +171,13 @@ mdtxAsyncSignal(int signal)
   // retrieve daemon's pid
   if (!(conf = getConfiguration())) goto error;
   if ((fd = fopen(conf->pidFile, "r")) == 0) {
-    logCommon(LOG_INFO, "open %s failed: %s", 
+    logCommon(LOG_INFO, "fails to open %s: %s", 
 	    conf->pidFile, strerror(errno));
     goto error;
   }
 
   if (fscanf(fd, "%i", &pid) != 1) {
-    logCommon(LOG_INFO, "cannot retrieve pid from %s", conf->pidFile);
+    logCommon(LOG_INFO, "fails to read pid from %s", conf->pidFile);
     goto error;
   }
   if (fclose(fd)) {
