@@ -1,5 +1,4 @@
 /*=======================================================================
- * Version: $Id: mediatex.h,v 1.8 2015/08/10 12:24:27 nroche Exp $
  * Project: MediaTex
  * Module : headers
  *
@@ -7,7 +6,7 @@
  * It should be included by final user.
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -83,6 +82,8 @@ extern RecordTree* parseRecords(int fd);
 typedef struct MdtxEnv {
 
   // loggin
+  int nbVerbose;
+  char v[32], vv[32], vvv[32];
   int logFacility;
   char *logFile;
   int logSeverity[LOG_MAX_MODULE];
@@ -97,11 +98,11 @@ typedef struct MdtxEnv {
   char* confLabel;
   int dryRun;        // output to stdout (set by unit tests by default)
   int noRegression;  // fixed dates and no sig to server (unit tests only)
-  int noCollCvs;     // do not call cvs loading/saving collections
-  int cvsprintMax;   // maximum size for files handle by CVS
+  int noGit;         // do not use git (cgi and server)
+  int noGitPullPush; // no pull/push (no network) but still do commits
+  int cvsprintMax;   // maximum size for files handle by GIT
 
   // debug options
-  int debugScript;
   int debugLexer;
 
   // global data structures:
@@ -109,6 +110,7 @@ typedef struct MdtxEnv {
   int running;
   char commandLine[512];
   MdtxProgBar progBar;
+  int background;
 
 } MdtxEnv;
 
@@ -121,16 +123,16 @@ extern MdtxEnv envUnitTest; // only used for copy
 #define GLOBAL_MDTX_ENV_UT						\
   {									\
     /* logging */							\
-    99,	0,								\
+    0, "info", "debug:main,script", "debug:memory,misc", 99, 0,		\
       {LOG_INFO, LOG_INFO, LOG_INFO, LOG_INFO,				\
 	  LOG_INFO, LOG_INFO, LOG_INFO},				\
       0,								\
 	/* allocating */						\
 	0, (int (*)(long))0, 0,						\
 	/* configuration */						\
-	DEFAULT_MDTXUSER "1", TRUE, TRUE, TRUE, 500*KILO,		\
+	DEFAULT_MDTXUSER "1", TRUE, TRUE, TRUE, TRUE, 500*KILO,		\
 	/* debug */							\
-	FALSE, FALSE,							\
+	FALSE,								\
 	/* global data structure */					\
 	0, TRUE								\
 	}
@@ -140,23 +142,20 @@ extern MdtxEnv envUnitTest; // only used for copy
 #define GLOBAL_MDTX_ENV_BIN						\
   {									\
     /* logging */							\
-    99, 0,								\
+    0, "info", "debug:main,script", "debug:memory,misc", 99, 0,		\
       {	LOG_NOTICE, LOG_NOTICE, LOG_NOTICE, LOG_NOTICE,			\
 	  LOG_NOTICE, LOG_NOTICE, LOG_NOTICE},				\
       0,								\
 	/* allocating */						\
 	128, (int (*)(long))0, 0,					\
 	/* configration */						\
-	DEFAULT_MDTXUSER, FALSE, FALSE, TRUE, 500*KILO,			\
-	/* debug and tests */						\
-	FALSE, FALSE,							\
+	DEFAULT_MDTXUSER, FALSE, FALSE, TRUE, TRUE, 500*KILO,		\
+	/* debug */							\
+	FALSE,								\
 	/* global data structure */					\
 	0, TRUE								\
 	}
 
-/* #define GLOBAL_STRUCT_DEF MdtxEnv env =	GLOBAL_MDTX_STRUCT_UT */
-/* #define GLOBAL_STRUCT_DEF_BIN MdtxEnv env = GLOBAL_MDTX_STRUCT_BIN */
-
 #endif /* MDTX_H */
 
 /* Local Variables: */
