@@ -1,12 +1,11 @@
 /*=======================================================================
- * Version: $Id: archive.h,v 1.13 2015/09/23 19:10:20 nroche Exp $
  * Project: MediaTeX
  * Module : archive tree
  *
  * Archive producer interface
 
  MediaTex is an Electronic Archives Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -73,7 +72,8 @@ struct Archive
 /* API */
 char* strAState(AState state);
 int cmpArchive(const void *p1, const void *p2);
-int cmpArchive2(const void *p1, const void *p2);
+int cmpArchiveAvl(const void *p1, const void *p2);
+int cmpArchiveCacheAvl(const void *p1, const void *p2);
 int cmpArchiveSize(const void *p1, const void *p2);
 int cmpArchiveScore(const void *p1, const void *p2);
 Archive* getArchive(Collection* coll, char* hash, off_t size);
@@ -86,6 +86,7 @@ Archive* destroyArchive(Archive* self);
 int diseaseArchive(Collection* coll, Archive* arch);
 int diseaseArchives(Collection* coll);
 int isIncoming(Collection* coll, Archive* self);
+int isBadTopContainer(Collection* coll, Archive* archive);
 int hasExtractRule(Archive* self);
 
 #endif /* MDTX_MEMORY_ARCHIVE_H */
