@@ -1,12 +1,11 @@
 /*=======================================================================
- * Version: $Id: cacheTree.h,v 1.10 2015/10/04 22:15:50 nroche Exp $
  * Project: MediaTeX
  * Module : cache memory
  *
  * Manage local cache directory
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -75,7 +74,7 @@ struct CacheTree
 
   // Archive* that define at less 1 Record
   // use by cache.c::freeCache
-  RG* archives; // Archive*
+  AVLTree* archives; // Archive*
 };
 
 CacheTree* createCacheTree(void);
