@@ -1,12 +1,11 @@
 /*=======================================================================
- * Version: $Id: confTree.c,v 1.15 2015/10/12 23:28:51 nroche Exp $
  * Project: mediaTeX
  * Module : configuration
  *
  * configuration producer interface
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -73,7 +72,7 @@ createCollection(void)
   /* computed paths will be filled by expandCollection */
 
   if (!(rc->archives = 
-	avl_alloc_tree(cmpArchive2, (avl_freeitem_t)destroyArchive)))
+	avl_alloc_tree(cmpArchiveAvl, (avl_freeitem_t)destroyArchive)))
     goto error;
 
   if ((rc->networks = createRing()) == 0) goto error;
@@ -118,7 +117,7 @@ destroyCollection(Collection* self)
 
   // directories
   self->homeDir = destroyString(self->homeDir);
-  self->cvsDir = destroyString(self->cvsDir);
+  self->gitDir = destroyString(self->gitDir);
   self->sshDir = destroyString(self->sshDir);
   self->cacheDir = destroyString(self->cacheDir);
   self->extractDir = destroyString(self->extractDir);
@@ -182,7 +181,6 @@ expandCollection(Collection* self)
 {
   int rc = FALSE;
   Configuration* conf = 0;
-  char urlPart[128];
   int i,j;
   char* dataV[] = {CONF_CATHFILE, CONF_SERVFILE, CONF_EXTRFILE, "/cgi"};
   char** dataP[] = {
@@ -192,8 +190,6 @@ expandCollection(Collection* self)
     &self->htmlIndexDir, &self->htmlCacheDir, 
     &self->htmlScoreDir, &self->htmlCgiDir};
   char* label = 0;
-  char* mdtx = 0;
-  char* user = 0;
 
   // defensive code
   checkCollection(self);
@@ -237,8 +233,8 @@ expandCollection(Collection* self)
       || !(self->cacheDir =  catString(self->cacheDir, label))
       || !(self->extractDir = createString(conf->extractDir)) 
       || !(self->extractDir = catString(self->extractDir, label))
-      || !(self->cvsDir = createString(conf->cvsDir)) 
-      || !(self->cvsDir = catString(self->cvsDir, label))
+      || !(self->gitDir = createString(conf->gitDir)) 
+      || !(self->gitDir = catString(self->gitDir, label))
       || !(self->homeDir = createString(conf->homeDir))
       || !(self->homeDir =  catString(self->homeDir, CONF_HOME))
       || !(self->homeDir =  catString(self->homeDir, label))
@@ -265,7 +261,7 @@ expandCollection(Collection* self)
 
   // metadata files
   for (j=0; j<3; ++j) {
-    if (!(*dataP[j] = createString(self->cvsDir)) 
+    if (!(*dataP[j] = createString(self->gitDir)) 
 	|| !(*dataP[j] = catString(*dataP[j], dataV[j]))) 
       goto error;
   }
@@ -297,28 +293,6 @@ expandCollection(Collection* self)
 	   catString(self->sshDsaPublicKey, CONF_DSAUSERKEY)))
     goto error;
 
-  // urls
-  if (conf->wwwPort == 443) {
-    if (sprintf(urlPart, "/~%s", self->user) <= 0)
-      goto error;
-  }
-  else {
-    if (sprintf(urlPart, ":%i/~%s", conf->wwwPort, self->user) <= 0)
-      goto error;
-  }
-
-  if (!(self->cacheUrl = createString("https://")) 
-      || !(self->cacheUrl = catString(self->cacheUrl, conf->host))
-      || !(self->cacheUrl = catString(self->cacheUrl, urlPart))
-      || !(self->cacheUrl = catString(self->cacheUrl, "/cache")))
-      goto error;
-
-  if (!(self->cgiUrl = createString("https://")) 
-      || !(self->cgiUrl = catString(self->cgiUrl, conf->host))
-      || !(self->cgiUrl = catString(self->cgiUrl, urlPart))
-      || !(self->cgiUrl = catString(self->cgiUrl, "/cgi/get.cgi")))
-    goto error;
-
   // default values if not set
   if (!self->cacheSize) self->cacheSize = conf->cacheSize;
   if (!self->cacheTTL) self->cacheTTL = conf->cacheTTL;
@@ -337,19 +311,18 @@ expandCollection(Collection* self)
   self->cacheTree->recordTree->collection = self;
 
   // check directories
-  mdtx = env.confLabel;
-  user = self->user;
-
-  if (!checkDirectoryPerm(   self->homeDir,    user, mdtx, 0750)
-      || !checkDirectoryPerm(self->cacheDir,   mdtx, user, 02750)
-      || !checkDirectoryPerm(self->extractDir, mdtx, user, 02770)
-      || !checkDirectoryPerm(self->cvsDir,     mdtx, user, 02770)
-
-      /* mdtx was just been added to user group,
-  	 so it need to reload its groups to check the above
-  	 diretories */
-      || !checkDirectoryPerm(self->sshDir,     user, user, 0700)
-      || !checkDirectoryPerm(self->htmlDir,    mdtx, user, 02750)
+  if (!checkDirectoryPerm(self->user, self->homeDir, 
+			  VAR_CACHE_M_MDTX_HOME_COLL)
+      || !checkDirectoryPerm(self->user, self->cacheDir,
+			     VAR_CACHE_M_MDTX_CACHE_COLL)
+      || !checkDirectoryPerm(self->user, self->extractDir,
+			     VAR_CACHE_M_MDTX_TMP_COLL)
+      || !checkDirectoryPerm(self->user, self->gitDir, 
+			     VAR_CACHE_M_MDTX_GIT_COLL)
+      || !checkDirectoryPerm(self->user, self->sshDir, 
+			     VAR_CACHE_M_MDTX_HOME_COLL_SSH)
+      || !checkDirectoryPerm(self->user, self->htmlDir, 
+			     VAR_CACHE_M_MDTX_HOME_COLL_HTML)
       )
     goto error;
 
@@ -558,37 +531,39 @@ createConfiguration(void)
 
     if (!(tmpDir = catString(tmpDir, "/tmp"))
 	|| !(pidDir = createString(tmpDir))
-	|| !(conf->cvsRootDir = createString(tmpDir))
-	|| !(conf->homeDir = createString(tmpDir))
+	|| !(conf->gitBareDir = createString(tmpDir))
 	|| !(conf->scriptsDir = createString(tmpDir))
+	|| !(conf->homeDir = createString(tmpDir))
 	|| !(conf->hostSshDir = createString(tmpDir)))
       goto error;
   }
 
   // directories
   if (!(pidDir = catString(pidDir, CONF_PIDDIR+i))
-      || !(conf->cvsRootDir = catString(conf->cvsRootDir, CONF_STATEDIR+i))
-      || !(conf->cvsRootDir = catString(conf->cvsRootDir, label))
+      || !(conf->gitBareDir = catString(conf->gitBareDir, CONF_STATEDIR+i))
+      || !(conf->gitBareDir = catString(conf->gitBareDir, label))
       || !(conf->scriptsDir = catString(conf->scriptsDir, CONF_SCRIPTS+i))
       || !(conf->homeDir = catString(conf->homeDir, CONF_CACHEDIR+i))
       || !(conf->homeDir = catString(conf->homeDir, label))
+      || !(conf->jailDir = createString(conf->homeDir))
+      || !(conf->jailDir = catString(conf->jailDir, CONF_JAIL))
       || !(conf->md5sumDir = createString(conf->homeDir))
       || !(conf->md5sumDir = catString(conf->md5sumDir, CONF_MD5SUMS))
       || !(conf->cacheDir = createString(conf->homeDir))
       || !(conf->cacheDir = catString(conf->cacheDir, CONF_CACHES))
       || !(conf->extractDir = createString(conf->homeDir))
       || !(conf->extractDir = catString(conf->extractDir, CONF_EXTRACT))
-      || !(conf->cvsDir = createString(conf->homeDir))
-      || !(conf->cvsDir = catString(conf->cvsDir, CONF_CVSCLT))
-      || !(conf->mdtxCvsDir = createString(conf->cvsDir))
-      || !(conf->mdtxCvsDir = catString(conf->mdtxCvsDir, label))
+      || !(conf->gitDir = createString(conf->homeDir))
+      || !(conf->gitDir = catString(conf->gitDir, CONF_GITCLT))
+      || !(conf->mdtxGitDir = createString(conf->gitDir))
+      || !(conf->mdtxGitDir = catString(conf->mdtxGitDir, label))
       || !(conf->hostSshDir = catString(conf->hostSshDir, CONF_HOSTSSH+i)))
     goto error;
 
   // files
-  if (!(conf->supportDB = createString(conf->mdtxCvsDir))
+  if (!(conf->supportDB = createString(conf->mdtxGitDir))
       || !(conf->supportDB = catString(conf->supportDB, CONF_SUPPFILE))
-      || !(conf->confFile = createString(conf->mdtxCvsDir))
+      || !(conf->confFile = createString(conf->mdtxGitDir))
       || !(conf->confFile = catString(conf->confFile, label))
       || !(conf->confFile = catString(conf->confFile, CONF_CONFFILE))
       || !(conf->pidFile = createString(pidDir))
@@ -612,7 +587,8 @@ createConfiguration(void)
   conf->scoreParam = defaultScoreParam;
   strncpy(conf->host, DEFAULT_HOST, MAX_SIZE_HOST);
   conf->sshPort = SSH_PORT;
-  conf->wwwPort = WWW_PORT;
+  conf->httpPort = HTTP_PORT;
+  conf->httpsPort = HTTPS_PORT;
   conf->mdtxPort = env.noRegression?TESTING_PORT:CONF_PORT;
 
   rc = conf;
@@ -644,14 +620,15 @@ destroyConfiguration(Configuration* self)
   if(self) {
 
     // directories
-    self->cvsRootDir = destroyString(self->cvsRootDir);
+    self->gitBareDir = destroyString(self->gitBareDir);
     self->scriptsDir = destroyString(self->scriptsDir);
     self->homeDir = destroyString(self->homeDir);
     self->md5sumDir = destroyString(self->md5sumDir);
+    self->jailDir = destroyString(self->jailDir);
     self->cacheDir = destroyString(self->cacheDir);
     self->extractDir = destroyString(self->extractDir);
-    self->cvsDir = destroyString(self->cvsDir);
-    self->mdtxCvsDir = destroyString(self->mdtxCvsDir);
+    self->gitDir = destroyString(self->gitDir);
+    self->mdtxGitDir = destroyString(self->mdtxGitDir);
     self->hostSshDir = destroyString(self->hostSshDir);
 
     // files
@@ -665,7 +642,8 @@ destroyConfiguration(Configuration* self)
     self->host[0] = (char)0;
     self->mdtxPort = 0;
     self->sshPort = 0;
-    self->wwwPort = 0;
+    self->httpPort = 0;
+    self->httpsPort = 0;
     self->cacheTTL = 0;
     self->queryTTL = 0;
     self->checkTTL = 0;
@@ -702,9 +680,6 @@ expandConfiguration()
   Configuration* conf = 0;
   Collection* coll = 0;
   RGIT* curr = 0;
-  char* jail = 0;
-  char* meta = 0;
-  char* mdtx = env.confLabel;
 
   // defensive code
   if (!(conf = getConfiguration())) goto error;
@@ -714,22 +689,15 @@ expandConfiguration()
     goto end;
   }
 
-  if (!(jail = createString(conf->homeDir))
-      || !(jail = catString(jail, "/jail"))
-      || !(meta = createString(env.confLabel))
-      || !(meta = catString(meta, "_md")))
-    goto error;
-
   // check directories
-  if (!checkDirectoryPerm(jail,                "root", "root", 0755)
-      || !checkDirectoryPerm(conf->cvsRootDir,  mdtx,   meta,  0750)
-      || !checkDirectoryPerm(conf->homeDir,    "root", "root", 0755)
-      || !checkDirectoryPerm(conf->md5sumDir,   mdtx,   mdtx,  0750)
-      || !checkDirectoryPerm(conf->cacheDir,    mdtx,   meta,  0750)
-      || !checkDirectoryPerm(conf->extractDir,  mdtx,   meta,  0750)
-      || !checkDirectoryPerm(conf->cvsDir,      mdtx,   meta,  0750)
-      || !checkDirectoryPerm(conf->mdtxCvsDir,  mdtx,   mdtx,  02770)
-      || !checkDirectoryPerm(conf->hostSshDir, "root", "root", 0755)
+  if (FALSE
+      || !checkDirectoryPerm(0, conf->homeDir, VAR_CACHE_M_MDTX_HOME)
+      || !checkDirectoryPerm(0, conf->jailDir, VAR_CACHE_M_MDTX_JAIL)
+      || !checkDirectoryPerm(0, conf->md5sumDir, VAR_CACHE_M_MDTX_MD5SUMS)
+      || !checkDirectoryPerm(0, conf->cacheDir, VAR_CACHE_M_MDTX_CACHE)
+      || !checkDirectoryPerm(0, conf->extractDir, VAR_CACHE_M_MDTX_TMP)
+      || !checkDirectoryPerm(0, conf->gitDir, VAR_CACHE_M_MDTX_GIT)
+      || !checkDirectoryPerm(0, conf->mdtxGitDir, VAR_CACHE_M_MDTX_GIT_MDTX)
       )
     goto error;
 
@@ -747,8 +715,6 @@ expandConfiguration()
   if (!rc) {
     logMemory(LOG_ERR, "fails to expand configuration");
   }
-  jail = destroyString(jail);
-  meta = destroyString(meta);
   return rc;
 }
 
@@ -845,10 +811,6 @@ serializeConfiguration(Configuration* self)
 
   fprintf(fd, "# This is the MediaTeX software configuration file.\n");
 
-  // do not add the CVS version as it implies a commit evry time we
-  // rebuild the file (because we de not parse the version id)
-  //fprintf(fd, "# Version: $" "Id" "$\n");
-
   fprintf(fd, "\n# comment: greeter for this server\n");
   fprintf(fd, "%-10s \"%s\"\n", "comment", self->comment);
 
@@ -861,9 +823,10 @@ serializeConfiguration(Configuration* self)
   fprintf(fd, "\n# port: listening port for SSHd\n");
   fprintf(fd, "%-10s %i\n", "sshPort", self->sshPort);
 
-  fprintf(fd, "\n# port: listening port for Apache\n");
-  fprintf(fd, "%-10s %i\n", "wwwPort", self->wwwPort);
-  
+  fprintf(fd, "\n# port: listening ports for Apache\n");
+  fprintf(fd, "%-10s %i\n", "httpPort", self->httpPort);
+  fprintf(fd, "%-10s %i\n", "httpsPort", self->httpsPort);
+
   fprintf(fd, "\n# networks: networks the host belongs to\n");
   fprintf(fd, "%-10s ", "networks");
   if (isEmptyRing(self->networks)) {
@@ -1180,6 +1143,7 @@ addNetworkToRing(RG* ring, char *label)
 int addSupportToCollection(Support* support, Collection* coll)
 {
   int rc = FALSE;
+  int alreadyThere = FALSE;
 
   checkCollection(coll);
   checkSupport(support);
@@ -1187,13 +1151,25 @@ int addSupportToCollection(Support* support, Collection* coll)
 	  support->name, coll->label);
 
   // add collection to the support ring
-  if (!rgHaveItem(support->collections, coll) &&
-      !rgInsert(support->collections, coll)) goto error;
+  if (rgHaveItem(support->collections, coll)) {
+    alreadyThere = TRUE;
+  }
+  else {
+    if (!rgInsert(support->collections, coll)) goto error;
+  }
 
   // add support to collection ring
-  if (!rgHaveItem(coll->supports, support) &&
-      !rgInsert(coll->supports, support)) goto error;
+  if (rgHaveItem(coll->supports, support)) {
+    alreadyThere = TRUE;
+  }
+  else {
+    if (!rgInsert(coll->supports, support)) goto error;
+  }
 
+  if (alreadyThere) {
+    logMemory(LOG_NOTICE, "support %s already added to collection %s",
+	      support->name, coll->label);
+  }
   rc = TRUE;
  error:
   if (!rc) {
@@ -1246,6 +1222,7 @@ int delSupportFromCollection(Support* support, Collection* coll)
  * Synopsis   : Server* getLocalHost(Collection* coll)
  * Input      : Collection* coll: 
  * Output     : The localhost server, 0 on error
+ * Requirement: populateCollection(coll)
  =======================================================================*/
 Server* 
 getLocalHost(Collection* coll)
