@@ -1,12 +1,11 @@
 /*=======================================================================
- * Version: $Id: extractTree.c,v 1.14 2015/09/21 01:01:51 nroche Exp $
  * Project: MediaTeX
  * Module : extraction tree
  *
  * Extraction producer interface
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -137,7 +136,7 @@ cmpFromAssoAvl(const void *p1, const void *p2)
   FromAsso* v1 = (FromAsso*)p1;
   FromAsso* v2 = (FromAsso*)p2;
 
-  rc = cmpArchive2(v1->archive, v2->archive);
+  rc = cmpArchiveAvl(v1->archive, v2->archive);
   if (!rc) rc = cmpContainerAvl(v1->container, v2->container);
   return rc;
 }
@@ -220,6 +219,20 @@ serializeContainer(Collection* coll, Container* self, CvsFile* fd)
     goto error;
   }
 
+  if (avl_count(self->childs) < 1) {
+    if (self->type != INC) {
+      fd->print(fd, "\n#(%s\n", strEType(self->type));
+      fd->print(fd, "#=>\n");
+      fd->print(fd, "#)\n");
+      goto end;
+    }
+    else {
+      /* not blocking but prefer to stop now */
+      logMemory(LOG_CRIT, "empty container to serialize !");
+      goto error;
+    }
+  }
+
   fd->print(fd, "\n(%s\n", strEType(self->type));
   fd->doCut = FALSE;
  
@@ -237,7 +250,7 @@ serializeContainer(Collection* coll, Container* self, CvsFile* fd)
   if (avl_count(self->childs) > 0) {
     fd->print(fd, "=>\n");
 
-    for(node = self->childs->head; node; node = node->next) {
+    for (node = self->childs->head; node; node = node->next) {
       asso = node->item;
       if (self->type == INC && !isIncoming(coll, asso->archive)) continue;
       if (!serializeExtractRecord(asso->archive, fd)) goto error;
@@ -246,10 +259,14 @@ serializeContainer(Collection* coll, Container* self, CvsFile* fd)
   }
 
   fd->print(fd, ")\n");
+ end:
   fd->doCut = TRUE;
   ++env.progBar.cur;
   rc = TRUE;
  error:
+  if (!rc) {
+    logMemory(LOG_ERR, "serializeContainer fails");
+  }
   return(rc);
 }
 
@@ -604,7 +621,8 @@ addFromAsso(Collection* coll, Archive* archive, Container* container,
   case INC:
     // having 1 inc asso and 1 normal asso => remove the inc asso
     if (archive->fromContainers->nbItems > 0) {
-      logMemory(LOG_NOTICE, "remove %s:%lli archive from incomings", 
+      logMemory(LOG_NOTICE, 
+		"%s:%lli file is now archived (no more an incoming)",
 		archive->hash, (long long int)archive->size);
       asso = archive->fromContainers->head->it;
       goto end;
@@ -614,7 +632,7 @@ addFromAsso(Collection* coll, Archive* archive, Container* container,
 	       &date.tm_year, &date.tm_mon, &date.tm_mday,
 	       &date.tm_hour, &date.tm_min, &date.tm_sec)
 	!= 6) {
-      logCommon(LOG_ERR, "sscanf: error parsing date %s", path);
+      logCommon(LOG_ERR, "sscanf: error parsing date '%s'", path);
       goto error;
     }
 
@@ -632,7 +650,8 @@ addFromAsso(Collection* coll, Archive* archive, Container* container,
   default:
     // having 1 inc asso and 1 normal asso => remove the inc asso
     if (archive->uploadTime) {
-      logMemory(LOG_NOTICE, "remove %s:%lli archive from incomings", 
+      logMemory(LOG_NOTICE, 
+		"%s:%lli file is now archived (no more an incoming)", 
 		archive->hash, (long long int)archive->size);
       archive->uploadTime = 0;
     }
@@ -650,8 +669,11 @@ addFromAsso(Collection* coll, Archive* archive, Container* container,
   if (container->type != INC) {
     if (!rgInsert(archive->fromContainers, asso)) goto error;
   }
-  if (!avl_insert(container->childs, asso)) goto error;
-
+  if (!avl_insert(container->childs, asso)) {
+    logMemory(LOG_ERR, "cannot add %s:%lli (already there?)",
+	      archive->hash, (long long int)archive->size);
+    goto error;
+  }
  end:
   rc = asso;
  error:
@@ -775,7 +797,10 @@ addContainer(Collection* coll, EType type, Archive* parent)
   container->type = type;
   container->parent = parent;
   if (!addFromArchive(coll, container, parent)) goto error;
-  if (!avl_insert(coll->extractTree->containers, container)) goto error;
+  if (!avl_insert(coll->extractTree->containers, container)) {
+    logMemory(LOG_ERR, "cannot add container (already there?)");
+    goto error;
+  }
 
   rc = container;
  error:
