@@ -1,12 +1,11 @@
 /*=======================================================================
- * Version: $Id: recordTree.h,v 1.7 2015/09/17 18:53:47 nroche Exp $
  * Project: MediaTeX
  * Module : record tree
  *
  * Record producer interface
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -59,12 +58,13 @@ struct RecordTree
   char        fingerPrint[MAX_SIZE_MD5+1]; /* server id */
   AESData     aes;
   int         doCypher;   // do AES cypher the body when serializing
-  RG*         records;
+  AVLTree*    records;
 };
 
 int cmpRecordQuick(const void *p1, const void *p2);
 int cmpRecord(const void *p1, const void *p2);
 int cmpRecordSize(const void *p1, const void *p2);
+int cmpRecordPath(const void *p1, const void *p2);
 Record* createRecord(void);
 Record* destroyRecord(Record* self);
 Record* copyRecord(Record* destination, Record* source);
@@ -75,7 +75,7 @@ void logRecordTree(int logModule, int logPriority,
 RecordTree* createRecordTree(void);
 RecordTree* destroyRecordTree(RecordTree* self);
 int serializeRecord(RecordTree* tree, Record* self);
-int logRecord(int logModule, int logPriority, RecordTree* tree, Record* self);
+int logRecord(int logModule, int logPriority, Record* self);
 
 /* API */
 char* strMessageType(MessageType self);
