@@ -1,12 +1,11 @@
 /*=======================================================================
- * Version: $Id: serverTree.c,v 1.14 2015/09/17 18:53:47 nroche Exp $
  * Project: MediaTeX
  * Module : serverTree
 
 * Server producer interface
 
 MediaTex is an Electronic Records Management System
-Copyright (C) 2014 2015 Nicolas Roche
+Copyright (C) 2014 2015 2016 Nicolas Roche
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -179,9 +178,12 @@ createServer(void)
   if ((rc->networks = createRing()) == 0) goto error;
   if ((rc->gateways = createRing()) == 0) goto error;
   if ((rc->images = createRing()) == 0) goto error;
-  if ((rc->records = createRing()) == 0) goto error;
 
-  return rc;
+   /* if (!(rc->records =  */
+   /* 	 avl_alloc_tree(cmpRecordAvl, (avl_freeitem_t)destroyRecord))) */
+   /*   goto error; */
+
+   return rc;
  error:
   logMemory(LOG_ERR, "malloc: cannot create Server");
   return destroyServer(rc);
@@ -202,6 +204,7 @@ destroyServer(Server* self)
   self->label = destroyString(self->label);
   self->user = destroyString(self->user);
   self->comment = destroyString(self->comment);
+  self->url = destroyString(self->url);
   self->mdtxPort = 0;
   self->sshPort = 0;
   self->wwwPort = 0;
@@ -209,9 +212,10 @@ destroyServer(Server* self)
   self->hostKey = destroyString(self->hostKey);
   
   // do not delete objets (owned by serverTree or recordTree)
-  self->records = destroyOnlyRing(self->records);
   self->networks = destroyOnlyRing(self->networks);
   self->gateways = destroyOnlyRing(self->gateways);
+  //self->records->freeitem = 0;
+  //avl_free_tree(self->records);
 
   self->images = 
     destroyRing(self->images, (void*(*)(void*)) destroyImage);
@@ -251,31 +255,33 @@ serializeServer(Server* self, FILE* fd)
   
   fprintf(fd, "\nServer %s\n", self->fingerPrint);
   if (!isEmptyString(self->comment)) {
-    fprintf(fd, "\t%-9s \"%s\"\n", "comment", self->comment);
+    fprintf(fd, "\t%-10s \"%s\"\n", "comment", self->comment);
   }
   if (!isEmptyString(self->label)) {
-    fprintf(fd, "\t%-9s %s\n", "label", self->label);
+    fprintf(fd, "\t%-10s %s\n", "label", self->label);
   }
   if (!isEmptyString(self->host)) {
-    fprintf(fd, "\t%-9s %s\n", "host", self->host);
+    fprintf(fd, "\t%-10s %s\n", "host", self->host);
+  }
+
+  if (self->lastCommit) {
+    fprintf(fd, "\t%-10s %04i-%02i-%02i,%02i:%02i:%02i \n", "lastCommit",
+	    date.tm_year + 1900, date.tm_mon+1, date.tm_mday,
+	    date.tm_hour, date.tm_min, date.tm_sec);
   }
-  
-  fprintf(fd, "\t%-9s %04i-%02i-%02i,%02i:%02i:%02i \n", "lastCommit",
-	  date.tm_year + 1900, date.tm_mon+1, date.tm_mday,
-	  date.tm_hour, date.tm_min, date.tm_sec);
   
   if (self->mdtxPort) {
-    fprintf(fd, "\t%-9s %i\n", "mdtxPort", self->mdtxPort);
+    fprintf(fd, "\t%-10s %i\n", "mdtxPort", self->mdtxPort);
   }
   if (self->sshPort) {
-    fprintf(fd, "\t%-9s %i\n", "sshPort", self->sshPort);
+    fprintf(fd, "\t%-10s %i\n", "sshPort", self->sshPort);
   }
   if (self->wwwPort) {
-    fprintf(fd, "\t%-9s %i\n", "wwwPort", self->wwwPort);
+    fprintf(fd, "\t%-10s %i\n", "wwwPort", self->wwwPort);
   }
 
   if (!isEmptyRing(self->networks)) {
-    fprintf(fd, "\t%-9s ", "networks");
+    fprintf(fd, "\t%-10s ", "networks");
     if (!rgSort(self->networks, cmpString)) goto error;
     curr = 0;
     if (!(string = rgNext_r(self->networks, &curr))) goto error;
@@ -287,7 +293,7 @@ serializeServer(Server* self, FILE* fd)
   }
   
   if (!isEmptyRing(self->gateways)) {
-    fprintf(fd, "\t%-9s ", "gateways");
+    fprintf(fd, "\t%-10s ", "gateways");
     if (!rgSort(self->gateways, cmpString)) goto error;
     curr = 0;
     if (!(string = rgNext_r(self->gateways, &curr))) goto error;
@@ -300,13 +306,13 @@ serializeServer(Server* self, FILE* fd)
 
   /* cache parameters (take care, this use macro) */
   if (self->cacheSize) {
-    printCacheSize(fd, "\t%-9s", "cacheSize", self->cacheSize);
+    printCacheSize(fd, "\t%-10s", "cacheSize", self->cacheSize);
   }
   if (self->cacheTTL) {
-    printLapsTime(fd, "\t%-9s", "cacheTTL", self->cacheTTL);
+    printLapsTime(fd, "\t%-10s", "cacheTTL", self->cacheTTL);
   }
   if (self->queryTTL) {
-    printLapsTime(fd, "\t%-9s", "queryTTL", self->queryTTL);
+    printLapsTime(fd, "\t%-10s", "queryTTL", self->queryTTL);
   }
 
   // list of images
@@ -325,10 +331,13 @@ serializeServer(Server* self, FILE* fd)
   } 
 
   fprintf(fd, "%s", "#\tkeys:\n");
-  fprintf(fd, "\t%-9s \"%s\"\n", "userKey", self->userKey);
-  if (!isEmptyString(self->hostKey))
-    fprintf(fd, "\t%-9s \"%s\"\n", "hostKey", self->hostKey);
-
+  if (!isEmptyString(self->userKey)) {
+    fprintf(fd, "\t%-10s \"%s\"\n", "userKey", self->userKey);
+  }
+  if (!isEmptyString(self->hostKey)) {
+    fprintf(fd, "\t%-10s \"%s\"\n", "hostKey", self->hostKey);
+  }
+  
   fprintf (fd, "end\n");
   rc = TRUE;
  error:
@@ -379,7 +388,8 @@ createServerTree(void)
     
   memset(rc, 0, sizeof(ServerTree));
   strncpy(rc->aesKey, "01234567890abcdef", MAX_SIZE_AES);
-
+  rc->doHttps = TRUE;
+  rc->log = NO_LOG;
   rc->uploadTTL = DEFAULT_TTL_UPLOAD;
   rc->serverTTL = DEFAULT_TTL_SERVER;
   rc->scoreParam = defaultScoreParam;
@@ -437,7 +447,7 @@ serializeServerTree(Collection* coll)
   if(!(self = coll->serverTree)) goto error;
   logMemory(LOG_DEBUG, "serialize %s server tree", coll->label);
 
-  // we neeed to use the home cvs collection directory
+  // we neeed to use the home git collection directory
   if (!(coll->memoryState & EXPANDED)) {
     logMemory(LOG_ERR, "collection must be expanded first");
     goto error;
@@ -459,24 +469,27 @@ serializeServerTree(Collection* coll)
   }
 
   fprintf(fd, "# This file is managed by MediaTeX software.\n");
-
-  // do not add the CVS version as it implies a commit evry time we
-  // rebuild the file (because we de not parse the version id)
-  //fprintf(fd, "# Version: $" "Id" "$\n");
   
   if (!self->master) {
-    logMemory(LOG_ERR, "loose master server for %s collection", 
+    logMemory(LOG_WARNING, "loose master server for %s collection", 
 	    coll->label);
-    goto error;
   }
 
   // tel which is the master collection server
-  fprintf(fd, "# MediaTeX %s@%s:%i servers list:\n\n", 
-	  self->master->user, self->master->host, 
-	  self->master->sshPort);
-  fprintf(fd, "%-10s %s\n", "master", self->master->fingerPrint);
+  if (self->master) {
+    fprintf(fd, "# MediaTeX %s@%s:%i servers list:\n\n", 
+	    self->master->user, self->master->host, 
+	    self->master->sshPort);
+    fprintf(fd, "%-10s %s\n", "master", self->master->fingerPrint);
+  }
   
   fprintf(fd, "%-10s %s\n", "collKey", self->aesKey);
+  fprintf(fd, "%-10s %s\n", "https", self->doHttps?"yes":"no");
+  
+  fprintf(fd, "\n# self-ingestion parameters\n");
+  fprintf(fd, "%-10s %s\n", "logApache", self->log & APACHE?"yes":"no");
+  fprintf(fd, "%-10s %s\n", "logGit", self->log & GIT?"yes":"no");
+  fprintf(fd, "%-10s %s\n", "logAudit", self->log & AUDIT?"yes":"no");
 
   fprintf(fd, "\n# score parameters\n");
   printLapsTime(fd, "%-10s", "uploadTTL", self->uploadTTL);
@@ -607,8 +620,8 @@ addImage(Collection* coll, Server* server, Archive* archive)
  *              Image* image : the image to del
  * Output     : TRUE on success
  * Note       :
- *     Non sens: seul delArchive et delServer peuvent l'appeler
- *     or delServer => O(n2) pour rien.
+ *     Non sens: only delArchive and delServer can call it.
+ *     from  delServer => O(n2)
  =======================================================================*/
 int
 delImage(Collection* coll, Image* image)
@@ -733,7 +746,7 @@ delServer(Collection* coll, Server* server)
 {
   int rc = FALSE;
   Image* img = 0;
-  Record* rec = 0;
+  //Record* rec = 0;
   RGIT* curr = 0;
 
   checkCollection(coll);
@@ -743,13 +756,16 @@ delServer(Collection* coll, Server* server)
   // delete from coll if localhost 
   if (coll->localhost == server) coll->localhost = 0;
 
+  // delete master (needed by mdtxDelCollection to serialize)
+  if (coll->serverTree->master == server) coll->serverTree->master = 0;
+  
   // delete images own by the this server
   while ((img = rgHead(server->images)))
     if (!delImage(coll, img)) goto error;
 
   // delete records
-  while ((rec = rgHead(server->records)))
-    if (!delRecord(coll, rec)) goto error;
+  //while ((rec = rgHead(server->records)))
+  //  if (!delRecord(coll, rec)) goto error;
 
   // delete server from collection ring
   if ((curr = rgHaveItem(coll->serverTree->servers, server))) {
@@ -814,8 +830,10 @@ diseaseServer(Collection* coll, Server* server)
   server->label = destroyString(server->label);
   server->user = destroyString(server->user);
   server->comment = destroyString(server->comment);
+  server->lastCommit = 0;
   server->mdtxPort = 0;
   server->sshPort = 0;
+  server->wwwPort = 0;
   server->userKey = destroyString(server->userKey);
   server->hostKey = destroyString(server->hostKey);
   server->host[0] = (char)0;
@@ -860,6 +878,102 @@ diseaseServerTree(Collection* coll)
   return rc;
 }
 
+/*=======================================================================
+ * Function   : isReachable
+ * Description: test if "from" server may use gateways to reach "to" 
+ *              server
+ * Synopsis   : int isReachable(Collection* coll, 
+ *                                         Server* from, Server* to)
+ * Input      : Collection* coll : where to add
+ *              Server* server = the proxy server 
+ *              Server* proxy  = the proxy client
+ * Output     : TRUE on success
+ * Note       : this function is not symmetric
+ =======================================================================*/
+int 
+isReachable(Collection* coll, Server* from, Server* to)
+{
+  int rc = FALSE;
+  int loop = TRUE;
+  RG* reach = 0;
+  void* it = 0;
+  RG* tmp = 0;
+  //RG* tmp2 = 0;
+  RGIT* curr = 0;
+  Server* server = 0;
+  int nbReachable = 0;
+
+  logMemory(LOG_DEBUG, "isReachable from %s to %s",
+	  from->fingerPrint, to->fingerPrint);
+
+  // networks we can reach
+  if (!(reach = createRing())) goto error;
+  while ((it = rgNext_r(from->networks, &curr))) {
+    if (!rgInsert(reach, it)) goto error;
+  }
+  nbReachable = reach->nbItems;
+
+  // loop until "to" is located under a reachable network
+  /* printf("\n"); */
+  while (loop) {
+
+    /* printf("looping...\n"); */
+    /* printf("we now we can reach:"); */
+    /* while ((it = rgNext(reach))) printf(" %s", (char*)it); */
+    /* printf ("\n"); */
+
+    /* printf("we want to reach on of them:"); */
+    /* while ((it = rgNext(to->networks))) printf(" %s", (char*)it); */
+    /* printf ("\n"); */
+
+    // exit when reachable
+    if (!(tmp = rgInter(reach, to->networks))) goto error;
+    if (!isEmptyRing(tmp)) {
+      rc = TRUE;
+      tmp = destroyOnlyRing(tmp);
+      /* printf("... ok reachable\n"); */
+      goto end;
+    }
+    tmp = destroyOnlyRing(tmp);
+
+    // look for a new gateway (juste one)
+    loop = FALSE;
+    curr = 0; 
+    while (!loop && (server = rgNext_r(coll->serverTree->servers, &curr))) {
+      if (!(tmp = rgInter(reach, server->gateways))) goto error;
+      if (!isEmptyRing(tmp)) {
+
+	/* printf("new reachable networks:"); */
+	/* while ((it = rgNext(server->networks))) printf(" %s", (char*)it); */
+	/* printf ("\n");      */
+
+	// we find one so we now we can reach its networks
+	tmp = destroyOnlyRing(tmp);
+	if (!(tmp = rgUnion(reach, server->networks))) goto error;
+	reach = destroyOnlyRing(reach);
+	reach = tmp;
+	tmp = 0;
+
+	// but is there new networks ?
+	loop = (reach->nbItems > nbReachable);
+      }
+      tmp = destroyOnlyRing(tmp);
+    }
+  }
+
+  /* printf("... not reachable\n"); */
+ end:
+  logMemory(LOG_INFO, "%s may %sreach %s",
+	  from->fingerPrint, rc?"":"not ", to->fingerPrint);
+  reach = destroyOnlyRing(reach);
+  return rc;
+ error:
+  logMemory(LOG_DEBUG, "isReachable fails");
+  reach = destroyOnlyRing(reach);
+  return FALSE;
+}
+
+
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
