@@ -1,12 +1,11 @@
 /*=======================================================================
- * Version: $Id: command.h,v 1.13 2015/10/01 21:52:40 nroche Exp $
  * Project: MediaTeX
  * Module : command
  *
  * system API
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -28,17 +27,16 @@
 #include "mediatex-types.h"
 #include <getopt.h>
 
-#define MISC_SHORT_OPTIONS "hvf:s:l:nm:S"
+#define MISC_SHORT_OPTIONS "hVvf:s:l:nm:"
 #define MISC_LONG_OPTIONS				\
   {"help", no_argument, 0, 'h'},			\
-  {"version", no_argument, 0, 'v'},			\
+  {"version", no_argument, 0, 'V'},			\
+  {"verbose", no_argument, 0, 'v'},			\
   {"facility", required_argument, 0, 'f'},		\
   {"severity", required_argument, 0, 's'},		\
   {"log-file", required_argument, 0, 'l'},		\
   {"dry-run", no_argument, 0, 'n'},			\
-  {"memory-limit", required_argument, 0, 'm'},		\
-  {"script-out", required_argument, 0, 'S'}
-
+  {"memory-limit", required_argument, 0, 'm'}
 #define MEMORY_SHORT_OPTIONS MISC_SHORT_OPTIONS
 #define MEMORY_LONG_OPTIONS				\
   MISC_LONG_OPTIONS
@@ -84,18 +82,40 @@ int execScript(char** argv, char* user, char* pwd, int doHideStderr);
  * Note       : EXIT_SUCCESS = 0
  *              EINVAL = 22
  *              ENOMEM = 12
+ * TODO       : Try make an alway done action to summurise options 
+ *              effectively read.
  =======================================================================*/
 #define GET_MISC_OPTIONS						\
   case 'h':								\
-  usage(programName);							\
+    usage(programName);							\
+    rc = EXIT_SUCCESS;							\
+    goto optError;							\
+    break;								\
+									\
+  case 'V':								\
+    version();								\
     rc = EXIT_SUCCESS;							\
     goto optError;							\
     break;								\
 									\
   case 'v':								\
-    version();								\
-    rc = EXIT_SUCCESS;							\
-    goto optError;							\
+    switch (env.nbVerbose++) {						\
+      case 0:								\
+	if (!parseLogSeverityOption(env.v, env.logSeverity)) {		\
+	  rc = EINVAL;							\
+	}								\
+	break;								\
+      case 1:								\
+	if (!parseLogSeverityOption(env.vv, env.logSeverity)) {		\
+	  rc = EINVAL;							\
+	}								\
+	break;								\
+      case 2:								\
+	if (!parseLogSeverityOption(env.vvv, env.logSeverity)) {	\
+	  rc = EINVAL;							\
+	}								\
+	break;								\
+    }									\
     break;								\
 									\
   case 'f':								\
@@ -149,10 +169,6 @@ int execScript(char** argv, char* user, char* pwd, int doHideStderr);
     env.allocLimit = atoi(optarg);					\
     break;								\
 									\
-  case 'S':								\
-    env.debugScript = 1;						\
-    break;								\
-									\
   default:								\
     rc = EINVAL;							\
     usage(programName);
@@ -205,6 +221,23 @@ int execScript(char** argv, char* user, char* pwd, int doHideStderr);
 									\
   GET_PARSER_OPTIONS;
 
+/*=======================================================================
+ * Macro      : mdtxSetEnv
+ * Author(s)  : Nicolas Roche
+ * Description: Wraper for setenv
+ * Synopsis   : void mdtxSetEnv(envVar, tmpVar)
+ * Input      : char* envVar: env variable name
+ * Output     : char* value: value
+ =======================================================================*/
+#define mdtxSetEnv(envVar, value) {					\
+    if (setenv(envVar, value, 1) == -1) {				\
+      logMisc(LOG_ERR, "setenv fails %s <- %s : %s",			\
+	      envVar, value, strerror(errno));				\
+      goto error2;							\
+    }									\
+    logMisc(LOG_DEBUG, "setenv %s <- %s", envVar, value);		\
+  }
+
 /*=======================================================================
  * Macro      : ENDINGS
  * Description: stuff to do before exit
