@@ -1,5 +1,4 @@
 /*=======================================================================
- * Version: $Id: setuid.h,v 1.4 2015/06/30 17:37:34 nroche Exp $
  * Project: MediaTeX
  * Module : setuid
  *
@@ -9,7 +8,7 @@
  http://www.gnu.org/software/libc/manual/html_node/Setuid-Program-Example.html
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -37,7 +36,7 @@ int getPasswdLine (char* label, uid_t uid,
 int getGroupLine (char* label, gid_t gid, 
 		  struct group* gr, char** buffer);
 
-int undo_seteuid (void);
+int undoSeteuid (void);
 int allowedUser (char* label);
 int becomeUser (char* label, int doCheck);
 int logoutUser (int uid);
