@@ -69,7 +69,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 55 "parser/extractFile.y" /* yacc.c:339  */
+#line 54 "parser/extractFile.y" /* yacc.c:339  */
   
 #include "mediatex-config.h"
   /* yyscan_t is pre-defined by mediatex-config.h and will be defined
@@ -149,7 +149,7 @@ extern int extr_debug;
 typedef union EXTR_STYPE EXTR_STYPE;
 union EXTR_STYPE
 {
-#line 61 "parser/extractFile.y" /* yacc.c:355  */
+#line 60 "parser/extractFile.y" /* yacc.c:355  */
 
   off_t  size;
   char   string[MAX_SIZE_STRING+1];
@@ -167,7 +167,7 @@ union EXTR_STYPE
 
 int extr_parse (yyscan_t yyscanner, Collection* coll, Container* container);
 /* "%code provides" blocks.  */
-#line 27 "parser/extractFile.y" /* yacc.c:355  */
+#line 26 "parser/extractFile.y" /* yacc.c:355  */
 
 /*=======================================================================
  * Version: this file is generated by BISON using extractFile.y
@@ -177,7 +177,7 @@ int extr_parse (yyscan_t yyscanner, Collection* coll, Container* container);
  * extract parser.
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
    
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -200,7 +200,7 @@ int extr_parse (yyscan_t yyscanner, Collection* coll, Container* container);
 #endif /* !YY_EXTR_PARSER_EXTRACTFILE_TAB_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
-#line 69 "parser/extractFile.y" /* yacc.c:358  */
+#line 68 "parser/extractFile.y" /* yacc.c:358  */
 
 // we need YYSTYPE defined first to include the Flex headers
 #include "parser/extractFile.h"
@@ -452,16 +452,16 @@ union yyalloc
 /* YYFINAL -- State number of the termination state.  */
 #define YYFINAL  9
 /* YYLAST -- Last index in YYTABLE.  */
-#define YYLAST   23
+#define YYLAST   15
 
 /* YYNTOKENS -- Number of terminals.  */
 #define YYNTOKENS  14
 /* YYNNTS -- Number of nonterminals.  */
-#define YYNNTS  12
+#define YYNNTS  13
 /* YYNRULES -- Number of rules.  */
-#define YYNRULES  18
+#define YYNRULES  20
 /* YYNSTATES -- Number of states.  */
-#define YYNSTATES  26
+#define YYNSTATES  27
 
 /* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
    by yylex, with out-of-bounds checking.  */
@@ -508,8 +508,9 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,   111,   111,   113,   118,   122,   128,   135,   139,   143,
-     150,   157,   165,   169,   175,   179,   185,   192,   199
+       0,   110,   110,   112,   117,   121,   127,   135,   136,   137,
+     144,   156,   169,   173,   179,   181,   190,   194,   200,   207,
+     214
 };
 #endif
 
@@ -522,7 +523,7 @@ static const char *const yytname[] =
   "extrTYPE", "extrIMPLIES", "extrAS", "extrHASH", "extrCOLON", "extrSIZE",
   "extrCOMMA", "extrSTRING", "$accept", "file", "stanzas", "stanza",
   "container", "incContainer", "stdContainer", "parents", "childs",
-  "parent", "child", "archive", YY_NULLPTR
+  "childs2", "parent", "child", "archive", YY_NULLPTR
 };
 #endif
 
@@ -536,10 +537,10 @@ static const yytype_uint16 yytoknum[] =
 };
 # endif
 
-#define YYPACT_NINF -7
+#define YYPACT_NINF -9
 
 #define yypact_value_is_default(Yystate) \
-  (!!((Yystate) == (-7)))
+  (!!((Yystate) == (-9)))
 
 #define YYTABLE_NINF -1
 
@@ -550,9 +551,9 @@ static const yytype_uint16 yytoknum[] =
      STATE-NUM.  */
 static const yytype_int8 yypact[] =
 {
-      -2,    -3,     4,    -2,    -7,     0,    -1,    -7,     0,    -7,
-      -7,     1,    -7,     0,     0,    -7,    -7,     3,    -4,    -7,
-      -6,    -7,    -7,    -7,    -7,    -7
+      -3,    -4,     3,    -3,    -9,    -2,    -1,    -9,    -2,    -9,
+      -9,    -6,    -9,    -2,    -2,    -9,    -9,     0,     4,    -2,
+      -9,    -8,    -9,    -9,    -9,    -9,    -9
 };
 
   /* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
@@ -561,22 +562,22 @@ static const yytype_int8 yypact[] =
 static const yytype_uint8 yydefact[] =
 {
        3,     0,     0,     2,     5,    10,     0,     7,     8,     1,
-       4,     0,    11,     0,     9,    13,    16,     0,     0,    15,
-       0,    12,    18,     6,    14,    17
+       4,     0,    11,    15,     9,    13,    18,     0,     0,    14,
+      17,     0,    12,    20,     6,    16,    19
 };
 
   /* YYPGOTO[NTERM-NUM].  */
 static const yytype_int8 yypgoto[] =
 {
-      -7,    -7,    -7,     7,    -7,    -7,    -7,    -7,    -7,     2,
-       5,    -5
+      -9,    -9,    -9,     7,    -9,    -9,    -9,    -9,    -9,    -9,
+       1,    -7,    -5
 };
 
   /* YYDEFGOTO[NTERM-NUM].  */
 static const yytype_int8 yydefgoto[] =
 {
-      -1,     2,     3,     4,     6,     7,     8,    14,    18,    15,
-      19,    16
+      -1,     2,     3,     4,     6,     7,     8,    14,    18,    19,
+      15,    20,    16
 };
 
   /* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
@@ -584,16 +585,14 @@ static const yytype_int8 yydefgoto[] =
      number is the opposite.  If YYTABLE_NINF, syntax error.  */
 static const yytype_uint8 yytable[] =
 {
-      12,    23,     1,     5,     9,    11,    13,    25,    20,    11,
-      10,    17,     0,    20,    22,     0,    21,     0,     0,     0,
-       0,     0,     0,    24
+      12,     1,     5,     9,    17,    26,    13,    11,    21,    24,
+      10,    23,    25,     0,    21,    22
 };
 
 static const yytype_int8 yycheck[] =
 {
-       5,     5,     4,     6,     0,     9,     7,    13,    13,     9,
-       3,    10,    -1,    18,    11,    -1,    14,    -1,    -1,    -1,
-      -1,    -1,    -1,    18
+       5,     4,     6,     0,    10,    13,     7,     9,    13,     5,
+       3,    11,    19,    -1,    19,    14
 };
 
   /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
@@ -601,22 +600,24 @@ static const yytype_int8 yycheck[] =
 static const yytype_uint8 yystos[] =
 {
        0,     4,    15,    16,    17,     6,    18,    19,    20,     0,
-      17,     9,    25,     7,    21,    23,    25,    10,    22,    24,
-      25,    23,    11,     5,    24,    13
+      17,     9,    26,     7,    21,    24,    26,    10,    22,    23,
+      25,    26,    24,    11,     5,    25,    13
 };
 
   /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
 static const yytype_uint8 yyr1[] =
 {
        0,    14,    15,    15,    16,    16,    17,    18,    18,    18,
-      19,    20,    21,    21,    22,    22,    23,    24,    25
+      19,    20,    21,    21,    22,    22,    23,    23,    24,    25,
+      26
 };
 
   /* YYR2[YYN] -- Number of symbols on the right hand side of rule YYN.  */
 static const yytype_uint8 yyr2[] =
 {
        0,     2,     1,     0,     2,     1,     5,     1,     1,     2,
-       1,     2,     2,     1,     2,     1,     1,     2,     3
+       1,     2,     2,     1,     1,     0,     2,     1,     1,     2,
+       3
 };
 
 
@@ -1303,143 +1304,150 @@ yyreduce:
   switch (yyn)
     {
         case 3:
-#line 113 "parser/extractFile.y" /* yacc.c:1646  */
+#line 112 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_WARNING, "%s", "the extract file was empty");
 }
-#line 1311 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1312 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 4:
-#line 119 "parser/extractFile.y" /* yacc.c:1646  */
+#line 118 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: stanzas: stanzas stanza", LINENO);
 }
-#line 1319 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1320 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 5:
-#line 123 "parser/extractFile.y" /* yacc.c:1646  */
+#line 122 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: stanzas: stanza", LINENO);
 }
-#line 1327 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1328 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 6:
-#line 129 "parser/extractFile.y" /* yacc.c:1646  */
+#line 128 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: %s", LINENO, 
 	    "stanza: (container => childs)");
-}
-#line 1336 "parser/extractFile.tab.c" /* yacc.c:1646  */
-    break;
 
-  case 7:
-#line 136 "parser/extractFile.y" /* yacc.c:1646  */
-    {
-  logParser(LOG_DEBUG, "line %i: incContainer", LINENO);
 }
-#line 1344 "parser/extractFile.tab.c" /* yacc.c:1646  */
-    break;
-
-  case 8:
-#line 140 "parser/extractFile.y" /* yacc.c:1646  */
-    {
-  logParser(LOG_DEBUG, "line %i: stdContainer", LINENO);
-}
-#line 1352 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1338 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 9:
-#line 144 "parser/extractFile.y" /* yacc.c:1646  */
+#line 138 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: stdContainer parents", LINENO);
 }
-#line 1360 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1346 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 10:
-#line 151 "parser/extractFile.y" /* yacc.c:1646  */
+#line 145 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: incContainer: %s", 
 	    LINENO, strEType((yyvsp[0].type)));
+  if ((yyvsp[0].type) != INC) {
+    logParser(LOG_ERR, "line %i: %s", LINENO, 
+	      "only the 'INC' container do not provide parent");
+    YYERROR;
+  }
   container = coll->extractTree->incoming;
 }
-#line 1370 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1361 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 11:
-#line 158 "parser/extractFile.y" /* yacc.c:1646  */
+#line 157 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: stdContainer: %s archive",
 	    LINENO, strEType((yyvsp[-1].type)));
+  if ((yyvsp[-1].type) == INC) {
+    logParser(LOG_ERR, "line %i: %s (%s)", LINENO, 
+	      "the 'INC' container cannot have parent");
+    YYERROR;
+  }
   if (!(container = addContainer(coll, (yyvsp[-1].type), (yyvsp[0].archive)))) YYERROR;
 }
-#line 1380 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1376 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 12:
-#line 166 "parser/extractFile.y" /* yacc.c:1646  */
+#line 170 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: parents: parents parent", LINENO);
 }
-#line 1388 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1384 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 13:
-#line 170 "parser/extractFile.y" /* yacc.c:1646  */
+#line 174 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: parents: parent", LINENO);
 }
-#line 1396 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1392 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
-  case 14:
-#line 176 "parser/extractFile.y" /* yacc.c:1646  */
+  case 15:
+#line 181 "parser/extractFile.y" /* yacc.c:1646  */
     {
-  logParser(LOG_DEBUG, "line %i: childs: childs child", LINENO);
+  if (container->type != INC) {
+    logParser(LOG_ERR, "line %i: %s", LINENO, 
+	      "only the 'INC' container may do not provide childs");
+    YYERROR;
+  }
 }
 #line 1404 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
-  case 15:
-#line 180 "parser/extractFile.y" /* yacc.c:1646  */
+  case 16:
+#line 191 "parser/extractFile.y" /* yacc.c:1646  */
     {
-  logParser(LOG_DEBUG, "line %i: childs: child", LINENO);
+  logParser(LOG_DEBUG, "line %i: childs: childs child", LINENO);
 }
 #line 1412 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
-  case 16:
-#line 186 "parser/extractFile.y" /* yacc.c:1646  */
+  case 17:
+#line 195 "parser/extractFile.y" /* yacc.c:1646  */
+    {
+  logParser(LOG_DEBUG, "line %i: childs: child", LINENO);
+}
+#line 1420 "parser/extractFile.tab.c" /* yacc.c:1646  */
+    break;
+
+  case 18:
+#line 201 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: parent: archive", LINENO);
   if (!addFromArchive(coll, container, (yyvsp[0].archive))) YYERROR;
 }
-#line 1421 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1429 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
-  case 17:
-#line 193 "parser/extractFile.y" /* yacc.c:1646  */
+  case 19:
+#line 208 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: child: archive %s", LINENO, (yyvsp[0].string));
   if (!(addFromAsso(coll, (yyvsp[-1].archive), container, (yyvsp[0].string)))) YYERROR;
 }
-#line 1430 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1438 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
-  case 18:
-#line 200 "parser/extractFile.y" /* yacc.c:1646  */
+  case 20:
+#line 215 "parser/extractFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "line %i: archive: %s:%lli", LINENO, (yyvsp[-2].hash), (yyvsp[0].size));
   if (!((yyval.archive) = addArchive(coll, (yyvsp[-2].hash), (yyvsp[0].size)))) YYERROR;
 }
-#line 1439 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1447 "parser/extractFile.tab.c" /* yacc.c:1646  */
     break;
 
 
-#line 1443 "parser/extractFile.tab.c" /* yacc.c:1646  */
+#line 1451 "parser/extractFile.tab.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1667,7 +1675,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 206 "parser/extractFile.y" /* yacc.c:1906  */
+#line 221 "parser/extractFile.y" /* yacc.c:1906  */
 
 
 /* epilogue: =======================================================*/
