@@ -69,7 +69,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 55 "parser/recordFile.y" /* yacc.c:339  */
+#line 54 "parser/recordFile.y" /* yacc.c:339  */
   
 #include "mediatex-config.h"
   /* yyscan_t is pre-defined by mediatex-config.h and will be defined
@@ -155,7 +155,7 @@ extern int record_debug;
 typedef union RECORD_STYPE RECORD_STYPE;
 union RECORD_STYPE
 {
-#line 61 "parser/recordFile.y" /* yacc.c:355  */
+#line 60 "parser/recordFile.y" /* yacc.c:355  */
 
   Type    type;
   time_t  time;
@@ -175,7 +175,7 @@ union RECORD_STYPE
 
 int record_parse (yyscan_t yyscanner, RecordTree* recordTree);
 /* "%code provides" blocks.  */
-#line 27 "parser/recordFile.y" /* yacc.c:355  */
+#line 26 "parser/recordFile.y" /* yacc.c:355  */
 
 /*=======================================================================
  * Version: this file is generated by BISON using recordFile.y
@@ -185,7 +185,7 @@ int record_parse (yyscan_t yyscanner, RecordTree* recordTree);
  * recordList parser
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
    
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -208,7 +208,7 @@ int record_parse (yyscan_t yyscanner, RecordTree* recordTree);
 #endif /* !YY_RECORD_PARSER_RECORDFILE_TAB_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
-#line 71 "parser/recordFile.y" /* yacc.c:358  */
+#line 70 "parser/recordFile.y" /* yacc.c:358  */
 
   // upper YYSTYPE union is required by Flex headers
 #include "parser/recordFile.h"
@@ -517,8 +517,8 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,   117,   117,   120,   121,   124,   130,   131,   133,   148,
-     152,   156,   159,   160,   162,   192
+       0,   116,   116,   119,   120,   123,   129,   130,   132,   147,
+     151,   155,   158,   159,   161,   195
 };
 #endif
 
@@ -1308,7 +1308,7 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 117 "parser/recordFile.y" /* yacc.c:1646  */
+#line 116 "parser/recordFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_WARNING, "%s", "the records file was empty");
 }
@@ -1316,7 +1316,7 @@ yyreduce:
     break;
 
   case 5:
-#line 125 "parser/recordFile.y" /* yacc.c:1646  */
+#line 124 "parser/recordFile.y" /* yacc.c:1646  */
     {
   // enabling encryption for body if needed is done by scanner
 }
@@ -1324,12 +1324,12 @@ yyreduce:
     break;
 
   case 8:
-#line 134 "parser/recordFile.y" /* yacc.c:1646  */
+#line 133 "parser/recordFile.y" /* yacc.c:1646  */
     {
   Collection* coll = 0;
   if (!(coll = getCollection((yyvsp[0].string)))) {
     logParser(LOG_WARNING, "unknown collection: %s", (yyvsp[0].string));
-    YYABORT;
+    YYERROR;
   }
   recordTree->collection = coll;
 
@@ -1343,7 +1343,7 @@ yyreduce:
     break;
 
   case 9:
-#line 149 "parser/recordFile.y" /* yacc.c:1646  */
+#line 148 "parser/recordFile.y" /* yacc.c:1646  */
     {
   strncpy(recordTree->fingerPrint, (yyvsp[0].string), MAX_SIZE_MD5);
 }
@@ -1351,7 +1351,7 @@ yyreduce:
     break;
 
   case 10:
-#line 153 "parser/recordFile.y" /* yacc.c:1646  */
+#line 152 "parser/recordFile.y" /* yacc.c:1646  */
     {
     recordTree->messageType = (yyvsp[0].msgval);
 }
@@ -1359,14 +1359,14 @@ yyreduce:
     break;
 
   case 14:
-#line 163 "parser/recordFile.y" /* yacc.c:1646  */
+#line 162 "parser/recordFile.y" /* yacc.c:1646  */
     {
   logParser(LOG_DEBUG, "%s", "add new record");
 
   struct tm date;
   if (localtime_r(&(yyvsp[0].record)->date, &date) == (struct tm*)0) {
     logParser(LOG_ERR, "%s", "localtime_r returns on error");
-    YYABORT;
+    YYERROR;
   }
 
   logParser(LOG_DEBUG, "line %i: %c "
@@ -1381,17 +1381,21 @@ yyreduce:
 	    MAX_SIZE_MD5, (yyvsp[0].record)->archive->hash, 
 	    MAX_SIZE_SIZE, (long long int)(yyvsp[0].record)->archive->size, 
 	    (yyvsp[0].record)->extra?(yyvsp[0].record)->extra:"");
- 
-  if (!rgInsert(recordTree->records, (yyvsp[0].record))) YYERROR;
-  // RQ: YYABORT will close the socket, do YYERROR close it ?
+
+   if (!avl_insert(recordTree->records, (yyvsp[0].record))) {
+     logParser(LOG_ERR, "cannot add record (already there?)");
+     // RQ: YYABORT will close the socket, do YYERROR close it ?
+     YYERROR;
+  }
+
   (yyvsp[0].record) = 0;
 
 }
-#line 1391 "parser/recordFile.tab.c" /* yacc.c:1646  */
+#line 1395 "parser/recordFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 15:
-#line 193 "parser/recordFile.y" /* yacc.c:1646  */
+#line 196 "parser/recordFile.y" /* yacc.c:1646  */
     {
   Server* server = 0;
   Archive* archive = 0;
@@ -1415,14 +1419,14 @@ yyreduce:
   if (!(extra = createString((yyvsp[0].string)))) YYERROR;
   if (!((yyval.record) = 
 	addRecord(recordTree->collection, server, archive, (yyvsp[-5].type), extra)))
-    YYABORT;
+    YYERROR;
   (yyval.record)->date = (yyvsp[-4].time);
 }
-#line 1422 "parser/recordFile.tab.c" /* yacc.c:1646  */
+#line 1426 "parser/recordFile.tab.c" /* yacc.c:1646  */
     break;
 
 
-#line 1426 "parser/recordFile.tab.c" /* yacc.c:1646  */
+#line 1430 "parser/recordFile.tab.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1650,7 +1654,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 220 "parser/recordFile.y" /* yacc.c:1906  */
+#line 223 "parser/recordFile.y" /* yacc.c:1906  */
 
       /* epilogue: =====================================================*/
 
