@@ -56,100 +56,111 @@ extern int serv_debug;
     servMASTER = 258,
     servSERVER = 259,
     servCOMMENT = 260,
-    servLABEL = 261,
-    servHOST = 262,
-    servLASTCOMMIT = 263,
-    servNETWORKS = 264,
-    servGATEWAYS = 265,
-    servMDTXPORT = 266,
-    servSSHPORT = 267,
-    servWWWPORT = 268,
-    servCOLLKEY = 269,
-    servUSERKEY = 270,
-    servHOSTKEY = 271,
-    servPROVIDE = 272,
-    servCOMMA = 273,
-    servCOLON = 274,
-    servEQUAL = 275,
-    servENDBLOCK = 276,
-    servCACHESIZE = 277,
-    servCACHETTL = 278,
-    servQUERYTTL = 279,
-    servSUPPTTL = 280,
-    servUPLOADTTL = 281,
-    servSERVERTTL = 282,
-    servMAXSCORE = 283,
-    servBADSCORE = 284,
-    servPOWSUPP = 285,
-    servFACTSUPP = 286,
-    servFILESCORE = 287,
-    servMINGEODUP = 288,
-    servERROR = 289,
-    servSTRING = 290,
-    servNUMBER = 291,
-    servSCORE = 292,
-    servHASH = 293,
-    servSIZE = 294,
-    servTIME = 295,
-    servDATE = 296
+    servHTTPS = 261,
+    servLOGAPACHE = 262,
+    servLOGGIT = 263,
+    servLOGAUDIT = 264,
+    servLABEL = 265,
+    servHOST = 266,
+    servLASTCOMMIT = 267,
+    servNETWORKS = 268,
+    servGATEWAYS = 269,
+    servMDTXPORT = 270,
+    servSSHPORT = 271,
+    servWWWPORT = 272,
+    servCOLLKEY = 273,
+    servUSERKEY = 274,
+    servHOSTKEY = 275,
+    servPROVIDE = 276,
+    servCOMMA = 277,
+    servCOLON = 278,
+    servEQUAL = 279,
+    servENDBLOCK = 280,
+    servCACHESIZE = 281,
+    servCACHETTL = 282,
+    servQUERYTTL = 283,
+    servSUPPTTL = 284,
+    servUPLOADTTL = 285,
+    servSERVERTTL = 286,
+    servMAXSCORE = 287,
+    servBADSCORE = 288,
+    servPOWSUPP = 289,
+    servFACTSUPP = 290,
+    servFILESCORE = 291,
+    servMINGEODUP = 292,
+    servERROR = 293,
+    servSTRING = 294,
+    servNUMBER = 295,
+    servSCORE = 296,
+    servHASH = 297,
+    servSIZE = 298,
+    servTIME = 299,
+    servDATE = 300,
+    servBOOLEAN = 301
   };
 #endif
 /* Tokens.  */
 #define servMASTER 258
 #define servSERVER 259
 #define servCOMMENT 260
-#define servLABEL 261
-#define servHOST 262
-#define servLASTCOMMIT 263
-#define servNETWORKS 264
-#define servGATEWAYS 265
-#define servMDTXPORT 266
-#define servSSHPORT 267
-#define servWWWPORT 268
-#define servCOLLKEY 269
-#define servUSERKEY 270
-#define servHOSTKEY 271
-#define servPROVIDE 272
-#define servCOMMA 273
-#define servCOLON 274
-#define servEQUAL 275
-#define servENDBLOCK 276
-#define servCACHESIZE 277
-#define servCACHETTL 278
-#define servQUERYTTL 279
-#define servSUPPTTL 280
-#define servUPLOADTTL 281
-#define servSERVERTTL 282
-#define servMAXSCORE 283
-#define servBADSCORE 284
-#define servPOWSUPP 285
-#define servFACTSUPP 286
-#define servFILESCORE 287
-#define servMINGEODUP 288
-#define servERROR 289
-#define servSTRING 290
-#define servNUMBER 291
-#define servSCORE 292
-#define servHASH 293
-#define servSIZE 294
-#define servTIME 295
-#define servDATE 296
+#define servHTTPS 261
+#define servLOGAPACHE 262
+#define servLOGGIT 263
+#define servLOGAUDIT 264
+#define servLABEL 265
+#define servHOST 266
+#define servLASTCOMMIT 267
+#define servNETWORKS 268
+#define servGATEWAYS 269
+#define servMDTXPORT 270
+#define servSSHPORT 271
+#define servWWWPORT 272
+#define servCOLLKEY 273
+#define servUSERKEY 274
+#define servHOSTKEY 275
+#define servPROVIDE 276
+#define servCOMMA 277
+#define servCOLON 278
+#define servEQUAL 279
+#define servENDBLOCK 280
+#define servCACHESIZE 281
+#define servCACHETTL 282
+#define servQUERYTTL 283
+#define servSUPPTTL 284
+#define servUPLOADTTL 285
+#define servSERVERTTL 286
+#define servMAXSCORE 287
+#define servBADSCORE 288
+#define servPOWSUPP 289
+#define servFACTSUPP 290
+#define servFILESCORE 291
+#define servMINGEODUP 292
+#define servERROR 293
+#define servSTRING 294
+#define servNUMBER 295
+#define servSCORE 296
+#define servHASH 297
+#define servSIZE 298
+#define servTIME 299
+#define servDATE 300
+#define servBOOLEAN 301
 
 /* Value type.  */
 #if ! defined SERV_STYPE && ! defined SERV_STYPE_IS_DECLARED
 typedef union SERV_STYPE SERV_STYPE;
 union SERV_STYPE
 {
-#line 61 "parser/serverFile.y" /* yacc.c:1909  */
+#line 60 "parser/serverFile.y" /* yacc.c:1909  */
 
   off_t  number;
   off_t  size;
   time_t time;
   float  score;
+  int    boolean;
   char   string[(MAX_SIZE_STRING+1)*2]; // keys needs more place
   char   hash[MAX_SIZE_MD5+1];
 
-#line 153 "parser/serverFile.tab.h" /* yacc.c:1909  */
+#line 164 "parser/serverFile.tab.h" /* yacc.c:1909  */
 };
 # define SERV_STYPE_IS_TRIVIAL 1
 # define SERV_STYPE_IS_DECLARED 1
@@ -159,7 +170,7 @@ union SERV_STYPE
 
 int serv_parse (yyscan_t yyscanner, Collection* coll, Server* server);
 /* "%code provides" blocks.  */
-#line 27 "parser/serverFile.y" /* yacc.c:1909  */
+#line 26 "parser/serverFile.y" /* yacc.c:1909  */
 
 /*=======================================================================
  * Version: this file is generated by BISON using serverFile.y
@@ -169,7 +180,7 @@ int serv_parse (yyscan_t yyscanner, Collection* coll, Server* server);
  * server file parser
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -187,6 +198,6 @@ int serv_parse (yyscan_t yyscanner, Collection* coll, Server* server);
 
 #define YYSTYPE SERV_STYPE
 
-#line 191 "parser/serverFile.tab.h" /* yacc.c:1909  */
+#line 202 "parser/serverFile.tab.h" /* yacc.c:1909  */
 
 #endif /* !YY_SERV_PARSER_SERVERFILE_TAB_H_INCLUDED  */
