@@ -69,7 +69,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 55 "parser/shellQuery.y" /* yacc.c:339  */
+#line 54 "parser/shellQuery.y" /* yacc.c:339  */
   
 #include "mediatex-config.h"
 #include "client/mediatex-client.h"
@@ -232,7 +232,7 @@ extern int shell_debug;
 typedef union SHELL_STYPE SHELL_STYPE;
 union SHELL_STYPE
 {
-#line 62 "parser/shellQuery.y" /* yacc.c:355  */
+#line 61 "parser/shellQuery.y" /* yacc.c:355  */
 
   int         number;
   char        string[MAX_SIZE_STRING+1];
@@ -248,7 +248,7 @@ union SHELL_STYPE
 
 int shell_parse (yyscan_t yyscanner, Collection* coll, UploadParams* upParam);
 /* "%code provides" blocks.  */
-#line 27 "parser/shellQuery.y" /* yacc.c:355  */
+#line 26 "parser/shellQuery.y" /* yacc.c:355  */
 
 /*=======================================================================
  * Version: this file is generated by BISON using shellQuery.y
@@ -258,7 +258,7 @@ int shell_parse (yyscan_t yyscanner, Collection* coll, UploadParams* upParam);
  * shell query parser.
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
    
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -281,7 +281,7 @@ int shell_parse (yyscan_t yyscanner, Collection* coll, UploadParams* upParam);
 #endif /* !YY_SHELL_PARSER_SHELLQUERY_TAB_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
-#line 68 "parser/shellQuery.y" /* yacc.c:358  */
+#line 67 "parser/shellQuery.y" /* yacc.c:358  */
 
   // upper YYSTYPE union is required by Flex headers
 #include "parser/shellQuery.h"
@@ -591,15 +591,15 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   159,   159,   164,   169,   174,   179,   185,   191,   192,
-     195,   200,   205,   209,   211,   215,   217,   218,   220,   224,
-     226,   234,   242,   253,   254,   259,   278,   283,   285,   298,
-     318,   325,   332,   339,   346,   353,   365,   374,   383,   392,
-     401,   410,   418,   426,   434,   442,   450,   458,   471,   479,
-     487,   495,   506,   515,   524,   533,   542,   551,   560,   569,
-     576,   585,   594,   604,   614,   627,   636,   645,   652,   659,
-     666,   680,   689,   698,   707,   714,   721,   728,   735,   749,
-     758
+       0,   158,   158,   163,   168,   173,   178,   184,   190,   191,
+     194,   199,   204,   208,   210,   214,   216,   217,   219,   223,
+     225,   233,   241,   252,   253,   258,   277,   282,   284,   297,
+     317,   324,   331,   338,   345,   352,   364,   373,   382,   391,
+     400,   409,   417,   425,   433,   441,   449,   457,   470,   478,
+     486,   494,   505,   514,   523,   532,   541,   550,   559,   568,
+     575,   584,   593,   603,   613,   626,   635,   644,   651,   658,
+     665,   679,   688,   697,   706,   713,   720,   727,   734,   748,
+     757
 };
 #endif
 
@@ -1511,7 +1511,7 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 160 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 159 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   strcpy((yyval.string), (yyvsp[0].string));
 }
@@ -1519,7 +1519,7 @@ yyreduce:
     break;
 
   case 3:
-#line 165 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 164 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   strcpy((yyval.string), (yyvsp[0].string));
 }
@@ -1527,7 +1527,7 @@ yyreduce:
     break;
 
   case 4:
-#line 170 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 169 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   strcpy((yyval.string), (yyvsp[0].string));
 }
@@ -1535,7 +1535,7 @@ yyreduce:
     break;
 
   case 5:
-#line 175 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 174 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   strcpy((yyval.string), (yyvsp[0].string));
 }
@@ -1543,7 +1543,7 @@ yyreduce:
     break;
 
   case 6:
-#line 180 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 179 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   (yyval.coll) = coll;
   coll = 0;
@@ -1552,7 +1552,7 @@ yyreduce:
     break;
 
   case 7:
-#line 186 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 185 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   // addCollection will be call later
   if (!(coll = createCollection())) YYABORT;
@@ -1561,7 +1561,7 @@ yyreduce:
     break;
 
   case 10:
-#line 196 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 195 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   if (!(coll->masterLabel = createString((yyvsp[0].string)))) YYABORT;
 }
@@ -1569,7 +1569,7 @@ yyreduce:
     break;
 
   case 11:
-#line 201 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 200 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   strncpy(coll->label, (yyvsp[0].string), MAX_SIZE_COLL);
 }
@@ -1577,7 +1577,7 @@ yyreduce:
     break;
 
   case 12:
-#line 206 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 205 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   strncpy(coll->masterHost, (yyvsp[0].string), MAX_SIZE_HOST);
 }
@@ -1585,7 +1585,7 @@ yyreduce:
     break;
 
   case 14:
-#line 212 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 211 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   coll->masterPort = (yyvsp[0].number);
 }
@@ -1593,7 +1593,7 @@ yyreduce:
     break;
 
   case 18:
-#line 221 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 220 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   if (!(upParam->target = createString((yyvsp[0].string)))) YYABORT;
 }
@@ -1601,7 +1601,7 @@ yyreduce:
     break;
 
   case 20:
-#line 227 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 226 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   if (upParam->file) {
     logParser(LOG_ERR, "please only provide one data file to upload");
@@ -1613,7 +1613,7 @@ yyreduce:
     break;
 
   case 21:
-#line 235 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 234 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   if (upParam->catalog) {
     logParser(LOG_ERR, "please only provide catalog file to upload");
@@ -1625,7 +1625,7 @@ yyreduce:
     break;
 
   case 22:
-#line 243 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 242 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   if (upParam->extract) {
     logParser(LOG_ERR, "please only provide one extract file to upload");
@@ -1637,7 +1637,7 @@ yyreduce:
     break;
 
   case 24:
-#line 255 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 254 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_ERR, "please use the -h flag to get help\n");
 }
@@ -1645,7 +1645,7 @@ yyreduce:
     break;
 
   case 30:
-#line 319 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 318 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "initializing mediatex software");
   if (!env.noRegression) {
@@ -1656,7 +1656,7 @@ yyreduce:
     break;
 
   case 31:
-#line 326 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 325 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "removing mediatex software");
   if (!env.noRegression) {
@@ -1667,7 +1667,7 @@ yyreduce:
     break;
 
   case 32:
-#line 333 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 332 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "purging mediatex software");
   if (!env.noRegression) {
@@ -1678,7 +1678,7 @@ yyreduce:
     break;
 
   case 33:
-#line 340 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 339 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "add %s user to groups", (yyvsp[-1].string));
   if (!env.noRegression) {
@@ -1689,7 +1689,7 @@ yyreduce:
     break;
 
   case 34:
-#line 347 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 346 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "del %s user from groups", (yyvsp[-1].string));
   if (!env.noRegression) {
@@ -1700,7 +1700,7 @@ yyreduce:
     break;
 
   case 35:
-#line 354 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 353 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   int rc = TRUE;
   logParser(LOG_INFO, "create/join new %s collection", (yyvsp[-1].coll)->label);
@@ -1716,7 +1716,7 @@ yyreduce:
     break;
 
   case 36:
-#line 366 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 365 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "free the %s collection", (yyvsp[-1].string));
   if (!env.noRegression) {
@@ -1729,7 +1729,7 @@ yyreduce:
     break;
 
   case 37:
-#line 375 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 374 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "update all");
   if (!env.noRegression) {
@@ -1742,7 +1742,7 @@ yyreduce:
     break;
 
   case 38:
-#line 384 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 383 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "update collection");
   if (!env.noRegression) {
@@ -1755,7 +1755,7 @@ yyreduce:
     break;
 
   case 39:
-#line 393 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 392 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "commit all");
   if (!env.noRegression) {
@@ -1768,7 +1768,7 @@ yyreduce:
     break;
 
   case 40:
-#line 402 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 401 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "commit collection");
   if (!env.noRegression) {
@@ -1781,11 +1781,11 @@ yyreduce:
     break;
 
   case 41:
-#line 411 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 410 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "quickly make all");
   if (!env.noRegression) {
-    env.noCollCvs = TRUE; // disable update/commit
+    env.noGitPullPush = TRUE; // disable git to reach network
     if (!clientLoop(mdtxMake)) YYABORT;
   }
 }
@@ -1793,11 +1793,11 @@ yyreduce:
     break;
 
   case 42:
-#line 419 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 418 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "quickly make collection");
   if (!env.noRegression) {
-    env.noCollCvs = TRUE;
+    env.noGitPullPush = TRUE; // disable git to reach network
     if (!mdtxMake((yyvsp[-1].string))) YYABORT;
   }
 }
@@ -1805,7 +1805,7 @@ yyreduce:
     break;
 
   case 43:
-#line 427 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 426 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "bind mediatex directories");
   if (!env.noRegression) {
@@ -1817,7 +1817,7 @@ yyreduce:
     break;
 
   case 44:
-#line 435 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 434 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "unbind mediatex directories");
   if (!env.noRegression) {
@@ -1829,7 +1829,7 @@ yyreduce:
     break;
 
   case 45:
-#line 443 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 442 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "mount %s on %s", (yyvsp[-3].string), (yyvsp[-1].string));
   if (!env.noRegression) {
@@ -1841,7 +1841,7 @@ yyreduce:
     break;
 
   case 46:
-#line 451 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 450 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "umount %s", (yyvsp[-1].string));
   if (!env.noRegression) {
@@ -1853,12 +1853,12 @@ yyreduce:
     break;
 
   case 47:
-#line 460 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 459 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "get %s as %s on %s as %s", (yyvsp[-7].string), (yyvsp[-5].string), (yyvsp[-3].string), (yyvsp[-1].string));
   if (!env.noRegression) {
     if (!allowedUser(env.confLabel)) YYABORT;
-    env.noCollCvs = TRUE; // do not upgrade
+    env.noGit = TRUE; // do not use git at all (no commit)
     if (!mdtxScp((yyvsp[-5].string), (yyvsp[-3].string), (yyvsp[-7].string), (yyvsp[-1].string))) YYABORT;
   }
 }
@@ -1866,7 +1866,7 @@ yyreduce:
     break;
 
   case 48:
-#line 472 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 471 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "send SAVEMD5 signal to daemon");
   if (!env.noRegression) {
@@ -1878,7 +1878,7 @@ yyreduce:
     break;
 
   case 49:
-#line 480 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 479 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "send EXTRACT signal to daemon");
   if (!env.noRegression) {
@@ -1890,7 +1890,7 @@ yyreduce:
     break;
 
   case 50:
-#line 488 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 487 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "send NOTIFY signal to daemon");
   if (!env.noRegression) {
@@ -1902,7 +1902,7 @@ yyreduce:
     break;
 
   case 51:
-#line 496 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 495 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "send DELIVER signal to daemon");
   if (!env.noRegression) {
@@ -1914,7 +1914,7 @@ yyreduce:
     break;
 
   case 52:
-#line 507 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 506 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "add a support to all collection");
   if (!env.noRegression) {
@@ -1927,7 +1927,7 @@ yyreduce:
     break;
 
   case 53:
-#line 516 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 515 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "add a support to a collection");
   if (!env.noRegression) {
@@ -1940,7 +1940,7 @@ yyreduce:
     break;
 
   case 54:
-#line 525 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 524 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "del a support from all collection");
   if (!env.noRegression) {
@@ -1953,7 +1953,7 @@ yyreduce:
     break;
 
   case 55:
-#line 534 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 533 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "del a support from a collection");
   if (!env.noRegression) {
@@ -1966,7 +1966,7 @@ yyreduce:
     break;
 
   case 56:
-#line 543 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 542 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "add %s support on %s", (yyvsp[-3].string), (yyvsp[-1].string));
   if (!env.noRegression) {
@@ -1979,7 +1979,7 @@ yyreduce:
     break;
 
   case 57:
-#line 552 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 551 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "add %s file", (yyvsp[-1].string));
   if (!env.noRegression) {
@@ -1992,7 +1992,7 @@ yyreduce:
     break;
 
   case 58:
-#line 561 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 560 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "remove a support");
   if (!env.noRegression) {
@@ -2005,7 +2005,7 @@ yyreduce:
     break;
 
   case 59:
-#line 570 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 569 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "list local supports");
   if (!env.noRegression) {
@@ -2016,7 +2016,7 @@ yyreduce:
     break;
 
   case 60:
-#line 577 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 576 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "note a support as \"%s\"", (yyvsp[-1].string));
   if (!env.noRegression) {
@@ -2029,7 +2029,7 @@ yyreduce:
     break;
 
   case 61:
-#line 586 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 585 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "check content located at %s", (yyvsp[-1].string));
   if (!env.noRegression) {
@@ -2042,7 +2042,7 @@ yyreduce:
     break;
 
   case 62:
-#line 595 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 594 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "upload a file to a collection");
   if (!env.noRegression) {
@@ -2056,7 +2056,7 @@ yyreduce:
     break;
 
   case 63:
-#line 605 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 604 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "upload+ a file to a collection");
   if (!env.noRegression) {
@@ -2070,7 +2070,7 @@ yyreduce:
     break;
 
   case 64:
-#line 615 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 614 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "upload++ a file to a collection");
   if (!env.noRegression) {
@@ -2084,7 +2084,7 @@ yyreduce:
     break;
 
   case 65:
-#line 628 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 627 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "add a key to a collection");
   if (!env.noRegression) {
@@ -2097,7 +2097,7 @@ yyreduce:
     break;
 
   case 66:
-#line 637 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 636 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "del a key to a collection");
   if (!env.noRegression) {
@@ -2110,7 +2110,7 @@ yyreduce:
     break;
 
   case 67:
-#line 646 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 645 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "listing locally hosted collections");
   if (!env.noRegression) {
@@ -2121,7 +2121,7 @@ yyreduce:
     break;
 
   case 68:
-#line 653 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 652 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "listing collections");
   if (!env.noRegression) {
@@ -2132,7 +2132,7 @@ yyreduce:
     break;
 
   case 69:
-#line 660 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 659 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "message of the day");
   if (!env.noRegression) {
@@ -2143,7 +2143,7 @@ yyreduce:
     break;
 
   case 70:
-#line 667 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 666 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "upgrade all");
   if (!env.noRegression) {
@@ -2161,7 +2161,7 @@ yyreduce:
     break;
 
   case 71:
-#line 681 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 680 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "upgrade a collection");
   if (!env.noRegression) {
@@ -2174,7 +2174,7 @@ yyreduce:
     break;
 
   case 72:
-#line 690 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 689 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "make all");
   if (!env.noRegression) {
@@ -2187,7 +2187,7 @@ yyreduce:
     break;
 
   case 73:
-#line 699 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 698 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "build a HTML catalog");
   if (!env.noRegression) {
@@ -2200,7 +2200,7 @@ yyreduce:
     break;
 
   case 74:
-#line 708 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 707 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "clean all");
   if (!env.noRegression) {
@@ -2211,7 +2211,7 @@ yyreduce:
     break;
 
   case 75:
-#line 715 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 714 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "clean an HTML catalog", (yyvsp[-1].string));
   if (!env.noRegression) {
@@ -2222,7 +2222,7 @@ yyreduce:
     break;
 
   case 76:
-#line 722 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 721 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "change to mediatex user");
   if (!env.noRegression) {
@@ -2233,7 +2233,7 @@ yyreduce:
     break;
 
   case 77:
-#line 729 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 728 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "change to collection user");
   if (!env.noRegression) {
@@ -2244,7 +2244,7 @@ yyreduce:
     break;
 
   case 78:
-#line 736 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 735 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "upgrade+ all");
   if (!env.noRegression) {
@@ -2262,7 +2262,7 @@ yyreduce:
     break;
 
   case 79:
-#line 750 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 749 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "upgrade+ a collection");
   if (!env.noRegression) {
@@ -2275,7 +2275,7 @@ yyreduce:
     break;
 
   case 80:
-#line 759 "parser/shellQuery.y" /* yacc.c:1646  */
+#line 758 "parser/shellQuery.y" /* yacc.c:1646  */
     {
   logParser(LOG_INFO, "audit collection");
   if (!env.noRegression) {
@@ -2516,7 +2516,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 768 "parser/shellQuery.y" /* yacc.c:1906  */
+#line 767 "parser/shellQuery.y" /* yacc.c:1906  */
 
 
 
@@ -2533,8 +2533,10 @@ void shell_error(yyscan_t yyscanner, Collection* coll,
 {
   logParser(LOG_ERR, "%s on token '%s'",
 	  message, shell_get_text(yyscanner));
-  logParser(LOG_NOTICE, 
-	  "bad invocation of mdtx's shell (try completion)");
+  logParser(LOG_NOTICE,
+	    "bad invocation of mdtx's shell. Try auto-completion:");
+  logParser(LOG_NOTICE,
+	    "-> $ . /etc/bash_completion.d/mediatex_comp");
 }
 
 
@@ -2555,8 +2557,11 @@ parseShellQuery(int argc, char** argv, int optind)
   UploadParams upParam = {0, 0, 0};
 
   logParser(LOG_DEBUG, "parseShellQuery");
-  if (!getCommandLine(argc, argv, optind)) goto error;
-
+  if (!getCommandLine(argc, argv, optind)) {
+    rc = TRUE; // no query
+    goto error;
+  }
+    
   // initialise parser
   if (shell_lex_init(&scanner)) {
     logParser(LOG_ERR, "shell_lex_init fails");
