@@ -1,12 +1,11 @@
 /*=======================================================================
- * Version: $Id: extract.c,v 1.25 2015/10/12 23:28:52 nroche Exp $
  * Project: MediaTeX
  * Module : mdtx-extract
  *
  * Manage remote extraction
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -25,7 +24,7 @@
 #include "mediatex-config.h"
 #include "server/mediatex-server.h"
 
-int extractArchive(ExtractData* data, Archive* archive);
+int extractArchive(ExtractData* data, Archive* archive, int doCp);
 
 /*=======================================================================
  * Function   : mdtxCall
@@ -278,7 +277,7 @@ extractIso(Collection* coll, FromAsso* asso, char* targetPath)
 
   // mount the iso
   if (!(iso = getAbsoluteArchivePath(coll, archive))) goto error2;
-  if (!mdtxCall(6, "adm", "mount", iso, "on", tmpDir, "-S")) 
+  if (!mdtxCall(5, "adm", "mount", iso, "on", tmpDir)) 
     goto error2;
 
   // copy the asso file
@@ -669,7 +668,8 @@ extractRar(Collection* coll, FromAsso* asso, char* targetPath)
 
 /*=======================================================================
  * Function   : extractAddToKeep
- * Description: lock archive as it may be used for extraction too
+ * Description: lock just extracted archive as it may be used for 
+ *              depper extraction too
  * Synopsis   : int extractAddToKeep(ExtractData* data, Archive* archive)
  * Input      : ExtractData* data
  *              Archive* archive
@@ -700,7 +700,7 @@ extractAddToKeep(ExtractData* data, Archive* archive)
 
 /*=======================================================================
  * Function   : extractDelToKeeps
- * Description: unlock archive
+ * Description: unlock archive (no more extraction using it)
  * Synopsis   : int extractDelToKeeps(Collection* coll, RG* toKeeps)
  * Input      : Collection* coll
  *              RG* toKeeps
@@ -728,7 +728,7 @@ extractDelToKeeps(Collection* coll, RG* toKeeps)
   if (!rc) {
     logMain(LOG_ERR, "extractDelToKeeps fails");
   }
-  destroyOnlyRing(toKeeps);
+  rgDelete(toKeeps);
   return rc;
 }
 
@@ -768,17 +768,23 @@ cacheSet(ExtractData* data, Record* record,
     goto error;
 
   // move from extract dir into the cache dir
-  // (rename do not remove source due to bind mount)
+  // (rename do not honor default target acl)
   logMain(LOG_INFO, "move %s to %s", 
-	  absoluteExtractPath, absoluteCachePath);  
+	  absoluteExtractPath, absoluteCachePath);
+  /*
   if (rename(absoluteExtractPath, absoluteCachePath)) {
     logMain(LOG_ERR, "rename fails: %s", strerror(errno));
     goto error;
   }
+  */
+  if (!extractCp(absoluteExtractPath, absoluteCachePath)) goto error;
+  if (unlink(absoluteExtractPath)) {
+    logMain(LOG_ERR, "unlink fails: %s", strerror(errno));
+    goto error;
+  }
 
   // toggle !malloc record to local-supply...
   relativeCachePath = absoluteCachePath + strlen(coll->cacheDir) + 1;
- 
   record->extra = destroyString(record->extra);
   if (!(record->extra = createString(relativeCachePath))) goto error;
 
@@ -798,7 +804,9 @@ cacheSet(ExtractData* data, Record* record,
 
 /*=======================================================================
  * Function   : extractRecord
- * Description: extract a record (cp and scp)
+ * Description: extract a record 
+ *               - cp from final supplies (ie supports)
+ *               - scp from remote cache's contents
  * Synopsis   : int extractRecord(Collection* coll, Record* sourceRecord)
  * Input      : Collection* coll
  *              Record* sourceRecord
@@ -906,7 +914,8 @@ extractRecord(ExtractData* data, Record* sourceRecord)
 
 /*=======================================================================
  * Function   : extractFromAsso
- * Description: extract a FromAsso (iso, cat and tgz)
+ * Description: extract a FromAss (iso, cat, tgz...)
+ *              (extract from container available into the local cache)
  * Synopsis   : int extractFromAsso(Collection* coll, Record* record)
  * Input      : Collection* coll
  *              Record* record
@@ -1018,9 +1027,7 @@ int extractContainer(ExtractData* data, Container* container)
 {
   int rc = FALSE;
   Archive* archive = 0;
-  Record* record = 0;
   RGIT* curr = 0;
-  RGIT* curr2 = 0;
   int found = FALSE;
 
   checkCollection(data->coll);
@@ -1033,39 +1040,28 @@ int extractContainer(ExtractData* data, Container* container)
 	  strEType(container->type), container->parent->hash,
 	  (long long int)container->parent->size);
 
-  // we extract all parents (only one for TGZ, several for CAT...)
+  // we extract all parents (as only one for TGZ, several for CAT...)
   curr = 0;
   found = TRUE;
   while ((archive = rgNext_r(container->parents, &curr))) {
-    if (!extractArchive(data, archive)) goto error;
+    if (!extractArchive(data, archive, FALSE)) goto error;
     found = found && data->found;
   }
-
+  
   logMain(LOG_INFO, "%sfound container %s/%s:%lli", data->found?"":"not ", 
 	  strEType(container->type), container->parent->hash,
 	  (long long int)container->parent->size);
 
   // postfix: copy container parts from final supplies
   if (!found) {
-
-    // for each part we have on final supply
     curr = 0;
     while ((archive = rgNext_r(container->parents, &curr))) {
-      if (archive->state < AVAILABLE &&
-  	  archive->finalSupplies->nbItems > 0) {
-  	logMain(LOG_INFO, "extract part from support");
-
-  	// stop on the first final-supply extraction that success
-	data->found = FALSE;
-  	while (!data->found &&
-  	       (record = rgNext_r(archive->finalSupplies, &curr2))) {
-  	  if (!extractRecord(data, record)) goto error;
-  	}
-      }
+      if (archive->state >= AVAILABLE) continue;
+      if (archive->finalSupplies->nbItems == 0) continue;
+      
+      logMain(LOG_INFO, "extract part from support");
+      if (!extractArchive(data, archive, TRUE)) goto error;
     }
-
-    // here we have only copy parts for next try
-    //data->found = FALSE; (already set)
   }
 
   data->found = found;
@@ -1081,16 +1077,20 @@ int extractContainer(ExtractData* data, Container* container)
 /*=======================================================================
  * Function   : extractArchive
  * Description: Single archive extraction
- * Synopsis   : int extractArchive
- * Input      : Collection* coll = context
- *              Archive* archive = what to extract
- * Output     : int data->found = TRUE if extracted
- *              FALSE on error
+ * Synopsis   : int extractArchive(ExtractData* data, Archive* archive,
+ *                                 int doCpIntoCache)
+ * Input      : Collection* coll: context
+ *              Archive* archive: what to extract
+ *              int doCp: use by extractContainer to provides container 
+ *                        parts, when not all available.
+ * Output     : int data->found: TRUE if extracted
+ *              int rc: FALSE on error
  * Note       : Recursive call
  =======================================================================*/
-int extractArchive(ExtractData* data, Archive* archive)
+int extractArchive(ExtractData* data, Archive* archive, int doCp)
 {
   int rc = FALSE;
+  Collection* coll = 0;
   int isThere = FALSE;
   FromAsso* asso = 0;
   Record* record = 0;
@@ -1098,15 +1098,30 @@ int extractArchive(ExtractData* data, Archive* archive)
   RGIT* curr = 0;
   RG* toKeepsBck = 0;
   RG* toKeepsTmp = 0;
+  int toDeliver = FALSE;
+  static int nbRemoteCopying = 0;
 
   logMain(LOG_DEBUG, "extract an archive: %s:%lli", 
 	  archive->hash, archive->size);
+  coll = data->coll;
   data->found = FALSE;
-  checkCollection(data->coll);
+  checkCollection(coll);
 
+  // deliver this archive if extraction success,
+  // if it match any CGI or local user demands
+  curr = 0;
+  while ((record = rgNext_r(archive->demands, &curr))) {
+    if (getRecordType(record) & (LOCAL_DEMAND | FINAL_DEMAND)) {
+      toDeliver = TRUE;
+      break;
+    }
+  }
+  
+  // local supply
   if (archive->state >= AVAILABLE) {
+    
     // test if the file is really there 
-    if (!(path = getAbsoluteRecordPath(data->coll, archive->localSupply))) 
+    if (!(path = getAbsoluteRecordPath(coll, archive->localSupply))) 
       goto error;
     if (!callAccess(path, &isThere)) goto error;
     if (!isThere) {
@@ -1120,45 +1135,57 @@ int extractArchive(ExtractData* data, Archive* archive)
 
   // final supply
   if (archive->finalSupplies->nbItems > 0) {
-    // test if the file is really there 
-    if (!(record = rgHead(archive->finalSupplies))) goto error;
-    if (!(path = getAbsoluteRecordPath(data->coll, record))) 
-      goto error;
-    if (!callAccess(path, &isThere)) goto error;
-    if (!isThere) {
-      logMain(LOG_DEBUG, "no input file: %s", path);
-      goto error;
-    }
 
-    // copy archive if wanted into the cache
-    if (data->target == archive) {
-      if (!extractRecord(data, record)) goto error;
-    }
-
-    data->found = TRUE;
+    // copy archive into the cache if it helps
+    if (archive->state == WANTED // localy (toDeliver) or remotely 
+	|| doCp // to help next remote extractions (see extractContainer)
+	|| (data->cpContext == X_DO_LOCAL_COPY // provides bad images
+	    && archive->state < WANTED
+	    && isBadTopContainer(coll, archive)))
+      {
+	curr = 0;
+	while (!data->found &&
+	       (record = rgNext_r(archive->finalSupplies, &curr))) {	  
+	  data->found = extractRecord(data, record);
+	}
+      }
+    data->found = TRUE; // from cache or final-supply
     goto end;
   }
 
-  // prefix: scp. Else (postfix) we will scp containers first.
-  if (data->context != X_CGI) {
-    curr = 0;
-    while (!data->found && 
-	  (record = rgNext_r(archive->remoteSupplies, &curr))) {
-      if (record->type & REMOVE) continue;
+  // remote supply (infixed call to scp the smallest file)
+  if (data->scpContext != X_NO_REMOTE_COPY) {
+    if (nbRemoteCopying >= MAX_REMOTE_COPIES) {
+      logMain(LOG_WARNING,
+	      "skip remote extraction as %i are already running",
+	      nbRemoteCopying);
+    }
+    else {
+      curr = 0;
+      while (!data->found &&
+	     (record = rgNext_r(archive->remoteSupplies, &curr))) {
+	if (record->type & REMOVE) continue;
 
-      // scp supply from nat clients on remote demand (may be optimized)
-      if (data->context == X_STEP &&
-	  !rgShareItems(data->coll->localhost->gateways,
-			record->server->networks)) 
-	continue;
+	// nat server scp from nat clients on remote demand
+	if (data->scpContext == X_GW_REMOTE_COPY &&
+	    !rgShareItems(coll->localhost->gateways,
+			  record->server->networks))
+	  continue;
 
-      if (!extractRecord(data, record)) goto error;
-      data->found = TRUE;
-      goto end; 
+	// remote copy
+	++nbRemoteCopying;
+	if (!extractRecord(data, record)) {
+	  --nbRemoteCopying;
+	  goto error;
+	}
+	--nbRemoteCopying;
+	data->found = TRUE;
+	goto end; 
+      }
     }
   }
 
-  // Recursive call: we stop on the first container we have extract
+  // Recursive call: we stop on the first extraction
 
   // backup toKeeps
   toKeepsBck = data->toKeeps;
@@ -1170,82 +1197,30 @@ int extractArchive(ExtractData* data, Archive* archive)
     if (!extractContainer(data, asso->container)) goto error;
   }
 
-  // backup temporary toKeeps
+  // backup temporary toKeeps and restore previous context
   toKeepsTmp = data->toKeeps;
   data->toKeeps = toKeepsBck;
-
+  
   if (data->found) {
     if (!extractFromAsso(data, asso)) goto error;
   }
 
-  // release temporary toKeeps
-  if (!extractDelToKeeps(data->coll, toKeepsTmp)) goto error;
-
+  // release temporary toKeeps (recursive extraction is now done)
+  if (!extractDelToKeeps(coll, toKeepsTmp)) goto error;
+  
  end:
   logMain(LOG_NOTICE, "%s:%lli %sfound", 
 	  archive->hash, archive->size, data->found?"":"not ");
+  if (data->found && toDeliver) {
+    if (!deliverArchive(coll, archive)) goto error;
+  }
   rc = TRUE;
  error:
   if (!rc) {
     logMain(LOG_ERR, "extractArchive fails");
   }
   path = destroyString(path);
-  return rc;
-} 
-
-/*=======================================================================
- * Function   : getWantedArchives
- * Description: copy all wanted archives into a ring
- * Synopsis   : RG* getWantedArchives(Collection* coll)
- * Input      : Collection* coll
- * Output     : a ring of arhives, 0 o error
- *
- * Warning    : there is still no unit test for this function !
- =======================================================================*/
-RG* 
-getWantedArchives(Collection* coll)
-{
-  RG* rc = 0;
-  RG* ring = 0;
-  Archive* archive = 0;
-  RGIT* curr = 0;
-  int isBadTop = 0;
-
-  checkCollection(coll);
-  logMain(LOG_DEBUG, "getWantedArchives");
-
-  if (!(ring = createRing())) goto error;
-  if (!computeExtractScore(coll)) goto error;
-
-  // look for archives we will try to extract
-  while ((archive = rgNext_r(coll->cacheTree->archives, &curr))) {
-
-    // check if it is a top containers having bad score
-    isBadTop =
-      (archive->state <= WANTED &&
-       archive->fromContainers->nbItems == 0 &&
-       archive->extractScore <= coll->serverTree->scoreParam.maxScore /2);
-
-    // add all local demands...
-    if (haveRecords(archive->demands) ||
-
-	// ...and available candidates for (local or remote) final supplies
-	isBadTop) {
-
-      /* maybe check minGeoDup and nb REMOTE_SUPPLY too in future */
-
-      logMain(LOG_INFO, "looking for %s%lli",
-	      archive->hash, (long long int)archive->size);
-      if (!rgInsert(ring, archive)) goto error;
-    }
-  }
-  
-  rc = ring;
- error:
-  if (!rc) {
-    logMain(LOG_ERR, "getWantedArchives fails");
-    destroyOnlyRing(ring);
-  }
+  toKeepsTmp = destroyOnlyRing(toKeepsTmp);
   return rc;
 } 
 
@@ -1260,58 +1235,60 @@ int extractArchives(Collection* coll)
 {
   int rc = FALSE;
   int rc2 = FALSE;
-  RG* archives = 0;
   Archive* archive = 0;
   Record* record = 0;
+  AVLNode* node = 0;
   RGIT* curr = 0;
-  RGIT* curr2 = 0;
   ExtractData data;
 
   logMain(LOG_DEBUG, "extractArchives %s collection", coll->label);
   checkCollection(coll);
   memset(&data, 0, sizeof(ExtractData));
+  if (!(data.toKeeps = createRing())) goto error;
+  data.cpContext = X_DO_LOCAL_COPY;
   data.coll = coll;
 
   if (!loadCollection(coll, SERV|EXTR|CACH)) goto error;
   if (!lockCacheRead(coll)) goto error2;
 
-  // for each archives we are looking for
-  if (!(archives = getWantedArchives(coll))) goto error3;
-  while ((archive = rgNext_r(archives, &curr))) {
+  // try to extract/deliver all demands
+  for (node = coll->cacheTree->archives->head; node; node = node->next) {
+    archive = node->item;
+    if (isEmptyRing(archive->demands) &&
+	  // candidates for (local or remote) final supplies
+	!(archive->state < WANTED && isBadTopContainer(coll, archive)))
+      continue;
+    logMain(LOG_INFO, "looking for %s%lli",
+	    archive->hash, (long long int)archive->size);
     
-    // define extraction context : X_MAIN or X_STEP (ie: scp or not)
-    data.context = X_STEP;
+    // define default scp extraction context:
+    // only scp to provides nat client content (not recheable by others)
+    data.scpContext = X_GW_REMOTE_COPY;
 
-    // we scp only when archive is or locally wanted...
-    curr2 = 0;
-    while ((record = rgNext_r(archive->demands, &curr2))) {
+    // but also do scp when archive is locally wanted...
+    curr = 0;
+    while ((record = rgNext_r(archive->demands, &curr))) {
       if (getRecordType(record) == FINAL_DEMAND) {
-	data.context = X_MAIN;
+	data.scpContext = X_DO_REMOTE_COPY;
 	break;
       }
     }
     
-    // ...or if bad score but already a final supply (store locally)
-    if ((archive->extractScore <= 
-	coll->serverTree->scoreParam.maxScore /2) &&
+    // ...or if it is a top container having bad score,
+    // not already burned locally
+    if (isBadTopContainer(coll, archive) &&
 	!haveRecords(archive->finalSupplies))
-      data.context = X_MAIN;
+      data.scpContext = X_DO_REMOTE_COPY;
     
-    data.target = archive;
-    if (!(data.toKeeps = createRing())) goto error3;
-    rc2 = extractArchive(&data, archive);
-    data.toKeeps = destroyOnlyRing(data.toKeeps);
+    rc2 = extractArchive(&data, archive, isBadTopContainer(coll, archive));
+    if (!extractDelToKeeps(coll, data.toKeeps)) goto error3;
     
     if (!rc2) {
       logMain(LOG_WARNING, "however continue...");
       continue;
     }
-
-    if (data.found) {
-      if (!deliverArchive(coll, archive)) goto error3;
-    }
   }
-  
+
   rc = TRUE;
  error3:
   if (!unLockCache(coll)) rc = FALSE;
@@ -1321,7 +1298,6 @@ int extractArchives(Collection* coll)
   if (!rc) {
     logMain(LOG_ERR, "extraction fails (internal error)");
   }
-  destroyOnlyRing(archives);
   destroyOnlyRing(data.toKeeps);
   return rc;
 } 
