@@ -1,12 +1,11 @@
 /*=======================================================================
- * Version: $Id: notify.h,v 1.5 2015/08/19 01:09:10 nroche Exp $
  * Project: MediaTeX
  * Module : notify
  *
  * Manage notify for remote servers: send local md5sums list
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -33,7 +32,7 @@ extern int running; // from threads.c
 typedef struct NotifyData {
 
   Collection* coll;
-  RG* toNotify; // records
+  AVLTree* toNotify; // records
   int found;
 
 } NotifyData;
