@@ -6,7 +6,7 @@
  * Example using libmediatex.a
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014  Nicolas Roche
+ Copyright (C) 2014 2015 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -29,8 +29,6 @@
 #include <locale.h>
 #include <avl.h>
 
-GLOBAL_STRUCT_DEF_BIN;
-
 /*=======================================================================
  * Function   : sqlString
  * Description: replace special caracteres
@@ -381,7 +379,7 @@ sqlExtractTree(Collection* coll)
   
   checkCollection(coll);
   if (!(self = coll->extractTree)) goto error;
-  logEmit(LOG_DEBUG, "sql %s extract tree", coll->label);
+  logMain(LOG_DEBUG, "sql %s extract tree", coll->label);
 
 
   // archives
@@ -446,7 +444,7 @@ sqlExtractTree(Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "sqlExtractTree fails");
+    logMain(LOG_ERR, "%s", "sqlExtractTree fails");
   }
   return rc;
 }
@@ -471,7 +469,7 @@ sqlServerTree(Collection* coll)
   
   checkCollection(coll);
   if (!(self = coll->serverTree)) goto error;
-  logEmit(LOG_DEBUG, "sql %s server tree", coll->label);
+  logMain(LOG_DEBUG, "sql %s server tree", coll->label);
 
 
   // servers
@@ -516,7 +514,7 @@ sqlServerTree(Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "sqlExtractTree fails");
+    logMain(LOG_ERR, "%s", "sqlExtractTree fails");
   }
   return rc;
 }
@@ -548,7 +546,7 @@ sqlCatalogTree(Collection* coll)
 
   checkCollection(coll);
   if (!(self = coll->catalogTree)) goto error;
-  logEmit(LOG_DEBUG, "sql %s document tree", coll->label);
+  logMain(LOG_DEBUG, "sql %s document tree", coll->label);
 
   // categories
   if (!isEmptyRing(self->categories)) {
@@ -731,7 +729,7 @@ sqlCatalogTree(Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "sqlCatalogTree fails");
+    logMain(LOG_ERR, "%s", "sqlCatalogTree fails");
   }
   return rc;
 }
@@ -785,7 +783,7 @@ sqlCaracs(Collection* coll)
   int i = 0;
 
   checkCollection(coll);
-  logEmit(LOG_DEBUG, "%s", "sql Caracs");
+  logMain(LOG_DEBUG, "%s", "sql Caracs");
 
   if (!(caracs = createRing())) goto error;
 
@@ -835,7 +833,7 @@ sqlCaracs(Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "cannot sql all caracs");
+    logMain(LOG_ERR, "%s", "cannot sql all caracs");
   }
   caracs = destroyOnlyRing(caracs);
   return(rc);
@@ -863,7 +861,7 @@ sqlAssoCaracs(Collection* coll)
   int i = 0;
 
   checkCollection(coll);
-  logEmit(LOG_DEBUG, "%s", "sql Caracs");
+  logMain(LOG_DEBUG, "%s", "sql Caracs");
 
   if (!(caracs = createRing())) goto error;
 
@@ -961,7 +959,7 @@ sqlAssoCaracs(Collection* coll)
   rc = TRUE;
  error:
   if (!rc) {
-    logEmit(LOG_ERR, "%s", "cannot sql all caracs");
+    logMain(LOG_ERR, "%s", "cannot sql all caracs");
   }
   caracs = destroyOnlyRing(caracs);
   return(rc);
@@ -971,8 +969,7 @@ sqlAssoCaracs(Collection* coll)
  * Function   : usage
  * Description: Print the usage.
  * Synopsis   : static void usage(char* programName)
- * Input      : programName = the name of the program; usually
- *                                  argv[0].
+ * Input      : programName = the name of the program; usually argv[0].
  * Output     : N/A
  =======================================================================*/
 static void 
@@ -981,19 +978,17 @@ usage(char* programName)
   mdtxUsage(programName);
   fprintf(stderr, "\n\t\tlabel");
   mdtxOptions();
-  fprintf(stderr, "  ---\n  label:\t\tcollection's label");
+  fprintf(stderr, "  ---\n  label:\t\tcollection's label\n");
   return;
 }
 
 
 /*=======================================================================
  * Function   : main 
- * Author     : Nicolas ROCHE
- * modif      : 2010/12/10
- * Description: Entry point for mdtx wrapper
- * Synopsis   : ./mdtx
+ * Description: Example using libmediatex
+ * Synopsis   : ./txt2sql
  * Input      : stdin
- * Output     : rtfm
+ * Output     : sql on stdout
  =======================================================================*/
 int 
 main(int argc, char** argv)
@@ -1037,7 +1032,7 @@ main(int argc, char** argv)
     goto optError;
   }
 
-  logEmit(LOG_INFO, "** txt2sql: %s **", argv[optind]);
+  logMain(LOG_INFO, "** txt2sql: %s **", argv[optind]);
 
   if (!(coll = mdtxGetCollection(argv[optind]))) goto error;
   if (!loadCollection(coll, SERV|CTLG|EXTR)) goto error;
